/*
 * Copyright (c) 2001 Pixware. 
 *
 * Author: Hussein Shafie
 *
 * This file is part of the XMLmind XML Editor project.
 * For conditions of distribution and use, see the accompanying legal.txt file.
 */

import java.io.*;
import com.xmlmind.xmledit.model.DocumentTypeModel;
import com.xmlmind.xmledit.modelimpl.Document;
import com.xmlmind.xmledit.modelimpl.XPDocumentLoader;
import com.xmlmind.xmledit.modeltool.DocumentTypeWriter;
import com.jclark.xml.parse.NotWellFormedException;

public class ExpandDTD {
    public static void main(String[] args) {
	if (args.length != 1) {
	    System.err.println("usage: java ExpandDTD inFileName");
	    System.exit(1);
	}
	String inFileName = args[0];

	try {
	    Document document = new Document();
	    (new XPDocumentLoader()).load(inFileName, document);

	    DocumentTypeModel docType = document.getDocumentType();
	    if (docType == null) {
		System.err.println("'" + inFileName + 
				   "' has no document type");
		System.exit(2);
	    }
		
	    DocumentTypeWriter.writeDocumentType(
		docType, new OutputStreamWriter(System.out, "UTF8"), 
                /*useURL*/ false);

	} catch (NotWellFormedException e1) {
	    System.err.println("parse error in '" + e1.getEntityLocation() + 
			       "', line " + e1.getLineNumber() +
			       ", column " + e1.getColumnNumber() + 
			       ": " + e1.getMessageWithoutLocation());
	    System.exit(3);
	} catch (Exception e2) {
	    e2.printStackTrace();

	    System.err.print(e2.getClass().getName());
	    String msg = e2.getMessage();
	    if (msg == null)
		System.err.println();
	    else
		System.err.println(": " + msg);
	    System.exit(4);
	}
    }
}
