/*
 * Copyright (c) 2001 Pixware. 
 *
 * Author: Hussein Shafie
 *
 * This file is part of the XMLmind XML Editor project.
 * For conditions of distribution and use, see the accompanying legal.txt file.
 */
package com.xmlmind.attedit;

import java.awt.Font;
import java.awt.Color;
import java.awt.Component;
import javax.swing.JTable;
import javax.swing.JLabel;
import javax.swing.ImageIcon;
import javax.swing.table.DefaultTableCellRenderer;
import com.xmlmind.awtutil.Bitmap;
import com.xmlmind.xmledit.model.AttributeDefinitionModel;

public class AttributeRenderer extends DefaultTableCellRenderer {
    private Font requiredAttributeFont = null;
    private Font fixedAttributeFont = null;
    private ImageIcon dropdownIcon = null;

    private static final Bitmap dropdownBitmap = 
	new Bitmap(7, 7, new byte[] {
	    (byte)0x00, (byte)0x00, (byte)0x7f, (byte)0x3e, (byte)0x1c, 
	    (byte)0x08, (byte)0x00
	});

    // -----------------------------------------------------------------------

    public AttributeRenderer() {
	setHorizontalTextPosition(JLabel.LEADING);
	setIconTextGap(2);
    }

    public Component getTableCellRendererComponent(JTable table, Object value,
						   boolean isSelected, 
						   boolean hasFocus, 
						   int row, int column) {
	super.getTableCellRendererComponent(table, value, isSelected, hasFocus,
					    row, column);

	Attribute attr = (Attribute) value;
	String text;

	setHorizontalAlignment(JLabel.LEADING);

	ImageIcon icon = null;
	if (column == 1 && attr.definition != null) {
	    switch (attr.definition.getAttributeType()) {
	    case AttributeDefinitionModel.IDREF:
	    case AttributeDefinitionModel.ENTITY:
	    case AttributeDefinitionModel.NOTATION:
	    case AttributeDefinitionModel.ENUMERATION:
		if (dropdownIcon == null)
		    dropdownIcon = new ImageIcon(
			dropdownBitmap.getImage(getForeground()));
		icon = dropdownIcon;
		break;
	    }
	}
	setIcon(icon);

	setEnabled(attr.value != null || isSelected || hasFocus);
	// Otherwise paint text as if disabled to show that the value comes
	// from the attribute definition default value.

	if (column == 0) {
	    if (attr.definition != null) {
		switch (attr.definition.getAttributePresence()) {
		case AttributeDefinitionModel.REQUIRED:
		    if (requiredAttributeFont == null) {
			Font font = getFont();
			requiredAttributeFont =
			    new Font(font.getFamily(), 
				     (font.isBold()? Font.PLAIN : Font.BOLD), 
				     font.getSize());
		    }
		    setFont(requiredAttributeFont);
		    break;
		case AttributeDefinitionModel.FIXED:
		    if (fixedAttributeFont == null) {
			Font font = getFont();
			fixedAttributeFont =
			    new Font(
				font.getFamily(), 
				(font.isItalic()? Font.PLAIN : Font.ITALIC), 
				font.getSize());
		    }
		    setFont(fixedAttributeFont);
		    break;
		}
	    }

	    text = attr.name;
	} else {
	    text = attr.value;
	    if (text == null) {
		if (attr.definition != null)
		    text = attr.definition.getAttributeDefaultValue();

		if (text == null) {
		    text = "-";
		    setHorizontalAlignment(JLabel.CENTER);
		}
	    }
	}

	setText(text);

	return this;
    }

    protected void setValue(Object value) {
	// Does nothing, the JLabel text is set by our
	// getTableCellRendererComponent.
    }
}
