/*
 * Copyright (c) 2001 Pixware. 
 *
 * Author: Hussein Shafie
 *
 * This file is part of the XMLmind XML Editor project.
 * For conditions of distribution and use, see the accompanying legal.txt file.
 */
package com.xmlmind.attedit;

import java.util.ResourceBundle;
import java.util.MissingResourceException;
import java.awt.Component;
import java.awt.Dialog;
import java.awt.Frame;
import javax.swing.JDesktopPane;
import javax.swing.JOptionPane;
import javax.swing.ImageIcon;
import com.xmlmind.awtutil.ImageResource;

public class Dialogs {
    private static ItemSelector itemSelector = null;
    private static ItemsSelector itemsSelector = null;
    private static ListEditor listEditor = null;

    private static ImageIcon itemSelectorIcon = 
        new ImageIcon(ImageResource.get(Dialogs.class, "item.gif"));
    private static ImageIcon listEditorIcon = 
        new ImageIcon(ImageResource.get(Dialogs.class, "listedit.gif"));
    private static ImageIcon itemsSelectorIcon = 
        new ImageIcon(ImageResource.get(Dialogs.class, "items.gif"));

    private static String errorLabel = "error";
    private static String browserTitleLabel = "browserTitle";
    private static String unselectedLabel = "unselected";
    private static String selectedLabel = "selected";
    static {
	try {
	    ResourceBundle resourceBundle = ResourceBundle.getBundle(
		"com.xmlmind.attedit.DialogsRes");
	    errorLabel = resourceBundle.getString(errorLabel);
	    browserTitleLabel = 
		resourceBundle.getString(browserTitleLabel);
	    unselectedLabel = resourceBundle.getString(unselectedLabel);
	    selectedLabel = resourceBundle.getString(selectedLabel);
	} catch (MissingResourceException ignored) {}
    }

    // -----------------------------------------------------------------------

    public static Component findDialogParent(Component component) {
	while (component != null) {
	    if ((component instanceof JDesktopPane) ||
		(component instanceof Dialog) ||
		(component instanceof Frame))
		return component;

	    component = component.getParent();
	}

	return null;
    }

    public static void showError(Component component, String message) {
	Component parent = findDialogParent(component);
	if (parent instanceof JDesktopPane)
	    JOptionPane.showInternalMessageDialog(parent, message, errorLabel, 
						  JOptionPane.ERROR_MESSAGE);
	else
	    JOptionPane.showMessageDialog(parent, message, errorLabel, 
					  JOptionPane.ERROR_MESSAGE);
    }

    public static String selectItem(Component component, String[] items, 
				    String selectedItem) {
	if (itemSelector == null) 
	    itemSelector = new ItemSelector(15, 20);
	itemSelector.setItems(items, /*sort*/ true, selectedItem);

	Component parent = findDialogParent(component);
	int option;
	if (parent instanceof JDesktopPane)
	    option = JOptionPane.showInternalOptionDialog(
		parent, itemSelector, browserTitleLabel, 
		JOptionPane.OK_CANCEL_OPTION, JOptionPane.PLAIN_MESSAGE, 
                itemSelectorIcon, /*options*/ null, /*initVal*/ null);
	else
	    option = JOptionPane.showOptionDialog(
		parent, itemSelector, browserTitleLabel, 
		JOptionPane.OK_CANCEL_OPTION, JOptionPane.PLAIN_MESSAGE, 
                itemSelectorIcon, /*options*/ null, /*initVal*/ null);

	return ((option == 0)? itemSelector.getItem() : null);
    }

    public static String[] editList(Component component, String[] items,
				    ItemChecker itemChecker) {
	if (listEditor == null) 
	    listEditor = new ListEditor(15, 20);
	listEditor.setItems(items);
	listEditor.setItemChecker(itemChecker);

	Component parent = findDialogParent(component);
	int option;
	if (parent instanceof JDesktopPane)
	    option = JOptionPane.showInternalOptionDialog(
		parent, listEditor, browserTitleLabel, 
		JOptionPane.OK_CANCEL_OPTION, JOptionPane.PLAIN_MESSAGE, 
                listEditorIcon, /*options*/ null, /*initVal*/ null);
	else
	    option = JOptionPane.showOptionDialog(
		parent, listEditor, browserTitleLabel, 
		JOptionPane.OK_CANCEL_OPTION, JOptionPane.PLAIN_MESSAGE, 
                listEditorIcon, /*options*/ null, /*initVal*/ null);

	return ((option == 0)? listEditor.getItems() : null);
    }

    public static String[] selectItems(Component component, String[] items, 
				       String[] selectedItems) {
	if (itemsSelector == null) 
	    itemsSelector = new ItemsSelector(15, 12, 
					      unselectedLabel, selectedLabel);
	itemsSelector.setItems(items, /*sort*/ true, selectedItems);

	Component parent = findDialogParent(component);
	int option;
	if (parent instanceof JDesktopPane)
	    option = JOptionPane.showInternalOptionDialog(
		parent, itemsSelector, browserTitleLabel, 
		JOptionPane.OK_CANCEL_OPTION, JOptionPane.PLAIN_MESSAGE, 
                itemsSelectorIcon, /*options*/ null, /*initVal*/ null);
	else
	    option = JOptionPane.showOptionDialog(
		parent, itemsSelector, browserTitleLabel, 
		JOptionPane.OK_CANCEL_OPTION, JOptionPane.PLAIN_MESSAGE, 
                itemsSelectorIcon, /*options*/ null, /*initVal*/ null);

	return ((option == 0)? itemsSelector.getItems() : null);
    }
}
