/*
 * Copyright (c) 2001 Pixware. 
 *
 * Author: Hussein Shafie
 *
 * This file is part of the XMLmind XML Editor project.
 * For conditions of distribution and use, see the accompanying legal.txt file.
 */
package com.xmlmind.attedit;

import java.awt.BorderLayout;
import javax.swing.JPanel;
import javax.swing.JScrollPane;
import javax.swing.JList;
import javax.swing.ListSelectionModel;
import fr.pixware.util.QuickSort;
import fr.pixware.util.StringUtil;

public class ItemSelector extends JPanel {
    private JList list;

    public ItemSelector(int rows, int columns) {
	setLayout(new BorderLayout());

	list = new JList();
	list.setSelectionMode(ListSelectionModel.SINGLE_SELECTION);
	StringBuffer prototype = new StringBuffer();
	while (columns > 0) {
	    prototype.append('x');
	    --columns;
	}
	list.setPrototypeCellValue(prototype.toString());
	list.setVisibleRowCount(rows);

	JScrollPane scroller = new JScrollPane(list);
	add(scroller, BorderLayout.CENTER);
    }

    public void setItems(String[] items, boolean sortItems, 
			 String selectedItem) {
	if (sortItems && items.length > 1) {
	    String[] sortedItems = new String[items.length];

	    System.arraycopy(items, 0, sortedItems, 0, items.length);
	    QuickSort.sort(sortedItems);

	    items = sortedItems;
	}

	if (selectedItem != null && !StringUtil.contains(items, selectedItem))
	    selectedItem = null;

	if (selectedItem == null && items.length > 0) 
	    selectedItem = items[0];

	list.setListData(items);
	if (selectedItem != null)
	    list.setSelectedValue(selectedItem, /*scroll*/ true);
    }

    public String getItem() {
	return (String) list.getSelectedValue();
    }
}
