/*
 * Copyright (c) 2001 Pixware. 
 *
 * Author: Hussein Shafie
 *
 * This file is part of the XMLmind XML Editor project.
 * For conditions of distribution and use, see the accompanying legal.txt file.
 */
package com.xmlmind.attedit;

import java.awt.Insets;
import java.awt.FlowLayout;
import java.awt.BorderLayout;
import java.awt.GridBagLayout;
import java.awt.GridBagConstraints;
import java.awt.event.ActionListener;
import java.awt.event.ActionEvent;
import javax.swing.JPanel;
import javax.swing.JScrollPane;
import javax.swing.JList;
import javax.swing.JTextField;
import javax.swing.JButton;
import javax.swing.ListModel;
import javax.swing.ListSelectionModel;
import javax.swing.ImageIcon;
import javax.swing.event.ListSelectionListener;
import javax.swing.event.ListSelectionEvent;
import fr.pixware.util.StringUtil;
import com.xmlmind.awtutil.ImageResource;

public class ListEditor extends JPanel 
                        implements ActionListener, ListSelectionListener {
    public static final int FIRST    = 0;
    public static final int PREVIOUS = 1;
    public static final int NEXT     = 2;
    public static final int LAST     = 3;

    private ItemChecker itemChecker = null;

    private JTextField field;
    private JButton removeButton;
    private JButton addButton;
    private JButton cancelButton;
    private JList list;
    private JButton firstButton;
    private JButton previousButton;
    private JButton nextButton;
    private JButton lastButton;

    // -----------------------------------------------------------------------

    public ListEditor(int rows, int columns) {
	setLayout(new BorderLayout(0, 2));

	JPanel form = new JPanel(new GridBagLayout());
	add(form, BorderLayout.NORTH);

        GridBagConstraints constraints = new GridBagConstraints();
        constraints.gridx = 0;
        constraints.gridy = 0;

	field = new JTextField();
	constraints.fill = GridBagConstraints.HORIZONTAL;
	constraints.weightx = 1;
	form.add(field, constraints);
	field.setActionCommand("add");
	field.addActionListener(this);
	
	removeButton = new JButton(new ImageIcon(
	    ImageResource.get(getClass(), "remove.gif")));
	Insets margin = new Insets(1, 1, 1, 1);
	removeButton.setMargin(margin);
	++constraints.gridx;
	constraints.fill = GridBagConstraints.NONE;
	constraints.weightx = 0;
	constraints.insets.left = 2;
	form.add(removeButton, constraints);
	removeButton.setActionCommand("remove");
	removeButton.addActionListener(this);

	addButton = new JButton(new ImageIcon(
	    ImageResource.get(getClass(), "add.gif")));
	addButton.setMargin(margin);
	++constraints.gridx;
	form.add(addButton, constraints);
	addButton.setActionCommand("add");
	addButton.addActionListener(this);

	cancelButton = new JButton(new ImageIcon(
	    ImageResource.get(getClass(), "cancel.gif")));
	cancelButton.setMargin(margin);
	++constraints.gridx;
	form.add(cancelButton, constraints);
	cancelButton.setActionCommand("cancel");
	cancelButton.addActionListener(this);

	list = new JList();
	list.setSelectionMode(ListSelectionModel.SINGLE_SELECTION);
	StringBuffer prototype = new StringBuffer();
	while (columns > 0) {
	    prototype.append('x');
	    --columns;
	}
	list.setPrototypeCellValue(prototype.toString());
	list.setVisibleRowCount(rows);
	list.addListSelectionListener(this);

	JScrollPane scroller = new JScrollPane(list);
	add(scroller, BorderLayout.CENTER);

	JPanel buttons = new JPanel(new FlowLayout(FlowLayout.CENTER, 2, 0));
	add(buttons, BorderLayout.SOUTH);

	firstButton = new JButton(new ImageIcon(
	    ImageResource.get(getClass(), "first.gif")));
	firstButton.setMargin(margin);
	buttons.add(firstButton);
	firstButton.setActionCommand("first");
	firstButton.addActionListener(this);

	previousButton = new JButton(new ImageIcon(
	    ImageResource.get(getClass(), "previous.gif")));
	previousButton.setMargin(margin);
	buttons.add(previousButton);
	previousButton.setActionCommand("previous");
	previousButton.addActionListener(this);

	nextButton = new JButton(new ImageIcon(
	    ImageResource.get(getClass(), "next.gif")));
	nextButton.setMargin(margin);
	buttons.add(nextButton);
	nextButton.setActionCommand("next");
	nextButton.addActionListener(this);

	lastButton = new JButton(new ImageIcon(
	    ImageResource.get(getClass(), "last.gif")));
	lastButton.setMargin(margin);
	buttons.add(lastButton);
	lastButton.setActionCommand("last");
	lastButton.addActionListener(this);
    }

    public void setItemChecker(ItemChecker itemChecker) {
	this.itemChecker = itemChecker;
    }

    public ItemChecker getItemChecker() {
	return itemChecker;
    }

    public void setItems(String[] items) {
	list.setListData(items);
	list.ensureIndexIsVisible(0);
	cancel();
    }

    private void cancel() {
	list.clearSelection();
	itemSelected(-1);
    }

    private void itemSelected(int index) {
	ListModel model = list.getModel();
	int last = model.getSize() - 1;

	if (index < 0 || index > last) {
	    field.setText("");
	    field.setEditable(true);
	    removeButton.setEnabled(false);
	    addButton.setEnabled(true);

	    firstButton.setEnabled(false);
	    previousButton.setEnabled(false);
	    nextButton.setEnabled(false);
	    lastButton.setEnabled(false);
	} else {
	    field.setText((String) model.getElementAt(index));
	    field.setEditable(false);
	    removeButton.setEnabled(true);
	    addButton.setEnabled(false);

	    firstButton.setEnabled(index > 0);
	    previousButton.setEnabled(index > 0);
	    nextButton.setEnabled(index < last);
	    lastButton.setEnabled(index < last);
	}
    }

    public String[] getItems() {
	return getListData(list);
    }

    private static String[] getListData(JList list) {
	ListModel model = list.getModel();
	String[] items = new String[model.getSize()];

	for (int i = 0; i < items.length; ++i)
	    items[i] = (String) model.getElementAt(i);

	return items;
    }

    public void valueChanged(ListSelectionEvent e) {
	int index  = list.getSelectedIndex();
	if (index >= 0)
	    itemSelected(index);
    }

    public void actionPerformed(ActionEvent e) {
	String command = e.getActionCommand();

	if (command.equals("add")) 
	    add();
	else if (command.equals("remove")) 
	    remove();
	else if (command.equals("cancel")) 
	    cancel();
	else if (command.equals("first")) 
	    move(FIRST);
	else if (command.equals("previous")) 
	    move(PREVIOUS);
	else if (command.equals("next")) 
	    move(NEXT);
	else if (command.equals("last")) 
	    move(LAST);
    }

    private void remove() {
	int index  = list.getSelectedIndex();
	if (index < 0)
	    return;

	String[] items = getItems();
	if (index >= items.length)
	    return;

	list.setListData(StringUtil.removeAt(items, index));

	cancel();
    }

    private void add() {
	String newItem = field.getText().trim();
	if (newItem.length() == 0 ||
	    (itemChecker != null && !itemChecker.checkItem(newItem))) {
	    field.getToolkit().beep();
	    field.selectAll();
	    field.requestFocus();
	    return;
	}

	String[] newItems = StringUtil.append(getItems(), newItem);
	list.setListData(newItems);
	list.ensureIndexIsVisible(newItems.length-1);

	cancel();
    }

    private void move(int where) {
	int srcIndex  = list.getSelectedIndex();
	if (srcIndex < 0)
	    return;

	String[] items = getItems();
	if (srcIndex >= items.length)
	    return;

	int dstIndex = srcIndex;
	switch (where) {
	case FIRST:
	    dstIndex = 0;
	    break;
	case PREVIOUS:
	    dstIndex = srcIndex - 1;
	    if (dstIndex < 0)
		dstIndex = 0;
	    break;
	case NEXT:
	    dstIndex = srcIndex + 1;
	    if (dstIndex >= items.length)
		dstIndex = items.length - 1;
	    break;
	case LAST:
	    dstIndex = items.length - 1;
	    break;
	}

	if (dstIndex != srcIndex) {
	    move(items, srcIndex, dstIndex);
	    list.setListData(items);
	}
	list.setSelectedIndex(dstIndex);
	list.ensureIndexIsVisible(dstIndex);
    }

    private static void move(String[] strings, int srcIndex, int dstIndex) {
	if (dstIndex < srcIndex) {
	    String src = strings[srcIndex];
	    for (int i = srcIndex-1; i >= dstIndex; --i)
		strings[i+1] = strings[i];
	    strings[dstIndex] = src;
	} else if (dstIndex > srcIndex) {
	    String src = strings[srcIndex];
	    for (int i = srcIndex+1; i <= dstIndex; ++i)
		strings[i-1] = strings[i];
	    strings[dstIndex] = src;
	}
    }
}
