/*
 * Copyright (c) 2000-2001 Pixware. 
 *
 * Author: Hussein Shafie
 *
 * This file is part of the XMLmind XML Editor project.
 * For conditions of distribution and use, see the accompanying legal.txt file.
 */
package com.xmlmind.awtutil;

import java.awt.Component;
import java.awt.Toolkit;
import java.awt.Color;
import java.awt.Image;
import java.awt.image.MemoryImageSource;

public class Bitmap {
    private int width, height;
    private byte[] bytes;
	
    public Bitmap(int width, int height, byte[] bytes) {
	this.width = width;
	this.height = height;
	this.bytes = bytes;
    }

    public int getWidth() {
	return width;
    }

    public int getHeight() {
	return height;
    }

    public byte[] getBytes() {
	return bytes;
    }

    public Image getImage(Color foreground) {
	return getImage(foreground, null);
    }

    public Image getImage(Color foreground, Color background) {
	int bytesPerRow = (width + 7) / 8;
	int[] pixels = new int[width*height];
	int fgPixel = (0xFF000000 | (foreground.getRed() << 16) | 
		       (foreground.getGreen() << 8) | foreground.getBlue());
	int bgPixel;
	if (background == null)
	    bgPixel = 0x00FFFFFF; // Transparent!
	else
	    bgPixel = (0xFF000000 | (background.getRed() << 16) | 
		       (background.getGreen() << 8) | background.getBlue());

	int j = 0;
	for (int y = 0; y < height; ++y) {
	    int mask = 0x80;
	    int i = y*bytesPerRow - 1;
	    int bits = 0x0;

	    for (int x = 0; x < width; ++x) {
		if (mask == 0x80) {
		    ++i;
		    bits = bytes[i];
		    mask = 0x01;
		} else {
		    mask = (mask << 1);
		}

		pixels[j++] = ((bits & mask) == 0)? bgPixel : fgPixel;
	    }
	}

	MemoryImageSource source = 
	    new MemoryImageSource(width, height, pixels, 0, width);
	Image image = Toolkit.getDefaultToolkit().createImage(source);

	return (image == null)? null : ImageResource.loadImage(image);
    }
}
