/*
 * Copyright (c) 2000-2001 Pixware. 
 *
 * Author: Hussein Shafie
 *
 * This file is part of the XMLmind XML Editor project.
 * For conditions of distribution and use, see the accompanying legal.txt file.
 */
package com.xmlmind.awtutil;

import java.io.BufferedInputStream;
import java.io.ByteArrayOutputStream;
import java.awt.Component;
import java.awt.Toolkit;
import java.awt.Image;
import java.awt.MediaTracker;

public class ImageResource {
    private static Component component = new Component() {};
    private static MediaTracker tracker = new MediaTracker(component);

    public static Image get(Class cls, String name) {
	Image image;
	try {
	    // When writing applets, Netscape accepts getResourceAsStream()
	    // and rejects getResource().

	    BufferedInputStream in = 
		new BufferedInputStream(cls.getResourceAsStream(name));
	    ByteArrayOutputStream out = new ByteArrayOutputStream();
	    byte[] bytes = new byte[8192];
	    int count;

	    while ((count = in.read(bytes)) >= 0)
		out.write(bytes, 0, count);

	    image = Toolkit.getDefaultToolkit().createImage(out.toByteArray());
	} catch (Exception e) {
	    e.printStackTrace();
	    image = null;
	}

	return (image == null)? null : loadImage(image);
    }

    public static Image loadImage(Image image) {
	int status;

	synchronized (tracker) {
	    tracker.addImage(image, 0);
	    try {
		tracker.waitForID(0, 5000);
	    } catch (InterruptedException e) {
		e.printStackTrace();
	    }
            status = tracker.statusID(0, false);
	    tracker.removeImage(image, 0);
	}

	if (status != MediaTracker.COMPLETE)
	    image = null;

	return image;
    }
}

