/*
 * Copyright (c) 2000-2001 Pixware. 
 *
 * Author: Hussein Shafie
 *
 * This file is part of the XMLmind XML Editor project.
 * For conditions of distribution and use, see the accompanying legal.txt file.
 */
package com.xmlmind.gadget;

import java.awt.*;

public class ComponentWrapper extends Gadget {
    protected Component component;
    protected boolean stretchX, stretchY;

    public ComponentWrapper(Component component) {
	this.component = component;
	stretchX = stretchY = false;

	relayout();
    }

    public Component getComponent() {
	return component;
    }

    public void setXStretchable(boolean stretch) {
	stretchX = stretch;
    }

    public boolean isXStretchable() {
	return stretchX;
    }

    public void setYStretchable(boolean stretch) {
	stretchY = stretch;
    }

    public boolean isYStretchable() {
	return stretchY;
    }

    public void relayout(boolean recursive) {
	if (stretchX || stretchY)
	    super.relayout(recursive);
	else
	    layout(-1, -1, recursive);
    }

    public void layout(int constrainedWidth, int constrainedHeight,
		       boolean recursive) {
	Dimension dim = component.getPreferredSize();
	if (stretchX && constrainedWidth > 0) {
	    if (dim.width < constrainedWidth)
		dim.width = constrainedWidth;
	}
	if (stretchY && constrainedHeight > 0) {
	    if (dim.height < constrainedHeight)
		dim.height = constrainedHeight;
	}
	component.setSize(dim.width, dim.height);

	// Relayout the component.
	component.validate();

	width = dim.width;
	height = dim.height;
    }

    public void paint(Graphics g) {
	updateComponentLocation();

	// The component itself is painted by its AWT or Swing container: 
	// the panel.
    }

    public void updateComponentLocation() {
	Point origin = component.getLocation();
	int currentX = origin.x;
	int currentY = origin.y;

	origin.x = 0;
	origin.y = 0;
	gadgetToPanel(origin);

	if (origin.y != currentY || origin.x != currentX)
	    // setLocation is an expensive operation.
	    component.setLocation(origin.x, origin.y);
    }
}
