#!/bin/sh
#
# Next line is both a Tcl comment and a shell command \
exec tclsh "$0" "$@"

set xxeHome "/home/hussein/src/xmledit"
set xxeDist "$xxeHome/distrib"

global kClassPath
set kClassPath \
    "$xxeHome/class:$xxeDist/xp.jar:$xxeDist/sax.jar:$xxeDist/gnuregexp.jar"
if {[info exist env(CLASSPATH)]} {
    append kClassPath ":$env(CLASSPATH)"
}

proc processDir {dirName report} {
    set fileNames [glob -nocomplain [file join $dirName "*"]]

    foreach fileName $fileNames {
	if {[file isfile $fileName] && [file extension $fileName] == ".java"} {
	    processFile $fileName $report
	}
    }

    foreach fileName $fileNames {
	if {[file isdir $fileName]} {
	    processDir $fileName $report
	}
    }
}

proc processFile {fileName report} {
    global kClassPath

    set outName [file join /tmp [file rootname [file tail $fileName]]]
    set cmd [list java -classpath $kClassPath \
	    com.xmlmind.javadocformat.Format $fileName]

    set reportLine "$fileName:"

    set xmlName "${outName}.xml"
    set cmd1 [concat $cmd $xmlName]
    if {[catch {eval exec $cmd1} reason]} {
	append reportLine " FAIL:\n$reason\n\t"
	set cmd1Done 0
    } else {
	append reportLine " OK"
	set cmd1Done 1
    }

    if {$cmd1Done} {
	set cmd2 [list validxml $xmlName]
	if {[catch {eval exec $cmd2} reason]} {
	    append reportLine " FAIL:\n$reason\n\t"
	} else {
	    append reportLine " OK"
	}
    } else {
	append reportLine " -"
    }
    file delete -force $xmlName

    if {$cmd1Done} {
	set javaName "${outName}.java"

	set cmd3 [concat $cmd $javaName]
	if {[catch {eval exec $cmd3} reason]} {
	    append reportLine " FAIL:\n$reason\n\t"
	} else {
	    append reportLine " OK"
	}

	file delete -force $javaName
    } else {
	append reportLine " -"
    }

    puts stdout $reportLine

    puts $report $reportLine
    flush $report
}

if {$argc != 2} {
    puts stderr "usage: $argv0 java_dir report_file"
    exit 1
}
set dirName [lindex $argv 0]
set reportName [lindex $argv 1]
set report [open $reportName w]

if {![catch { processDir $dirName $report } error]} {
    set error ""
}

close $report

if {$error != ""} {
    puts stderr "$argv0: *** error: $error ***"
    exit 2
}


