/*
 * Copyright (c) 2001 Pixware. 
 *
 * Author: Hussein Shafie
 *
 * This file is part of the XMLmind XML Editor project.
 * For conditions of distribution and use, see the accompanying legal.txt file.
 */
package com.xmlmind.swingutil;

import javax.swing.SwingUtilities;

public abstract class AsyncCommand implements Runnable {
    private boolean doExec;
    private Thread worker;

    public boolean start() {
	if (!init())
	    return false;

	doExec = true;
	worker = new Thread(this);
	worker.start();
	return true;
    }

    public void run() {
	if (doExec) {
	    doExec = false;

	    try {
		exec();
	    } catch (Exception e) {
		System.err.println("internal error in " + 
				   getClass().getName());
		e.printStackTrace();
	    }

	    // The worker thread is terminated.
	    // finish runs in the AWT event dispatcher thread.
	    SwingUtilities.invokeLater(this);
	} else {
	    finish();
	}
    }

    protected abstract boolean init();
    protected abstract void exec();
    protected abstract void finish();
}
