/*
 * Copyright (c) 2000-2001 Pixware. 
 *
 * Author: Hussein Shafie
 *
 * This file is part of the XMLmind XML Editor project.
 * For conditions of distribution and use, see the accompanying legal.txt file.
 */
package com.xmlmind.swingutil;

import java.awt.*;
import javax.swing.border.AbstractBorder;
import javax.swing.text.JTextComponent;

public class ThinBorder extends AbstractBorder {
    private Color dark;
    private Color light;
    private boolean raised;
    private int marginWidth, marginHeight;

    public ThinBorder(Color color, boolean raised) {
	this(color, raised, -1, -1);
    }

    public ThinBorder(Color color, boolean raised, 
		      int marginWidth, int marginHeight) {
	if (marginWidth < 0)
	    marginWidth = 2;
	if (marginHeight < 0)
	    marginHeight = 2;

	dark = color.darker();
	light = color.brighter();
	this.raised = raised;
	this.marginWidth = marginWidth;
	this.marginHeight = marginHeight;
    }

    public void paintBorder(Component c, Graphics g, int x, int y, 
			    int width, int height) {
	// Graphics is in fact a SwingGraphics where draw3DRect has been
	// overridden.

	g.setColor(raised? dark : light);
	g.drawLine(x, y+height-1, x+width-1, y+height-1);
	g.drawLine(x+width-1, y+height-1, x+width-1, y);
	g.setColor(raised? light : dark);
	g.drawLine(x, y, x+width-1, y);
	g.drawLine(x, y, x, y+height-1);
    }

    public Insets getBorderInsets(Component c) {
	return new Insets(1+marginHeight, 1+marginWidth, 
			  1+marginHeight, 1+marginWidth);
    }
}
