/*
 * Copyright (c) 2000-2001 Pixware. 
 *
 * Author: Hussein Shafie
 *
 * This file is part of the XMLmind XML Editor project.
 * For conditions of distribution and use, see the accompanying legal.txt file.
 */
package com.xmlmind.xmledit;

import java.awt.Graphics;
import java.awt.Color;
import java.awt.Rectangle;
import com.xmlmind.gadget.Gadget;
import com.xmlmind.xmledit.model.SubelementModel;

public class DefaultSubelementSelection extends SubelementSelection {
    private Color color = Color.red;

    private RectangleListImpl rectList = new RectangleListImpl();
    private Rectangle nextRect = new Rectangle();
    private Rectangle currentRect = new Rectangle();

    // Scratch variables.
    private RectangularEnvelope envelope = new RectangularEnvelope();
    private RectangularEnvelope.Points points=new RectangularEnvelope.Points();

    public DefaultSubelementSelection(DocumentView documentView) {
	super(documentView);
    }

    public void setColor(Color color) {
	this.color = color;
	repaint();
    }

    private void repaint() {
	if (currentRect.width > 0)
	    docView.repaint(currentRect.x, currentRect.y, 
			    currentRect.width, currentRect.height);
    }

    public Color getColor() {
	return color;
    }

    public Rectangle refresh() {
	if (currentRect.width > 0) {
	    docView.repaint(currentRect.x, currentRect.y, 
			    currentRect.width, currentRect.height);
	    currentRect.x = currentRect.y = 
		currentRect.width = currentRect.height = 0;
	}

	relayout();
	if (nextRect.width > 0) 
	    docView.repaint(nextRect.x, nextRect.y,
			    nextRect.width, nextRect.height);

	return nextRect;
    }

    public void paint(Graphics g) {
	if (nextRect.width <= 0) 
	    relayout();

	int rectangleCount = rectList.size;
	if (rectangleCount > 0) {
	    Rectangle clip = g.getClipBounds();
	    
	    if (clip == null || 
		// Outline intersects clip.
		(nextRect.x < clip.x+clip.width && 
		 nextRect.y < clip.y+clip.height &&
		 nextRect.x+nextRect.width > clip.x && 
		 nextRect.y+nextRect.height > clip.y)) {

		g.setColor(color);

		Rectangle[] rectangles = rectList.list;
		if (rectangleCount == 1) {
		    Rectangle rect = rectangles[0];
		    g.drawRect(rect.x, rect.y, 
			       rect.width-1, rect.height-1);
		} else {
		    envelope.compute(rectList.list, rectangleCount, points);
		    g.drawPolygon(points.x, points.y, points.count);
		}
	    }

	    currentRect.x = nextRect.x;
	    currentRect.y = nextRect.y;
	    currentRect.width = nextRect.width;
	    currentRect.height = nextRect.height;

	    nextRect.x = nextRect.y = nextRect.width = nextRect.height = 0;

	    rectList.removeAll();
	}
    }

    private void relayout() {
	rectList.removeAll();
	nextRect.x = nextRect.y = nextRect.width = nextRect.height = 0;

	SubelementModel selected = mark.getSubelement();
	if (selected != null) {
	    docView.modelToView(selected, rectList);

	    int rectangleCount = rectList.size;
	    Rectangle[] rectangles = rectList.list;
	    for (int i = 0; i < rectangleCount; ++i) {
		Rectangle rectangle = rectangles[i];

		if (rectangle.height > 0) {
		    if (rectangle.width <= 0)
			rectangle.width = 1;

		    union(nextRect, rectangle);
		}
	    }
	}
    }

    private static final void union(Rectangle u, Rectangle r) {
	if (r.width <= 0 || r.height <= 0)
	    return;

	if (u.width <= 0 || u.height <= 0) {
	    u.x = r.x;
	    u.y = r.y;
	    u.width = r.width;
	    u.height = r.height;
	    return;
	}

	int x1 = Math.min(u.x, r.x);
	int x2 = Math.max(u.x + u.width, r.x + r.width);
	int y1 = Math.min(u.y, r.y);
	int y2 = Math.max(u.y + u.height, r.y + r.height);

	u.x = x1;
	u.y = y1;
	u.width = x2 - x1;
	u.height = y2 - y1;
    }
}

