/*
 * Copyright (c) 2000-2001 Pixware. 
 *
 * Author: Hussein Shafie
 *
 * This file is part of the XMLmind XML Editor project.
 * For conditions of distribution and use, see the accompanying legal.txt file.
 */
package com.xmlmind.xmledit;

import com.xmlmind.xmledit.model.ElementModel;
import com.xmlmind.xmledit.model.TextModel;
import com.xmlmind.xmledit.modeltool.ElementUtil;

public class DefaultViewFactory extends ViewFactory {
    private TreeView.Settings treeViewSettings;
    private WordView.Settings wordViewSettings;
    private CharView.Settings charViewSettings;

    public DefaultViewFactory(DocumentView documentView) {
	this(documentView, new TreeView.Settings(), new WordView.Settings(), 
	     new CharView.Settings());
    }

    public DefaultViewFactory(DocumentView documentView,
			      TreeView.Settings treeViewSettings, 
			      WordView.Settings wordViewSettings, 
			      CharView.Settings charViewSettings) {
	super(documentView);
	this.treeViewSettings = treeViewSettings;
	this.wordViewSettings = wordViewSettings;
	this.charViewSettings = charViewSettings;
    }

    public TreeView.Settings getTreeViewSettings() {
	return treeViewSettings;
    }

    public WordView.Settings getWordViewSettings() {
	return wordViewSettings;
    }

    public CharView.Settings getCharViewSettings() {
	return charViewSettings;
    }

    public boolean isElementViewAttributeDependant(ElementModel element, 
						   String attributeName,
						   ElementView parentView) {
	return (treeViewSettings.showAttributes ||
		attributeName.equals("xml:space"));
    }

    public ElementView createElementView(ElementModel element, 
					 ElementView parentView) {
	return new TreeView(element, treeViewSettings);
    }

    public TextView createTextView(TextModel text, ElementView parentView) {
	boolean preserveSpace = 
	    ElementUtil.hasPreserveSpace(text.getParentElement());

	if (preserveSpace) 
	    return new CharView(text, charViewSettings);
	else
	    return new WordView(text, wordViewSettings);
    }
}
