/*
 * Copyright (c) 2001 Pixware. 
 *
 * Author: Hussein Shafie
 *
 * This file is part of the XMLmind XML Editor project.
 * For conditions of distribution and use, see the accompanying legal.txt file.
 */
package com.xmlmind.xmledit;

import com.xmlmind.gadget.Gadget;

public final class GadgetListImpl implements GadgetList {
    public /*read-only*/ int size = 0;
    public /*read-only*/ Gadget[] list = new Gadget[0];

    private static final int CAPACITY_LIMIT = 100;

    public void appendGadget(Gadget gadget) {
	if (size + 1 > list.length) {
	    int newCapacity = Math.max(10, 2*list.length);
	    Gadget[] newList = new Gadget[newCapacity];

	    if (size > 0)
		System.arraycopy(list, 0, newList, 0, size);

	    list = newList;
	}

	list[size++] = gadget;
    }

    public void appendGadgets(Gadget[] gadgets, int offset, int length) {
	if (size + length > list.length) {
	    int newCapacity = Math.max(size+length, 2*list.length);
	    Gadget[] newList = new Gadget[newCapacity];

	    if (size > 0)
		System.arraycopy(list, 0, newList, 0, size);

	    list = newList;
	}

	System.arraycopy(gadgets, offset, list, size, length);
	size += length;
    }

    public void removeAll() {
	if (size > CAPACITY_LIMIT) 
	    list = new Gadget[CAPACITY_LIMIT];
	size = 0;
    }
}
