/*
 * Copyright (c) 2000-2001 Pixware. 
 *
 * Author: Hussein Shafie
 *
 * This file is part of the XMLmind XML Editor project.
 * For conditions of distribution and use, see the accompanying legal.txt file.
 */
package com.xmlmind.xmledit;

import java.awt.Point;
import java.awt.Insets;
import java.awt.Cursor;
import java.awt.Dimension;
import java.awt.Rectangle;
import java.awt.FontMetrics;
import java.awt.Container;
import java.awt.Component;
import java.awt.event.KeyEvent;
import javax.swing.DefaultFocusManager;
import javax.swing.Scrollable;
import javax.swing.SwingConstants;
import com.xmlmind.gadget.JGadgetPanel;
import com.xmlmind.gadget.RootGadget;
import com.xmlmind.gadget.Gadget;
import com.xmlmind.xmledit.model.DocumentModel;
import com.xmlmind.xmledit.model.SubelementModel;
import com.xmlmind.xmledit.model.ElementModel;
import com.xmlmind.xmledit.model.TextModel;
import com.xmlmind.xmledit.modeltool.TextOffset;
import com.xmlmind.xmledit.modeltool.TextRange;

public class JDocumentPane extends JGadgetPanel implements Scrollable {
    public static final int TEXT_PARENT      = DocumentView.TEXT_PARENT;
    public static final int PARENT_OR_TEXT   = DocumentView.PARENT_OR_TEXT;
    public static final int PARENT           = DocumentView.PARENT;
    public static final int CHILD            = DocumentView.CHILD;
    public static final int CHILD_OR_NONE    = DocumentView.CHILD_OR_NONE;
    public static final int PREVIOUS_SIBLING = DocumentView.PREVIOUS_SIBLING;
    public static final int NEXT_SIBLING     = DocumentView.NEXT_SIBLING;

    public static final int PASTE_BEFORE = DocumentView.PASTE_BEFORE;
    public static final int PASTE_INTO   = DocumentView.PASTE_INTO;
    public static final int PASTE_AFTER  = DocumentView.PASTE_AFTER;

    private int horizScrollUnit, vertScrollUnit;

    public JDocumentPane() {
	setCursor(Cursor.getPredefinedCursor(Cursor.TEXT_CURSOR));
	setAutoscrolls(true);

	FontMetrics metrics = getFontMetrics(getFont());
	horizScrollUnit = metrics.getMaxAdvance();
	vertScrollUnit = metrics.getHeight();
    }

    protected RootGadget createRootGadget() {
	return new DocumentView(this);
    }

    public void setDocument(DocumentModel doc) {
	((DocumentView) root).setDocument(doc);
	root.refresh();
    }

    public DocumentModel getDocument() {
	return ((DocumentView) root).getDocument();
    }

    public ViewFactory getViewFactory() {
	return ((DocumentView) root).getViewFactory();
    }

    public void setEditable(boolean editable) {
	((DocumentView) root).setEditable(editable);
    }

    public boolean isEditable() {
	return ((DocumentView) root).isEditable();
    }

    public void beginAction() {
	((DocumentView) root).beginAction();
    }

    public void endAction() {
	((DocumentView) root).endAction();
    }

    public void selectSubelement(int which) {
	((DocumentView) root).selectSubelement(which);
    }

    public void selectAll() {
	((DocumentView) root).selectAll();
    }

    public void selectText(TextRange range) {
	((DocumentView) root).selectText(range);
    }

    public void selectText(TextOffset markLocation, TextOffset pointLocation) {
	((DocumentView) root).selectText(markLocation, pointLocation);
    }

    public void selectText(TextModel markText, int markOffset,
			   TextModel pointText, int pointOffset) {
	((DocumentView) root).selectText(markText, markOffset,
					 pointText, pointOffset);
    }

    public void selectSubelement(SubelementModel sub) {
	((DocumentView) root).selectSubelement(sub);
    }

    public boolean ensurePointIsVisible() {
	return ((DocumentView) root).ensurePointIsVisible();
    }

    public boolean movePointInto(SubelementModel sub, boolean selectIfNoText) {
	return ((DocumentView) root).movePointInto(sub, selectIfNoText);
    }

    public void cancelSelection() {
	((DocumentView) root).cancelSelection();
    }

    public void addContextChangeListener(ContextChangeListener listener) {
	((DocumentView) root).addContextChangeListener(listener);
    }

    public void removeContextChangeListener(ContextChangeListener listener) {
	((DocumentView) root).removeContextChangeListener(listener);
    }

    public void getContext(ContextCommandInfo info) {
	((DocumentView) root).getContext(info);
    }

    public void getContextCommandInfo(ContextCommandInfo info) {
	((DocumentView) root).getContextCommandInfo(info);
    }

    public void delete() {
	((DocumentView) root).delete();
    }

    public void cut() {
	((DocumentView) root).cut();
    }

    public void copy() {
	((DocumentView) root).copy();
    }

    public void paste() {
	((DocumentView) root).paste();
    }

    public void pasteBefore() {
	((DocumentView) root).pasteBefore();
    }

    public void pasteAfter() {
	((DocumentView) root).pasteAfter();
    }

    public void insert(String elementTypeName) {
	((DocumentView) root).insert(elementTypeName);
    }

    public void insertBefore(String elementTypeName) {
	((DocumentView) root).insertBefore(elementTypeName);
    }

    public void insertAfter(String elementTypeName) {
	((DocumentView) root).insertAfter(elementTypeName);
    }

    public void convert(String elementTypeName) {
	((DocumentView) root).convert(elementTypeName);
    }

    public void split() {
	((DocumentView) root).split();
    }

    public void replace(String elementTypeName) {
	((DocumentView) root).replace(elementTypeName);
    }

    public void join() {
	((DocumentView) root).join();
    }

    public boolean insertAtSelected(boolean text, boolean before) {
	return ((DocumentView) root).insertAtSelected(text, before);
    }

    public boolean splitSelected() {
	return ((DocumentView) root).splitSelected();
    }

    public boolean pasteAtSelected(String content, int where) {
	return ((DocumentView) root).pasteAtSelected(content, where);
    }

    public ElementModel refreshSelected() {
	return ((DocumentView) root).refreshSelected();
    }

    public Caret getCaret() {
	return ((DocumentView) root).getCaret();
    }

    public SubelementSelection getSubelementSelection() {
	return ((DocumentView) root).getSubelementSelection();
    }

    public void refresh() {
	((DocumentView) root).refresh();
    }

    public DocumentView getDocumentView() {
	return (DocumentView) root;
    }

    // -----------------------------------------------------------------------

    public boolean isFocusTraversable() {
	// TAB gives focus to the host.
        return isEnabled();
    }

    public boolean isManagingFocus() {
	// The focus manager must not manage the focus cycle of the children
	// of the host. It'll do that itself.
	return true;
    }

    public static class FocusManager extends DefaultFocusManager {
	public void processKeyEvent(Component focusedComponent, 
				    KeyEvent anEvent) {
	    if(anEvent.getKeyCode() == KeyEvent.VK_TAB || 
	       anEvent.getKeyChar() == '\t') {
		// It is important for JDocumentPane to be able to
		// handle Ctrl+Tab and Ctrl+Shift+Tab too.
		if (focusedComponent instanceof JDocumentPane)
		    return;

		super.processKeyEvent(focusedComponent, anEvent);
	    }
	}
    }

    // -----------------------------------------------------------------------

    public Dimension getPreferredScrollableViewportSize() {
	return getPreferredSize();
    }

    public int getScrollableUnitIncrement(Rectangle visibleRect,
					  int orientation,
					  int direction) {
	if (orientation == SwingConstants.HORIZONTAL)
	    return horizScrollUnit;
	else
	    return vertScrollUnit;
    }

    public int getScrollableBlockIncrement(Rectangle visibleRect,
					   int orientation,
					   int direction) {
	if (orientation == SwingConstants.HORIZONTAL)
	    return visibleRect.width;
	else
	    return visibleRect.height;
    }

    public boolean getScrollableTracksViewportWidth() {
	// Called very often: must be very quick.
	return false;
    }

    public boolean getScrollableTracksViewportHeight() {
	return false;
    }
}
