/*
 * Copyright (c) 2001 Pixware. 
 *
 * Author: Hussein Shafie
 *
 * This file is part of the XMLmind XML Editor project.
 * For conditions of distribution and use, see the accompanying legal.txt file.
 */
package com.xmlmind.xmledit;

import java.awt.Rectangle;
import fr.pixware.util.QuickSort;
// Needed by main()
import java.awt.*;
import java.awt.event.*;
import fr.pixware.util.StringUtil;

public class RectangularEnvelope {
    public static class Points {
	int[] x;
	int[] y;
	int count;
    }

    private RectangleListImpl rectList = new RectangleListImpl();
    private int[] polygonX = new int[0];
    private int[] polygonY = new int[0];

    public static class RectangleCompare implements QuickSort.Compare {
	public int compare(Object o1, Object o2) {
	    return (((Rectangle) o1).y - ((Rectangle) o2).y);
	}
    }
    public static RectangleCompare rectCompare = new RectangleCompare();

    // -----------------------------------------------------------------------

    public void compute(Rectangle[] rectangles, int rectangleCount, 
			Points points) {
	rectList.removeAll();
	makeVerticalStack(rectangles, rectangleCount, rectList);

/*
for (int j = 0; j < rectList.size; ++j)
    System.err.println(rectList.list[j]);
*/

	int pointCount = 4*rectList.size;
	if (pointCount > polygonX.length) {
	    polygonX = new int[Math.max(pointCount, 2*polygonX.length)];
	    polygonY = new int[Math.max(pointCount, 2*polygonX.length)];
	}
	verticalStackEnvelope(rectList.list, rectList.size, 
			      polygonX, polygonY);

	points.x = polygonX;
	points.y = polygonY;
	points.count = pointCount;
    }

    private static final void makeVerticalStack(Rectangle[] rectangles,
						int rectangleCount,
						RectangleListImpl rectList) {
	// Rectangles are just assumed not to intersect with each other.
	// Assumes that rectangles are almost sorted from top to bottom and
	// from left to right.

	if (rectangleCount <= 0)
	    return;
	Rectangle rect = rectangles[0];
	rectList.appendRectangle(rect.x, rect.y, rect.width, rect.height);
	Rectangle line = rectList.list[0];

	for (int i = 1; i < rectangleCount; ++i) {
	    rect = rectangles[i];

	    if ((rect.y >= line.y && rect.y < line.y+line.height)  ||
		(rect.y+rect.height > line.y && 
		 rect.y+rect.height <= line.y+line.height) ||
		(line.y >= rect.y && line.y < rect.y+rect.height) ||
		(line.y+line.height > rect.y && 
		 line.y+line.height <= rect.y+rect.height)) {
		union(line, rect);
	    } else {
		// Line and rect are vertically disjoint: try to find a
		// previously appended line not vertically disjointed from
		// rect.

		line = null;
		int last = rectList.size-1;
		for (int j = 0; j < last; ++j) {
		    Rectangle l = rectList.list[j];
		    if ((rect.y >= l.y && rect.y < l.y+l.height)  ||
			(rect.y+rect.height > l.y && 
			 rect.y+rect.height <= l.y+l.height) ||
			(l.y >= rect.y && l.y < rect.y+rect.height) ||
			(l.y+l.height > rect.y && 
			 l.y+l.height <= rect.y+rect.height)) {
			line = l;
			union(line, rect);
			break;
		    }
		}

		if (line == null) {
		    rectList.appendRectangle(rect.x, rect.y, 
					     rect.width, rect.height);
		    line = rectList.list[rectList.size-1];
		}
	    }
	}

	if (rectList.size > 0)
	    QuickSort.sort(rectList.list, 0, rectList.size-1, rectCompare);
    }

    private static final void union(Rectangle u, Rectangle r) {
	if (r.width <= 0 || r.height <= 0)
	    return;

	if (u.width <= 0 || u.height <= 0) {
	    u.x = r.x;
	    u.y = r.y;
	    u.width = r.width;
	    u.height = r.height;
	    return;
	}

	int x1 = Math.min(u.x, r.x);
	int x2 = Math.max(u.x + u.width, r.x + r.width);
	int y1 = Math.min(u.y, r.y);
	int y2 = Math.max(u.y + u.height, r.y + r.height);

	u.x = x1;
	u.y = y1;
	u.width = x2 - x1;
	u.height = y2 - y1;
    }

    private static final void verticalStackEnvelope(Rectangle[] rectangles,
						    int rectangleCount,
						    int[] polygonX, 
						    int[] polygonY) {
	int left = 0;
	int right = 4*rectangleCount - 1;

	for (int i = 0; i < rectangleCount; ++i) {
	    Rectangle rect = rectangles[i];
	    int x1 = rect.x;
	    int y1 = rect.y;
	    int x2 = rect.x + rect.width - 1;
	    int y2 = rect.y + rect.height - 1;

	    if (i > 0) {
		polygonY[left - 1] = y1;
		polygonY[right + 1] = y1;
	    }

	    polygonX[left] = x1;
	    polygonY[left] = y1;
	    ++left;

	    polygonX[left] = x1;
	    polygonY[left] = y2;
	    ++left;

	    polygonX[right] = x2;
	    polygonY[right] = y1;
	    --right;

	    polygonX[right] = x2;
	    polygonY[right] = y2;
	    --right;
	}
    }

    // -----------------------------------------------------------------------

    public static void main(String[] args) {
	RectangleListImpl rectList = new RectangleListImpl();
	for (int i = 0; i < args.length; ++i) 
	    appendRectangle(rectList, args[i]);

	final Rectangle[] rectangles = rectList.list;
	final int rectangleCount = rectList.size;

	Points points = new Points();
	(new RectangularEnvelope()).compute(rectangles, rectangleCount,
					    points);
	final int[] pointX = points.x;
	final int[] pointY = points.y;
	final int pointCount = points.count;

   	Frame frame = new Frame("TestRectangularEnveloppe");
   	frame.addWindowListener(new WindowAdapter() {
   	    public void windowClosing(WindowEvent e) {
   	        System.exit(0);
   	    }
   	});

	Canvas canvas = new Canvas() {
	    public void paint(Graphics g) {
		g.setColor(Color.gray);
		for (int i = 0; i < rectangleCount; ++i) {
		    Rectangle rect = rectangles[i];
		    g.drawRect(rect.x, rect.y, rect.width-1, rect.height-1);
		}

		g.setColor(Color.red);
		g.drawPolygon(pointX, pointY, pointCount);

		for (int i = 0; i < pointCount; ++i) {
		    int px = pointX[i];
		    int py = pointY[i];
		    g.fillRect(px-1, py-1, 3, 3);
		}
	    }
	};
	canvas.setBackground(Color.white);
	canvas.setSize(500, 500);
   	frame.add(canvas, BorderLayout.CENTER);

   	frame.pack();
   	frame.show();
    }

    private static void appendRectangle(RectangleList rectList, String spec) {
	int[] coords = new int[4];

	String[] split = StringUtil.split(spec, ',');
	if (split.length != 4)
	    throw new IllegalArgumentException(spec);

	for (int i = 0; i < 4; ++i) {
	    try {
		coords[i] = Integer.parseInt(split[i]);
	    } catch (NumberFormatException e) {
		throw new IllegalArgumentException(spec);
	    }

	    if (i >= 2 && coords[i] <= 0)
		throw new IllegalArgumentException(spec);
	}

	rectList.appendRectangle(coords[0], coords[1], coords[2], coords[3]);
    }
}
