/*
 * Copyright (c) 2000-2001 Pixware. 
 *
 * Author: Hussein Shafie
 *
 * This file is part of the XMLmind XML Editor project.
 * For conditions of distribution and use, see the accompanying legal.txt file.
 */
package com.xmlmind.xmledit;

import java.awt.Graphics;
import java.awt.Rectangle;
import com.xmlmind.xmledit.model.DocumentModel;
import com.xmlmind.xmledit.model.SubelementModel;
import com.xmlmind.xmledit.modeltool.SubelementMark;
import com.xmlmind.xmledit.modeltool.SubelementMarkListener;
import com.xmlmind.xmledit.modeltool.SubelementMarkEvent;

public abstract class SubelementSelection implements SubelementMarkListener {
    protected DocumentView docView;
    protected SubelementMark mark;

    protected SubelementSelection(DocumentView documentView) {
	docView = documentView;

	mark = new SubelementMark();
	mark.addSubelementMarkListener(this);
    }

    public DocumentView getDocumentView() {
	return docView;
    }

    public void setDocument(DocumentModel document) {
	mark.setDocument(document);
    }

    public DocumentModel getDocument() {
	return mark.getDocument();
    }

    public boolean setSubelement(SubelementModel sub) {
	return mark.setSubelement(sub);
    }

    public SubelementModel getSubelement() {
	return mark.getSubelement();
    }

    public SubelementMark getMark() {
	return mark;
    }

    public abstract Rectangle refresh();
    public abstract void paint(Graphics g);

    public void subelementMarkMoved(SubelementMarkEvent event) {
	docView.refreshSubelementSelection();

	docView.notifyContextChangeListeners();
    }
}

