/*
 * Copyright (c) 2000-2001 Pixware. 
 *
 * Author: Hussein Shafie
 *
 * This file is part of the XMLmind XML Editor project.
 * For conditions of distribution and use, see the accompanying legal.txt file.
 */
package com.xmlmind.xmledit.model;

public abstract class DocumentEvent implements Cloneable {
    public static final int RESERVED_ID_MAX = 100;

    protected Object source;
    protected int id;

    public DocumentEvent() {}

    public DocumentEvent(Object source, int id) {
	initialize(source, id);
    }

    public void initialize(Object source, int id) {
	this.source = source;
	this.id = id;
    }

    public Object getSource() {
	return source;
    }
    
    public int getId() {
	return id;
    }

    public DocumentEvent duplicate() {
	DocumentEvent shallowCopy;

	try {
	    shallowCopy = (DocumentEvent) super.clone();
	} catch (CloneNotSupportedException cannotHappen) {
	    cannotHappen.printStackTrace();
	    shallowCopy = null;
	}
	
	return shallowCopy;
    }

    public String toString() {
	StringBuffer buffer = new StringBuffer();

	buffer.append(getClass().getName());
	buffer.append("[source=");
	buffer.append(source);
	buffer.append(",id=");
	buffer.append(id);
	buffer.append(']');

	return buffer.toString();
    }
}
