/*
 * Copyright (c) 2000-2001 Pixware. 
 *
 * Author: Hussein Shafie
 *
 * This file is part of the XMLmind XML Editor project.
 * For conditions of distribution and use, see the accompanying legal.txt file.
 */
package com.xmlmind.xmledit.model;

public class ElementAttributeEvent extends DocumentEvent {
    public static final int FIRST = ElementStructureEvent.LAST + 1;
    public static final int LAST  = FIRST + 9;

    public static final int ATTRIBUTE_ADDED   = FIRST + 0;
    public static final int ATTRIBUTE_CHANGED = FIRST + 1;
    public static final int ATTRIBUTE_REMOVED = FIRST + 2;

    private String name;
    private String oldValue;
    private String newValue;

    public ElementAttributeEvent() {}

    public ElementAttributeEvent(Object source, int id, String name, 
				 String oldValue, String newValue) {
	initialize(source, id, name, oldValue, newValue);
    }

    public void initialize(Object source, int id, String name, 
			   String oldValue, String newValue) {
	super.initialize(source, id);
	this.name = name;
	this.oldValue = oldValue;
	this.newValue = newValue;
    }

    public ElementModel getElementSource() {
	return (ElementModel) source;
    }

    public String getName() {
	return name;
    }

    public String getOldValue() {
	return oldValue;
    }

    public String getNewValue() {
	return newValue;
    }

    public String toString() {
	StringBuffer buffer = new StringBuffer();

	buffer.append(getClass().getName());
	buffer.append("[source=");
	buffer.append(source);
	buffer.append(",id=");
	switch (id) {
	case ATTRIBUTE_ADDED:
	    buffer.append("ATTRIBUTE_ADDED");
	    break;
	case ATTRIBUTE_CHANGED:
	    buffer.append("ATTRIBUTE_CHANGED");
	    break;
	case ATTRIBUTE_REMOVED:
	    buffer.append("ATTRIBUTE_REMOVED");
	    break;
	default:
	    buffer.append(id);
	}
	buffer.append(",name=");
	buffer.append(name);
	buffer.append(",oldValue=");
	buffer.append(oldValue);
	buffer.append(",newValue=");
	buffer.append(newValue);
	buffer.append(']');

	return buffer.toString();
    }
}
