/*
 * Copyright (c) 2000-2001 Pixware. 
 *
 * Author: Hussein Shafie
 *
 * This file is part of the XMLmind XML Editor project.
 * For conditions of distribution and use, see the accompanying legal.txt file.
 */
package com.xmlmind.xmledit.model;

public class ElementStructureEvent extends DocumentEvent {
    public static final int FIRST = TextEvent.LAST + 1;
    public static final int LAST  = FIRST + 9;

    public static final int CHILD_ADDED    = FIRST + 0;
    public static final int CHILD_REPLACED = FIRST + 1;
    public static final int CHILD_REMOVED  = FIRST + 2;

    private SubelementModel referenceChild;
    private SubelementModel oldChild;
    private SubelementModel newChild;

    public ElementStructureEvent() {}

    public ElementStructureEvent(Object source, int id, 
				 SubelementModel referenceChild, 
				 SubelementModel oldChild, 
				 SubelementModel newChild) {
	initialize(source, id, referenceChild, oldChild, newChild);
    }

    public void initialize(Object source, int id, 
			   SubelementModel referenceChild, 
			   SubelementModel oldChild, 
			   SubelementModel newChild) {
	super.initialize(source, id);
	this.referenceChild = referenceChild;
	this.oldChild = oldChild;
	this.newChild = newChild;
    }

    public ElementModel getElementSource() {
	return (ElementModel) source;
    }

    public SubelementModel getReferenceChild() {
	return referenceChild;
    }

    public SubelementModel getOldChild() {
	return oldChild;
    }

    public SubelementModel getNewChild() {
	return newChild;
    }

    public String toString() {
	StringBuffer buffer = new StringBuffer();

	buffer.append(getClass().getName());
	buffer.append("[source=");
	buffer.append(source);
	buffer.append(",id=");
	switch (id) {
	case CHILD_ADDED:
	    buffer.append("CHILD_ADDED");
	    break;
	case CHILD_REPLACED:
	    buffer.append("CHILD_REPLACED");
	    break;
	case CHILD_REMOVED:
	    buffer.append("CHILD_REMOVED");
	    break;
	default:
	    buffer.append(id);
	}
	buffer.append(",referenceChild=");
	buffer.append(referenceChild);
	buffer.append(",oldChild=");
	buffer.append(oldChild);
	buffer.append(",newChild=");
	buffer.append(newChild);
	buffer.append(']');

	return buffer.toString();
    }
}
