/*
 * Copyright (c) 2000-2001 Pixware. 
 *
 * Author: Hussein Shafie
 *
 * This file is part of the XMLmind XML Editor project.
 * For conditions of distribution and use, see the accompanying legal.txt file.
 */
package com.xmlmind.xmledit.model;

public class TextEvent extends DocumentEvent {
    public static final int FIRST = 0;
    public static final int LAST  = 9;

    public static final int TEXT_INSERTED = FIRST + 0;
    public static final int TEXT_REPLACED = FIRST + 1;
    public static final int TEXT_DELETED  = FIRST + 2;

    private int offset;
    private String oldString;
    private String newString;

    public TextEvent() {}

    public TextEvent(Object source, int id, int offset, 
		     String oldString, String newString) {
	initialize(source, id, offset, oldString, newString);
    }

    public void initialize(Object source, int id, int offset, 
			   String oldString, String newString) {
	super.initialize(source, id);
	this.offset = offset;
	this.oldString = oldString;
	this.newString = newString;
    }

    public TextModel getTextSource() {
	return (TextModel) source;
    }

    public int getOffset() {
	return offset;
    }

    public String getOldString() {
	return oldString;
    }

    public String getNewString() {
	return newString;
    }

    public String toString() {
	StringBuffer buffer = new StringBuffer();

	buffer.append(getClass().getName());
	buffer.append("[source=");
	buffer.append(source);
	buffer.append(",id=");
	switch (id) {
	case TEXT_INSERTED:
	    buffer.append("TEXT_INSERTED");
	    break;
	case TEXT_REPLACED:
	    buffer.append("TEXT_REPLACED");
	    break;
	case TEXT_DELETED:
	    buffer.append("TEXT_DELETED");
	    break;
	default:
	    buffer.append(id);
	}
	buffer.append(",offset=");
	buffer.append(offset);
	buffer.append(",oldString=");
	if (oldString != null) {
	    buffer.append('\"');
	    buffer.append(oldString);
	    buffer.append('\"');
	}
	buffer.append(",newString=");
	if (newString != null) {
	    buffer.append('\"');
	    buffer.append(newString);
	    buffer.append('\"');
	}
	buffer.append(']');

	return buffer.toString();
    }
}
