/*
 * Copyright (c) 2000-2001 Pixware. 
 *
 * Author: Hussein Shafie
 *
 * This file is part of the XMLmind XML Editor project.
 * For conditions of distribution and use, see the accompanying legal.txt file.
 */
package com.xmlmind.xmledit.modelimpl;

import com.xmlmind.xmledit.model.*;

public class AttributeDefinition implements AttributeDefinitionModel {
    private String name;
    private int type;
    private String[] enumValues;
    private int presence;
    private String defaultValue;

    public AttributeDefinition(String name, int type, String[] enumValues, 
			       int presence, String defaultValue) {
	this.name = name;
	this.type = type;
	this.enumValues = enumValues;
	this.presence = presence;
	this.defaultValue = defaultValue;
    }

    public String getAttributeName() {
	return name;
    }

    public int getAttributeType() {
	return type;
    }

    public String[] getAttributeEnumeratedValues() {
	return enumValues;
    }

    public int getAttributePresence() {
	return presence;
    }

    public String getAttributeDefaultValue() {
	return defaultValue;
    }

    public boolean equals(Object other) {
	if (other == null || !(other instanceof AttributeDefinition))
	    return false;

	AttributeDefinition def = (AttributeDefinition) other;

	if (type != def.type || 
	    presence != def.presence ||
	    !name.equals(def.name))
	    return false;

	if ((defaultValue == null && def.defaultValue != null) ||
	    (defaultValue != null && !defaultValue.equals(def.defaultValue)))
	    return false;

	if ((enumValues == null && def.enumValues != null) ||
	    (enumValues != null && 
	     (def.enumValues == null || 
	      def.enumValues.length != enumValues.length))) 
	    return false;

	if (enumValues != null) {
	    for (int i = 0; i < enumValues.length; ++i) {
		if (!enumValues[i].equals(def.enumValues[i]))
		    return false;
	    }
	}

	return true;
    }

    public int hashCode() {
	return name.hashCode();
    }
}
