/*
 * Copyright (c) 2000-2001 Pixware. 
 *
 * Author: Hussein Shafie
 *
 * This file is part of the XMLmind XML Editor project.
 * For conditions of distribution and use, see the accompanying legal.txt file.
 */
package com.xmlmind.xmledit.modelimpl;

import java.util.Enumeration;
import fr.pixware.util.LinearHashtable;
import com.xmlmind.xmledit.model.*;

public class DocumentType implements DocumentTypeModel {
    private String publicID;
    private String systemID;
    private String internalSubset;
    private String url;
    private LinearHashtable notations = new LinearHashtable();
    private LinearHashtable unparsedEntities = new LinearHashtable();
    private LinearHashtable elementTypes = new LinearHashtable();

    public DocumentType(String publicID, String systemID, 
			String internalSubset, String url) {
	this.publicID = publicID;
	this.systemID = systemID;
	this.internalSubset = internalSubset;
	this.url = url;
    }

    public String getDocumentTypePublicId() {
	return publicID;
    }

    public String getDocumentTypeSystemId() {
	return systemID;
    }

    public String getDocumentTypeInternalSubset() {
	return internalSubset;
    }

    public String getDocumentTypeURL() {
	return url;
    }

    public ElementTypeModel putElementType(ElementTypeModel elementType) {
	return (ElementTypeModel) elementTypes.put(
	    elementType.getElementTypeName(), elementType);
    }

    public ElementTypeModel getElementType(String elementTypeName) {
	return (ElementTypeModel) elementTypes.get(elementTypeName);
    }

    public int getElementTypeCount() {
	return elementTypes.size();
    }

    public Enumeration getElementTypes() {
	return elementTypes.elements();
    }

    public NotationModel putNotation(NotationModel notation) {
	return (NotationModel) notations.put(notation.getNotationName(), 
					     notation);
    }

    public NotationModel getNotation(String notationName) {
	return (NotationModel) notations.get(notationName);
    }

    public int getNotationCount() {
	return notations.size();
    }

    public Enumeration getNotations() {
	return notations.elements();
    }

    public UnparsedEntityModel putUnparsedEntity(
	UnparsedEntityModel unparsedEntity) {
	return (UnparsedEntityModel) unparsedEntities.put(
	    unparsedEntity.getUnparsedEntityName(), unparsedEntity);
    }

    public UnparsedEntityModel getUnparsedEntity(String unparsedEntityName) {
	return (UnparsedEntityModel) unparsedEntities.get(unparsedEntityName);
    }

    public int getUnparsedEntityCount() {
	return unparsedEntities.size();
    }

    public Enumeration getUnparsedEntities() {
	return unparsedEntities.elements();
    }
}
