/*
 * Copyright (c) 2000-2001 Pixware. 
 *
 * Author: Hussein Shafie
 *
 * This file is part of the XMLmind XML Editor project.
 * For conditions of distribution and use, see the accompanying legal.txt file.
 */
package com.xmlmind.xmledit.modelimpl;

import java.util.Enumeration;
import fr.pixware.util.LinearHashtable;
import com.xmlmind.xmledit.model.*;

public class ElementType implements ElementTypeModel {
    private String name;
    private int contentType;
    private Object content;
    private LinearHashtable attributeDefinitions = new LinearHashtable();

    public ElementType(String name, int contentType) {
	this.name = name;
	this.contentType = contentType;
	content = null;
    }

    public String getElementTypeName() {
	return name;
    }

    public int getElementContentType() {
	return contentType;
    }

    public void setMixedElementTypes(ElementTypeModel[] mix) {
	contentType = MIXED;
	content = mix;
    }

    public ElementTypeModel[] getMixedElementTypes() {
	return (contentType == MIXED)? (ElementTypeModel[]) content : null;
    }

    public void setElementContent(ElementContentModel content) {
	contentType = ELEMENT;
	this.content = content;
    }

    public ElementContentModel getElementContent() {
	return (contentType == ELEMENT)? (ElementContentModel) content : null;
    }

    public AttributeDefinitionModel putAttributeDefinition(
	                                    AttributeDefinitionModel attrDef) {
	return (AttributeDefinitionModel) attributeDefinitions.put(
	    attrDef.getAttributeName(), attrDef);
    }

    public AttributeDefinitionModel getAttributeDefinition(String attrName) {
	return (AttributeDefinitionModel) attributeDefinitions.get(attrName);
    }

    public int getAttributeDefinitionCount() {
	return attributeDefinitions.size();
    }

    public Enumeration getAttributeDefinitions() {
	return attributeDefinitions.elements();
    }
}
