/*
 * Copyright (c) 2000-2001 Pixware. 
 *
 * Author: Hussein Shafie
 *
 * This file is part of the XMLmind XML Editor project.
 * For conditions of distribution and use, see the accompanying legal.txt file.
 */
package com.xmlmind.xmledit.modelimpl;

import java.util.Enumeration;
import com.xmlmind.xmledit.model.*;

public abstract class Subelement implements SubelementModel {
    protected int type;
    protected Object[] listenerData;
    protected Element parent;
    protected Subelement previous;
    protected Subelement next;

    public Subelement(int type, int listenerCount) {
	this.type = type;
	if (listenerCount > 0)
	    listenerData = new Object[listenerCount];
    }

    public int getSubelementType() {
	return type;
    }

    public ElementModel getParentElement() {
	return parent;
    }

    public SubelementModel getPreviousSubelement() {
	return previous;
    }

    public SubelementModel getNextSubelement() {
	return next;
    }

    public void setDocumentListenerData(int listenerIndex, Object data) {
	listenerData[listenerIndex] = data;
    }

    public Object getDocumentListenerData(int listenerIndex) {
	return listenerData[listenerIndex];
    }

    public int documentListenerIndex(Object data) {
	for (int i = 0; i < listenerData.length; ++i) {
	    if (listenerData[i] == data)
		return i;
	}
	return -1;
    }

    /*package*/ void setPrevious(Subelement previous) {
	this.previous = previous;
    }

    /*package*/ Subelement getPrevious() {
	return previous;
    }

    /*package*/ void setNext(Subelement next) {
	this.next = next;
    }

    /*package*/ Subelement getNext() {
	return next;
    }

    /*package*/ void setAttached(Element parent, 
				 Subelement previous, Subelement next) {
	this.parent = parent;
	this.previous = previous;
	this.next = next;
    }

    /*package*/ void setDetached() {
	parent = null;
	previous = null;
	next = null;
    }

    /*package*/ boolean isDetached() {
	return (parent == null && next == null && previous == null);
    }

    /*package*/ void listenerAdded() {
	if (listenerData == null) {
	    listenerData = new Object[1];
	} else {
	    Object[] newData = new Object[listenerData.length + 1];
	    System.arraycopy(listenerData, 0, newData, 0, listenerData.length);
	    listenerData = newData;
	}
    }

    /*package*/ void listenerRemoved(int listenerIndex) {
	if (listenerData.length == 1) {
	    listenerData = null;
	} else {
	    Object[] newData = new Object[listenerData.length - 1];

	    if (listenerIndex > 0)
		System.arraycopy(listenerData, 0, newData, 0, listenerIndex);

	    int first = listenerIndex + 1;
	    int tail = listenerData.length - first;
	    if (tail > 0) 
		System.arraycopy(listenerData, first, 
				 newData, listenerIndex, tail);

	    listenerData = newData;
	}
    }
}

