/*
 * Copyright (c) 2000-2001 Pixware. 
 *
 * Author: Hussein Shafie
 *
 * This file is part of the XMLmind XML Editor project.
 * For conditions of distribution and use, see the accompanying legal.txt file.
 */
package com.xmlmind.xmledit.modelimpl;

import com.xmlmind.xmledit.model.*;

public class Text extends Subelement implements TextModel {
    private char[] chars = new char[0];

    public Text(String text, int listenerCount) {
	super(TEXT, listenerCount);
	chars = text.toCharArray();
    }

    public DocumentModel getDocument() {
	return ((parent == null)? null : parent.getDocument());
    }

    public void setText(String text) {
	String oldString = new String(chars);

	chars = text.toCharArray();

	Document document = (Document) getDocument();
	if (document != null)
	    document.textNotification(this, TextEvent.TEXT_REPLACED, 
				      0, oldString, text);
    }

    public void insertText(int offset, String text) {
	int length = chars.length;
	if (offset < 0 || offset > length)
	    throw new IllegalArgumentException("invalid offset");

	int added = text.length();
	if (added == 0)
	    return;

	char[] newChars = new char[length + added];
	if (offset > 0)
	    System.arraycopy(chars, 0, newChars, 0, offset);

	text.getChars(0, added, newChars, offset);

	if (offset < length)
	    System.arraycopy(chars, offset, newChars, offset + added, 
			     length - offset);

	chars = newChars;

	Document document = (Document) getDocument();
	if (document != null)
	    document.textNotification(this, TextEvent.TEXT_INSERTED, 
				      offset, null, text);
    }

    public void appendText(String text) {
	insertText(chars.length, text);
    }

    public void replaceText(int offset, int removed, String text) {
	if (offset < 0)
	    throw new IllegalArgumentException("negative offset");
	int length = chars.length;
	if (removed < 0 || offset + removed > length)
	    throw new IllegalArgumentException("invalid count");

	if (removed == 0)
	    return;
	String removedPart = new String(chars, offset, removed);

	int added = text.length();
	char[] newChars = new char[length - removed + added];
	if (offset > 0)
	    System.arraycopy(chars, 0, newChars, 0, offset);

	if (added > 0) 
	    text.getChars(0, added, newChars, offset);

	int tail = (offset + removed);
	if (tail < length)
	    System.arraycopy(chars, tail, newChars, offset + added,
			     length - tail);

	chars = newChars;

	Document document = (Document) getDocument();
	if (document != null) {
	    if (added > 0) {
		document.textNotification(
		    this, TextEvent.TEXT_REPLACED, offset, removedPart, text);
	    } else {
		document.textNotification(
		    this, TextEvent.TEXT_DELETED, offset, removedPart, null);
	    }
	}
    }

    public void deleteText(int offset, int count) {
	replaceText(offset, count, "");
    }

    public String getText() {
	return new String(chars);
    }

    public char[] getTextChars() {
	return chars;
    }

    public char getTextChar(int offset) {
	return chars[offset];
    }

    public int getTextLength() {
	return chars.length;
    }
}

