/*
 * Copyright (c) 2000-2001 Pixware. 
 *
 * Author: Hussein Shafie
 *
 * This file is part of the XMLmind XML Editor project.
 * For conditions of distribution and use, see the accompanying legal.txt file.
 */

import java.io.*;
import fr.pixware.util.FileUtil;
import com.xmlmind.xmledit.model.DocumentTypeModel;
import com.xmlmind.xmledit.modelimpl.Document;
import com.xmlmind.xmledit.modelimpl.XPDocumentLoader;
import com.xmlmind.xmledit.modeltool.DocumentWriter;
import com.xmlmind.xmledit.modeltool.DocumentTypeWriter;
import com.jclark.xml.parse.NotWellFormedException;

public class TestXPDocumentLoader {
    public static void main(String[] args) {
	String inFileName = null;
	String outFileName = null;
	boolean dtd = false;
	int indent = -1;
	int maxLineLength = -1;

	switch (args.length) {
	case 5:
	    {
		try {
		    maxLineLength = Integer.parseInt(args[4]);
		} catch (NumberFormatException e) {
		    maxLineLength = -1;
		}
		if (maxLineLength <= 0)
		    usage();
	    }
	    /*FALLTHROUGH*/

	case 4:
	    {
		try {
		    indent = Integer.parseInt(args[3]);
		} catch (NumberFormatException e) {
		    indent = -1;
		}
		if (indent < 0)
		    usage();
	    }
	    /*FALLTHROUGH*/

	case 3:
	    dtd = args[2].equals("dtd");
	    /*FALLTHROUGH*/

	case 2:
	    outFileName = args[1];
	    if (outFileName.equals("-"))
		outFileName = null;
	    /*FALLTHROUGH*/

	case 1:
	    inFileName = args[0];
	    break;

	default:
	    usage();
	}

	try {

	    Document document = new Document();
	    XPDocumentLoader loader = new XPDocumentLoader();
	    loader.setGuessingElementContent(true);
	    loader.load(inFileName, document);

	    if (dtd) {
		DocumentTypeModel docType = document.getDocumentType();
		if (docType == null) {
		    System.err.println("'" + inFileName + 
				       "' has no document type");
		    System.exit(2);
		}
		
		if (outFileName == null) 
		    DocumentTypeWriter.writeDocumentType(
			docType, System.out, FileUtil.defaultEncoding(), 
                        /*useURL*/ false);
		else
		    DocumentTypeWriter.writeDocumentType(
			docType, outFileName, /*useURL*/ false);
	    } else {
		if (outFileName == null) 
		    DocumentWriter.writeDocument(
			document, System.out, FileUtil.defaultEncoding(), 
                        /*useURL*/ false, indent, maxLineLength);
		else
		    DocumentWriter.writeDocument(
			document, outFileName, /*useURL*/ false, 
			indent, maxLineLength);
	    }

	} catch (NotWellFormedException e1) {
	    System.err.println("parse error in '" + e1.getEntityLocation() + 
			       "', line " + e1.getLineNumber() +
			       ", column " + e1.getColumnNumber() + 
			       ": " + e1.getMessageWithoutLocation());
	    System.exit(3);
	} catch (Exception e2) {
	    e2.printStackTrace();

	    System.err.print(e2.getClass().getName());
	    String msg = e2.getMessage();
	    if (msg == null)
		System.err.println();
	    else
		System.err.println(": " + msg);
	    System.exit(4);
	}
    }

    private static void usage() {
	System.err.println(
	    "usage: java TestXPDocumentLoader" +
	    " inFileName ?outFileName? ?doc|dtd? ?indent? ?maxLineLength?");
	System.exit(1);
    }
}
