/*
 * Copyright (c) 2000-2001 Pixware. 
 *
 * Author: Hussein Shafie
 *
 * This file is part of the XMLmind XML Editor project.
 * For conditions of distribution and use, see the accompanying legal.txt file.
 */
package com.xmlmind.xmledit.modeltool;

import java.util.Vector;
import com.xmlmind.xmledit.model.*;

public class DocumentChecker implements Traversal.Handler {
    private DocumentModel doc;
    private ElementStructureChecker structChecker;
    private ElementAttributeChecker attrChecker;

    private Vector diagnostics = null;

    // -----------------------------------------------------------------------

    public DocumentChecker() {
	this(null);
    }

    public DocumentChecker(DocumentModel document) {
	structChecker = new ElementStructureChecker();
	attrChecker = new ElementAttributeChecker();
	setDocument(document);
    }

    public void setDocument(DocumentModel document) {
	doc = document;
	structChecker.setDocument(doc);
	attrChecker.setDocument(doc);
    }

    public DocumentModel getDocument() {
	return doc;
    }

    /**
     * <p>If the structure of an element is invalid, its attributes are 
     * not checked and its child elements are not checked at all.
     *
     * <p>If structure or attribute errors are found, cross references
     * (i.e. IDREF and IDREFS attributes matching ID attributes) are not 
     * checked.
     * 
     */
    public ElementCheckerDiagnostic[] check() {
	diagnostics = new Vector();

	Traversal.traverse(doc.getRootElement(), this);

	attrChecker.checkXRef(diagnostics);

	ElementCheckerDiagnostic[] result = 
	    new ElementCheckerDiagnostic[diagnostics.size()];
	diagnostics.copyInto(result);
	diagnostics = null;
	return result;
    }

    // -----------------------------------------------------------------------

    public Object enterElement(ElementModel element) { 
	ElementCheckerDiagnostic d = structChecker.check(element);
	if (d != null)
	    diagnostics.addElement(d);

	attrChecker.check(element, /*xref*/ false, diagnostics);

	return null;
    }

    public Object leaveElement(ElementModel element) { return null; }
    public Object processText(TextModel text) { return null; }
}
