/*
 * Copyright (c) 2001 Pixware. 
 *
 * Author: Hussein Shafie
 *
 * This file is part of the XMLmind XML Editor project.
 * For conditions of distribution and use, see the accompanying legal.txt file.
 */
package com.xmlmind.xmledit.modeltool;

import java.io.Writer;
import java.io.FilterWriter;
import java.io.IOException;

public class LineWriter extends FilterWriter {
    private int lineNumber;
    private int columnNumber;

    public LineWriter(Writer out) {
	super(out);
	lineNumber = columnNumber = 0;
    }

    public int getLineNumber() {
	return lineNumber;
    }

    public int getColumnNumber() {
	return columnNumber;
    }

    public void write(int c) throws IOException {
	out.write(c);

	if (c == '\n') {
	    ++lineNumber;
	    columnNumber = 0;
	} else {
	    ++columnNumber;
	}
    }

    public void write(char[] chars, int offset, int length) 
	throws IOException {
	out.write(chars, offset, length);
	
	int end = offset + length;
	for (int i = offset; i < end; ++i) {
	    if (chars[i] == '\n') {
		++lineNumber;
		columnNumber = 0;
	    } else {
		++columnNumber;
	    }
	}
    }

    public void write(String string, int offset, int length) 
	throws IOException {
	out.write(string, offset, length);
	
	int end = offset + length;
	for (int i = offset; i < end; ++i) {
	    if (string.charAt(i) == '\n') {
		++lineNumber;
		columnNumber = 0;
	    } else {
		++columnNumber;
	    }
	}
    }

    public void flush() throws IOException {
	out.flush();
    }

    public void close() throws IOException {
	out.close();
    }
}
