/*
 * Copyright (c) 2000-2001 Pixware. 
 *
 * Author: Hussein Shafie
 *
 * This file is part of the XMLmind XML Editor project.
 * For conditions of distribution and use, see the accompanying legal.txt file.
 */
package com.xmlmind.xmledit.modeltool;

import java.io.StringWriter;
import java.io.IOException;
import java.util.Enumeration;
import com.xmlmind.xmledit.model.*;

public class SubelementUtil {    
    public static String subelementPath(SubelementModel sub) {
	return subelementPath(sub, '/');
    }

    public static String subelementPath(SubelementModel sub, char separator) {
	StringBuffer path = new StringBuffer();
	boolean addSeparator;
	ElementModel element;

	if (sub.getSubelementType() == SubelementModel.TEXT) {
	    path.append("#PCDATA");
	    addSeparator = true;

	    element = sub.getParentElement();
	} else {
	    addSeparator = false;

	    element = (ElementModel) sub;
	}

	while (element != null) {
	    if (addSeparator)
		path.insert(0, separator);
	    else
		addSeparator = true;
	    path.insert(0, element.getElementTypeName());

	    element = element.getParentElement();
	}

	return path.toString();
    }

    // -----------------------------------------------------------------------

    public static SubelementModel copy(SubelementModel sub) {
	return copy(sub, sub.getDocument());
    }

    public static SubelementModel copy(SubelementModel sub, 
				       DocumentModel doc) {
	if (sub.getSubelementType() == SubelementModel.TEXT) {
	    TextModel src = (TextModel) sub;

	    return doc.createTextModel(src.getText());
	} else {
	    ElementModel src = (ElementModel) sub;
	    ElementModel dst = 
		doc.createElementModel(src.getElementTypeName());

	    // Copy attributes ---

	    Enumeration iter = src.getElementAttributes();
	    while (iter.hasMoreElements()) {
		String[] pair = (String[]) iter.nextElement();

		dst.putElementAttribute(pair[0], pair[1]);
	    }

	    // Copy subelements ---

	    SubelementModel child = src.getFirstSubelement();
	    while (child != null) {
		dst.appendSubelement(SubelementUtil.copy(child, doc));
		
		child = child.getNextSubelement();
	    }

	    return dst;
	}
    }

    // -----------------------------------------------------------------------

    public static String toString(SubelementModel sub) {
	if (sub.getSubelementType() == SubelementModel.TEXT) 
	    return ((TextModel) sub).getText();

	StringWriter writer = new StringWriter();

	try {
	    DocumentWriter.writeXMLDeclaration(null, null, writer);
	    DocumentWriter.writeElement((ElementModel) sub, writer);
	} catch (IOException cannotHappen) {
	    cannotHappen.printStackTrace();
	}

	return writer.toString();
    }
}
