/*
 * Copyright (c) 2000-2001 Pixware. 
 *
 * Author: Hussein Shafie
 *
 * This file is part of the XMLmind XML Editor project.
 * For conditions of distribution and use, see the accompanying legal.txt file.
 */
package com.xmlmind.xmledit.modeltool;

import com.xmlmind.xmledit.model.*;

public class TextLocation {
    private TextLocations manager;
    private Object id;
    private TextModel text = null;
    private int offset = 0;
    private boolean cursor = false;

    public TextLocations getManager() {
	return manager;
    }

    public Object getId() {
	return id;
    }

    public DocumentModel getDocument() {
	return ((manager == null)? null : manager.getDocument());
    }

    public boolean moveToDocumentBegin() {
	DocumentModel doc = getDocument();
	if (doc == null)
	    return false;

	TextModel newText = (TextModel) 
	    Traversal.traverse(doc.getRootElement(), Traversal.textFinder);
	if (newText == null)
	    return false;
	else
	    return moveTo(newText, 0);
    }

    public boolean moveToDocumentEnd() {
	DocumentModel doc = getDocument();
	if (doc == null)
	    return false;

	TextModel newText = (TextModel) 
	    Traversal.traverseBackward(doc.getRootElement(), 
				       Traversal.textFinder);
	if (newText == null)
	    return false;
	else
	    return moveTo(newText, newText.getTextLength());
    }

    public boolean moveToPreviousElement() {
	if (text == null)
	    return false;

	TextModel newText = (TextModel) 
	    Traversal.traverseBefore(text.getParentElement(), 
				     Traversal.textFinder);
	if (newText == null) {
	    return false;
	} else {
	    newText = (TextModel) 
		Traversal.traverse(newText.getParentElement(), 
				   Traversal.textFinder);
	    if (newText == null)
		return false;
	    else
		return moveTo(newText, 0);
	}
    }

    public boolean moveToNextElement() {
	if (text == null)
	    return false;

	TextModel newText = (TextModel) 
	    Traversal.traverseAfter(text.getParentElement(), 
				    Traversal.textFinder);
	if (newText == null)
	    return false;
	else
	    return moveTo(newText, 0);
    }

    public boolean moveToElementBegin() {
	if (text == null)
	    return false;

	TextModel newText = (TextModel) 
	    Traversal.traverse(text.getParentElement(), 
			       Traversal.textFinder);
	if (newText == null)
	    return false;
	else
	    return moveTo(newText, 0);
    }

    public boolean moveToElementEnd() {
	if (text == null)
	    return false;

	TextModel newText = (TextModel) 
	    Traversal.traverseBackward(text.getParentElement(), 
				       Traversal.textFinder);
	if (newText == null)
	    return false;
	else
	    return moveTo(newText, newText.getTextLength());
    }

    public boolean moveToPreviousText() {
	return moveToPreviousText(/*end*/ false);
    }

    private boolean moveToPreviousText(boolean end) {
	if (text == null)
	    return false;

	TextModel newText = (TextModel) 
	    Traversal.traverseBefore(text, Traversal.textFinder);
	if (newText == null)
	    return false;
	else
	    return moveTo(newText, (end? newText.getTextLength() : 0));
    }

    public boolean moveToNextText() {
	if (text == null)
	    return false;

	TextModel newText = (TextModel) 
	    Traversal.traverseAfter(text, Traversal.textFinder);
	if (newText == null)
	    return false;
	else
	    return moveTo(newText, 0);
    }

    public boolean moveToTextBegin() {
	if (text == null)
	    return false;

	if (offset == 0)
	    return false;
	else
	   return moveTo(text, 0); 
    }

    public boolean moveToTextEnd() {
	if (text == null)
	    return false;

	int end = text.getTextLength();
	if (offset == end)
	    return false;
	else
	    return moveTo(text, end);
    }

    public boolean moveToPreviousChar() {
	if (text == null)
	    return false;

	if (offset == 0)
	    return moveToPreviousText(/*end*/ true);
	else
	    return moveTo(text, offset - 1);
    }

    public boolean moveToNextChar() {
	if (text == null)
	    return false;

	if (offset == text.getTextLength()) 
	    return moveToNextText();
	else
	    return moveTo(text, offset + 1);
    }

    public boolean moveToPreviousWord() {
	if (text == null)
	    return false;

	TextModel newText = text;
	int newOffset = offset;
	char[] chars = newText.getTextChars();

	// Skip current word ---

	int charCount = newText.getTextLength();
	if (newOffset >= charCount) {
	    newOffset = charCount-1;
	} else {
	    while (newOffset >= 0 && !isXMLSpace(chars[newOffset]))
		--newOffset;
	}

	// Skip space and empty texts across elements ---

        loop: for (;;) {
	    while (newOffset >= 0) {
		if (!isXMLSpace(chars[newOffset]))
		    break loop;
		--newOffset;
	    }

	    while (newOffset < 0) {
		newText = (TextModel) 
		    Traversal.traverseBefore(newText, 
					     Traversal.textFinder);
		if (newText == null)
		    return false;

		newOffset = newText.getTextLength() - 1;
		chars = newText.getTextChars();
	    }
	}

	// Go to beginning of word ---

	while (newOffset >= 0 && !isXMLSpace(chars[newOffset]))
	    --newOffset;

	return moveTo(newText, newOffset + 1);
    }

    public boolean moveToNextWord() {
	if (text == null)
	    return false;

	TextModel newText = text;
	int newOffset = offset;
	char[] chars = newText.getTextChars();
	int charCount = newText.getTextLength();

	// Skip current word ---

	while (newOffset < charCount && !isXMLSpace(chars[newOffset]))
	    ++newOffset;

	// Skip space and empty texts across elements ---

        loop: for (;;) {
	    while (newOffset < charCount) {
		if (!isXMLSpace(chars[newOffset]))
		    break loop;
		++newOffset;
	    }

	    while (newOffset >= charCount) {
		newText = (TextModel) 
		    Traversal.traverseAfter(newText, 
					    Traversal.textFinder);
		if (newText == null)
		    return false;

		chars = newText.getTextChars();
		charCount = newText.getTextLength();
		newOffset = 0;
	    }
	}

	return moveTo(newText, newOffset);
    }

    public boolean moveToWordBegin() {
	if (text == null)
	    return false;

	char[] chars = text.getTextChars();
	int charCount = text.getTextLength();

	int i = offset;

	// Skip space at the end of the word.
	if (i >= charCount)
	    i = charCount - 1;
	while (i >= 0 && isXMLSpace(chars[i]))
	    --i;
	if (i < 0)
	    return false;

	int first = -1;
	while (i >= 0) {
	    if (isXMLSpace(chars[i]))
		break;

	    first = i;
	    --i;
	}
	if (first < 0)
	    return false;

	return moveTo(text, first);
    }

    public boolean moveToWordEnd() {
	if (text == null)
	    return false;

	char[] chars = text.getTextChars();
	int charCount = text.getTextLength();

	int i = offset;

	// Skip space at the end of the word.
	if (i >= charCount)
	    i = charCount - 1;
	while (i >= 0 && isXMLSpace(chars[i]))
	    --i;
	if (i < 0)
	    return false;

	int last = -1;
	while (i < charCount) {
	    if (isXMLSpace(chars[i]))
		break;

	    last = i;
	    ++i;
	}
	if (last < 0)
	    return false;

	return moveTo(text, last+1);
    }

    private static final boolean isXMLSpace(char c) {
	switch (c) {
	case ' ': case '\n': case '\r': case '\t':
	    return true;
	default:
	    return false;
	}
    }

    public boolean moveTo(TextModel text, int offset) {
	int end = (text == null)? 0 : text.getTextLength();
	if (offset < 0)
	    offset = 0;
	else if (offset > end)
	    offset = end;

	if (text == this.text && offset == this.offset) 
	    return false;

	TextModel prevText = this.text;
	int prevOffset = this.offset;

	this.text = text;
	this.offset = offset;

	if (manager != null)
	    manager.notifyTextLocationListeners(
		this, TextLocationEvent.LOCATION_MOVED, 
		prevText, prevOffset);

	return true;
    }

    public TextModel getText() {
	return text;
    }

    public int getOffset() {
	return offset;
    }

    public void setCursor(boolean cursor) {
	if (cursor != this.cursor) {
	    this.cursor = cursor;

	    if (cursor && text == null) 
		moveToDocumentBegin();
	}
    }

    public boolean isCursor() {
	return cursor;
    }

    // -----------------------------------------------------------------------

    /*package*/ TextLocation(TextLocations manager, Object id) {
	this.manager = manager;
	this.id = id;
    }

    /*package*/ void unsetManager() {
	manager = null;
    }
}

