/*
 * Copyright (c) 2000-2001 Pixware. 
 *
 * Author: Hussein Shafie
 *
 * This file is part of the XMLmind XML Editor project.
 * For conditions of distribution and use, see the accompanying legal.txt file.
 */
package com.xmlmind.xmledit.modeltool;

import com.xmlmind.xmledit.model.TextModel;

public final class TextRangeList {
    public /*read-only*/ int size = 0;
    public /*read-only*/ TextRange[] list = new TextRange[0];

    private static final int CAPACITY_LIMIT = 100;

    public void append(TextModel text, int offset, int count) {
	if (size + 1 > list.length) {
	    int newCapacity = Math.max(10, 2*list.length);
	    TextRange[] newList = new TextRange[newCapacity];

	    if (size > 0)
		System.arraycopy(list, 0, newList, 0, size);

	    for (int i = size; i < newCapacity; ++i)
		newList[i] = new TextRange();

	    list = newList;
	}

	TextRange last = list[size++];
	last.text = text;
	last.offset = offset;
	last.count = count;
    }

    public void removeAll() {
	if (size > CAPACITY_LIMIT) {
	    TextRange[] newList = new TextRange[CAPACITY_LIMIT];
	    System.arraycopy(list, 0, newList, 0, CAPACITY_LIMIT);
	    list = newList;
	}
	size = 0;
    }
}
