/*
 * Copyright (c) 2001 Pixware. 
 *
 * Author: Hussein Shafie
 *
 * This file is part of the XMLmind XML Editor project.
 * For conditions of distribution and use, see the accompanying legal.txt file.
 */
package com.xmlmind.xmledit.modeltool;

import java.util.Hashtable;

public class XMLUtil {
    public static boolean isNmtoken(String s) {
	int count;
	if (s == null || (count = s.length()) == 0)
	    return false;

	for (int i = 0; i < count; ++i) {
	    if (!isNameChar(s.charAt(i)))
		return false;
	}

	return true;
    }

    public static boolean isName(String s) {
	int count;
	if (s == null || (count = s.length()) == 0)
	    return false;

	char c = s.charAt(0);
	switch (c) {
	case '_': case ':':
	    break;
	default:
	    if (!Character.isLetter(c))
		return false;
	}

	for (int i = 1; i < count; ++i) {
	    if (!isNameChar(s.charAt(i)))
		return false;
	}

	return true;
    }

    private static final boolean isNameChar(char c) {
	switch (c) {
	case '.': case '-': case '_': case ':':
	    break;

	case 0x05BF: case 0x05C4: case 0x0670: case 0x093C: case 0x094D: 
	case 0x09BC: case 0x09BE: case 0x09BF: case 0x09D7: case 0x0A02: 
	case 0x0A3C: case 0x0A3E: case 0x0A3F: case 0x0ABC: case 0x0B3C: 
	case 0x0BD7: case 0x0D57: case 0x0E31: case 0x0EB1: case 0x0F35: 
	case 0x0F37: case 0x0F39: case 0x0F3E: case 0x0F3F: case 0x0F97: 
	case 0x0FB9: case 0x20E1: case 0x3099: case 0x309A:
	    // CombiningChar.
	    break;

	case 0x00B7: case 0x02D0: case 0x02D1: case 0x0387: case 0x0640: 
	case 0x0E46: case 0x0EC6: case 0x3005:
	    // Extender.
	    break;

	default:
	    if (Character.isLetterOrDigit(c)) 
		break;

	    if ((c >= 0x0300 && c <= 0x0345) ||
		(c >= 0x0360 && c <= 0x0361) ||
		(c >= 0x0483 && c <= 0x0486) ||
		(c >= 0x0591 && c <= 0x05A1) ||
		(c >= 0x05A3 && c <= 0x05B9) ||
		(c >= 0x05BB && c <= 0x05BD) ||
		(c >= 0x05C1 && c <= 0x05C2) ||
		(c >= 0x064B && c <= 0x0652) ||
		(c >= 0x06D6 && c <= 0x06DC) ||
		(c >= 0x06DD && c <= 0x06DF) ||
		(c >= 0x06E0 && c <= 0x06E4) ||
		(c >= 0x06E7 && c <= 0x06E8) ||
		(c >= 0x06EA && c <= 0x06ED) ||
		(c >= 0x0901 && c <= 0x0903) ||
		(c >= 0x093E && c <= 0x094C) ||
		(c >= 0x0951 && c <= 0x0954) ||
		(c >= 0x0962 && c <= 0x0963) ||
		(c >= 0x0981 && c <= 0x0983) ||
		(c >= 0x09C0 && c <= 0x09C4) ||
		(c >= 0x09C7 && c <= 0x09C8) ||
		(c >= 0x09CB && c <= 0x09CD) ||
		(c >= 0x09E2 && c <= 0x09E3) ||
		(c >= 0x0A40 && c <= 0x0A42) ||
		(c >= 0x0A47 && c <= 0x0A48) ||
		(c >= 0x0A4B && c <= 0x0A4D) ||
		(c >= 0x0A70 && c <= 0x0A71) ||
		(c >= 0x0A81 && c <= 0x0A83) ||
		(c >= 0x0ABE && c <= 0x0AC5) ||
		(c >= 0x0AC7 && c <= 0x0AC9) ||
		(c >= 0x0ACB && c <= 0x0ACD) ||
		(c >= 0x0B01 && c <= 0x0B03) ||
		(c >= 0x0B3E && c <= 0x0B43) ||
		(c >= 0x0B47 && c <= 0x0B48) ||
		(c >= 0x0B4B && c <= 0x0B4D) ||
		(c >= 0x0B56 && c <= 0x0B57) ||
		(c >= 0x0B82 && c <= 0x0B83) ||
		(c >= 0x0BBE && c <= 0x0BC2) ||
		(c >= 0x0BC6 && c <= 0x0BC8) ||
		(c >= 0x0BCA && c <= 0x0BCD) ||
		(c >= 0x0C01 && c <= 0x0C03) ||
		(c >= 0x0C3E && c <= 0x0C44) ||
		(c >= 0x0C46 && c <= 0x0C48) ||
		(c >= 0x0C4A && c <= 0x0C4D) ||
		(c >= 0x0C55 && c <= 0x0C56) ||
		(c >= 0x0C82 && c <= 0x0C83) ||
		(c >= 0x0CBE && c <= 0x0CC4) ||
		(c >= 0x0CC6 && c <= 0x0CC8) ||
		(c >= 0x0CCA && c <= 0x0CCD) ||
		(c >= 0x0CD5 && c <= 0x0CD6) ||
		(c >= 0x0D02 && c <= 0x0D03) ||
		(c >= 0x0D3E && c <= 0x0D43) ||
		(c >= 0x0D46 && c <= 0x0D48) ||
		(c >= 0x0D4A && c <= 0x0D4D) ||
		(c >= 0x0E34 && c <= 0x0E3A) ||
		(c >= 0x0E47 && c <= 0x0E4E) ||
		(c >= 0x0EB4 && c <= 0x0EB9) ||
		(c >= 0x0EBB && c <= 0x0EBC) ||
		(c >= 0x0EC8 && c <= 0x0ECD) ||
		(c >= 0x0F18 && c <= 0x0F19) ||
		(c >= 0x0F71 && c <= 0x0F84) ||
		(c >= 0x0F86 && c <= 0x0F8B) ||
		(c >= 0x0F90 && c <= 0x0F95) ||
		(c >= 0x0F99 && c <= 0x0FAD) ||
		(c >= 0x0FB1 && c <= 0x0FB7) ||
		(c >= 0x20D0 && c <= 0x20DC) ||
		(c >= 0x302A && c <= 0x302F))
		// CombiningChar
		break;

	    if ((c >= 0x3031 && c <= 0x3035) ||
		(c >= 0x309D && c <= 0x309E) || 
		(c >= 0x30FC && c <= 0x30FE))
		// Extender.
		break;

	    return false;
	}

	return true;
    }

    public static final boolean isXMLSpace(char c) {
	switch (c) {
	case ' ': case '\n': case '\r': case '\t':
	    return true;
	default:
	    return false;
	}
    }

    // -----------------------------------------------------------------------

    public static String normalizeAttributeValue(String value) {
	// No need to convert "\r\n" to a single '\n' because white spaces
	// are compressed.

	StringBuffer buffer = new StringBuffer();

	int length = value.length();
	char prevChar = '?';
	for (int i = 0; i < length; ++i) {
	    char c = value.charAt(i);

	    switch (c) {
	    case '\t': case '\r': case '\n':
		c = ' ';
		break;
	    }

	    if (c == ' ') {
		if (prevChar != ' ') {
		    buffer.append(c);
		    prevChar = c;
		}
	    } else {
		buffer.append(c);
		prevChar = c;
	    }
	}

	String normalized = buffer.toString();
	length = normalized.length();
	if (length > 0 && 
	    (normalized.charAt(length-1) == ' ' || 
	     normalized.charAt(0) == ' '))
	    return normalized.trim();
	else
	    return normalized;
    }

    public static String normalizeAttributeStringValue(String value) {
	StringBuffer buffer = new StringBuffer();

	int length = value.length();
	char prevChar = '?';
	for (int i = 0; i < length; ++i) {
	    char c = value.charAt(i);

	    switch (c) {
	    case '\t': case '\r': 
		buffer.append(' ');
		break;
	    case '\n':
		// Equivalent to converting "\r\n" to a single '\n' then
		// converting '\n' to ' '.
		if (prevChar != '\r')
		    buffer.append(' ');
		break;
	    default:
		buffer.append(c);
	    }

	    prevChar = c;
	}

	return buffer.toString();
    }

    // -----------------------------------------------------------------------

    public static String xml(String string) {
	StringBuffer escaped = new StringBuffer();
	escapeXML(string, escaped);
	return escaped.toString();
    }

    public static String qxml(String string) {
	StringBuffer quoted = new StringBuffer();
	quoted.append('\"');
	escapeXML(string, quoted);
	quoted.append('\"');
	return quoted.toString();
    }

    public static void escapeXML(String string, StringBuffer escaped) {
	char[] chars = string.toCharArray();
	escapeXML(chars, 0, chars.length, escaped);
    }

    public static void escapeXML(char[] chars, int offset, int length, 
				 StringBuffer escaped) {
	int end = offset + length;
	for (int i = offset; i < end; ++i) {
	    char c = chars[i];
	    switch (c) {
	    case '\'':
		escaped.append("&#39;");
		break;
	    case '\"':
		escaped.append("&#34;");
		break;
	    case '<':
		escaped.append("&#60;");
		break;
	    case '>':
		escaped.append("&#62;");
		break;
	    case '&':
		escaped.append("&#38;");
		break;
	    case 0x00A0:
		// &nbsp;
		escaped.append("&#160;");
		break;
	    default:
		escaped.append(c);
	    }
	}
    }

    // -----------------------------------------------------------------------

    public static String unescapeXML(String text) {
	StringBuffer unescaped = new StringBuffer();
	unescapeXML(text, 0, text.length(), unescaped);
	return unescaped.toString();
    }

    public static void unescapeXML(String text, int offset, int length,
				   StringBuffer unescaped) {
	int end = offset + length;

	for (int i = offset; i < end; ++i) {
	    char c = text.charAt(i);

	    if (c == '&') {
		StringBuffer charRef = new StringBuffer();

		++i;
		while (i < end) {
		    c = text.charAt(i);
		    if (c == ';')
			break;
		    charRef.append(c);
		    ++i;
		}

		c = parseCharRef(charRef.toString());
	    } 

	    unescaped.append(c);
	}
    }

    private static char parseCharRef(String charRef) {
	if (charRef.length() >= 2 && charRef.charAt(0) == '#') {
	    int i;

	    try {
		if (charRef.charAt(1) == 'x')
		    i = Integer.parseInt(charRef.substring(2), 16);
		else
		    i = Integer.parseInt(charRef.substring(1));
	    } catch (NumberFormatException e) {
		i = - 1;
	    }

	    if (i < 0 || i > Character.MAX_VALUE)
		return '?';
	    else
		return (char) i;
	} if (charRef.equals("amp")) {
	    return '&';
	} if (charRef.equals("apos")) {
	    return '\'';
	} if (charRef.equals("quot")) {
	    return '\"';
	} if (charRef.equals("lt")) {
	    return '<';
	} if (charRef.equals("gt")) {
	    return '>';
	} else {
	    return '?';
	}
    }

    // -----------------------------------------------------------------------

    // Add more: see IANA at http://ds.internic.net/rfc/rfc1700.txt.
    // Names for character encodings are case-insensitive.

    public static final String[] javaToIANA = {
	"ASCII", "US-ASCII",
	"ISO8859_1", "ISO-8859-1",
	"ISO8859_2", "ISO-8859-2",
	"ISO8859_3", "ISO-8859-3",
	"ISO8859_4", "ISO-8859-4",
	"ISO8859_5", "ISO-8859-5",
	"ISO8859_6", "ISO-8859-6",
	"ISO8859_7", "ISO-8859-7",
	"ISO8859_8", "ISO-8859-8",
	"ISO8859_9", "ISO-8859-9",
	"ISO8859_13", "ISO-8859-13",
	"ISO8859_15_FDIS", "ISO-8859-15",
	"Cp1250", "Windows-1250", // Windows Central European
	"Cp1251", "Windows-1251", // Windows Cyrillic
	"Cp1252", "Windows-1252", // Windows Latin-1 
	"Cp1253", "Windows-1253", // Windows Greek
	"MacRoman", "x-mac-roman",       // Netscape 3.0 and above on Mac
	"MacRoman", "macintosh",         // IANA registered
	"MacTurkish", "x-mac-turkish",   // NS3
	"MacCentralEurope", "x-mac-ce",  // NS3
	"MacCyrillic", "x-mac-cyrillic", // NS3
	"MacGreek", "x-mac-greek",       // NS3
	"MacArabic", "x-mac-arabic",
	"MacCroatian", "x-mac-croatian",
	"MacHebrew", "x-mac-hebrew",
	"MacIceland", "x-mac-iceland",
	"MacRomania", "x-mac-romania",
	"MacThai", "x-mac-thai",
	"MacUkraine", "x-mac-ukraine",
	"SJIS", "Shift_JIS",
	"UTF8", "UTF-8"
    };

    private static Hashtable javaToIANAMap = new Hashtable();
    private static Hashtable ianaToJavaMap = new Hashtable();
    static {
	for (int i = 0; i < javaToIANA.length; i += 2) 
	    javaToIANAMap.put(javaToIANA[i].toLowerCase(), javaToIANA[i+1]);
	for (int i = 0; i < javaToIANA.length; i += 2) 
	    ianaToJavaMap.put(javaToIANA[i+1].toLowerCase(), javaToIANA[i]);
    }

    public static String javaToIANAEncoding(String encoding) {
	return (String) javaToIANAMap.get(encoding.toLowerCase());
    }

    public static String ianaToJavaEncoding(String encoding) {
	return (String) ianaToJavaMap.get(encoding.toLowerCase());
    }
}
  
