/*
 * Compile using command:
 *
 * javac -classpath /usr/local/src/jaxp-1.1/jaxp.jar:/usr/local/src/jaxp-1.1/crimson.jar:.:$CLASSPATH JAXPValidator.java
 *
 * Run using command:
 *
 * java -classpath /usr/local/src/jaxp-1.1/jaxp.jar:/usr/local/src/jaxp-1.1/crimson.jar:.:$CLASSPATH JAXPValidator tany.xml
 */

import java.io.*;
import javax.xml.parsers.*;
import org.xml.sax.*;
import org.xml.sax.helpers.*;

public class JAXPValidator extends DefaultHandler {
    public void warning(SAXParseException e) throws SAXException {
	System.err.println(e.getSystemId() + ", line " + e.getLineNumber() + 
			   ", col. " + e.getColumnNumber() + ": warning: " + 
			   e.getMessage());
    }

    public void error(SAXParseException e) throws SAXException {
	System.err.println(e.getSystemId() + ", line " + e.getLineNumber() + 
			   ", col. " + e.getColumnNumber() + ": error: " + 
			   e.getMessage());
    }

    public void fatalError(SAXParseException e) throws SAXException {
	System.err.println(e.getSystemId() + ", line " + e.getLineNumber() + 
			   ", col. " + e.getColumnNumber() + ": fatal: " + 
			   e.getMessage());
    }

    public static void main(String[] args) throws Exception {
	File input = null;

	if (args.length != 1 || 
	    !(input = new File(args[0])).isFile()) {
	    System.err.println("usage: java JAXPValidator xml_file");
	    System.exit(1);
	}

	SAXParserFactory factory = SAXParserFactory.newInstance();
	factory.setValidating(true);

	SAXParser parser = factory.newSAXParser();
	JAXPValidator validator = new JAXPValidator();
	parser.parse(input, validator);
    }
}
