/*
 * Copyright (c) 2001-2002 Pixware. 
 *
 * Author: Hussein Shafie
 *
 * This file is part of the XMLmind XML Editor project.
 * For conditions of distribution and use, see the accompanying legal.txt file.
 */

import fr.pixware.util.*;
import com.xmlmind.xmledit.model.*;
import com.xmlmind.xmledit.modeltool.*;
import com.xmlmind.xmledit.modelimpl.*;

public class TestCharSequence {
    public static void main(String[] args) throws Exception {
	if (args.length < 2) {
	    System.err.println("java TestCharSequence xml_file text_file" + 
			       " ?searched1 ... searchedN?");
	    System.exit(1);
	}

	XPDocumentLoader loader = new XPDocumentLoader();
	Document document = new Document();
	loader.load(args[0], document);

	ElementCharSequence chars = 
	    new ElementCharSequence(document.getRootElement());
	String chars2 = chars.toString();

	FileUtil.saveString(chars2, args[1]);

	check(chars.length() == chars2.length(), 
	       "chars.length==chars2.length");

	int charCount = chars.length();
	for (int i = 0; i < charCount; ++i) {
	    char c = chars.charAt(i);
	    check(c == chars2.charAt(i),
		   "chars.charAt(" + i + ") == chars2.charAt(" + i + ")");

	    TextOffset textOffset = chars.getTextOffset(i);
	    if (textOffset.offset < textOffset.text.getTextLength()) {
		char c2 = textOffset.text.getTextChar(textOffset.offset);
		switch (c2) {
		case '?': 
		case '\n':
		    break;
		default:
		    check(c2 == c, "at index " + i + ": " + c2 + " == " + c);
		}
	    }
	}

	for (int i = 2; i < args.length; ++i) {
	    String searched = args[i];
	    System.out.println(searched);

	    System.out.print("\tindexOf: ");
	    int pos = CharSequenceUtil.indexOf(chars, searched);
	    if (pos < 0)
		System.out.println("NOT FOUND");
	    else
		System.out.println(chars.getTextOffset(pos));
		
	    System.out.print("\tlastIndexOf: ");
	    pos = CharSequenceUtil.lastIndexOf(chars, searched);
	    if (pos < 0)
		System.out.println("NOT FOUND");
	    else
		System.out.println(chars.getTextOffset(pos));
	}
    }

    private static void check(boolean condition, String description) {
	if (!condition) {
	    System.err.println("assertion failed: " + description);
	    System.exit(2);
	}
    }
}
