/*
 * Copyright (c) 2000-2001 Pixware. 
 *
 * Author: Hussein Shafie
 *
 * This file is part of the XMLmind XML Editor project.
 * For conditions of distribution and use, see the accompanying legal.txt file.
 */

import java.util.Vector;
import com.xmlmind.xmledit.model.TextModel;
import com.xmlmind.xmledit.model.ElementModel;
import com.xmlmind.xmledit.modelimpl.Document;
import com.xmlmind.xmledit.modelimpl.XPDocumentLoader;
import com.xmlmind.xmledit.modeltool.Traversal;

public class TestTraversal {
    public static class Tester extends Traversal.HandlerBase {
	private Vector traversed = new Vector();

	public void begin() {
	    traversed.removeAllElements();
	}

	public void end(String[] expected) {
	    if (traversed.size() != expected.length) {
		printTraversed(traversed);
		printExpected(expected);
		System.exit(3);
	    }

	    for (int i = 0; i < expected.length; ++i) {
		if (!((String) traversed.elementAt(i)).equals(expected[i])) {
		    printTraversed(traversed);
		    printExpected(expected);
		    System.exit(4);
		}
	    }

	    traversed.removeAllElements();
	}

	private static void printTraversed(Vector traversed) {
	    System.out.print("Traversed: ");
	    int count = traversed.size();
	    for (int i = 0; i < count; ++i) {
		System.out.print(traversed.elementAt(i));
		System.out.print(' ');
	    }
	    System.out.println();
	}

	private static void printExpected(String[] expected) {
	    System.out.print("Expected: ");
	    for (int i = 0; i < expected.length; ++i) {
		System.out.print(expected[i]);
		System.out.print(' ');
	    }
	    System.out.println();
	}

	public Object enterElement(ElementModel element) {
	    traversed.addElement(element.getElementTypeName());

	    return null;
	}
    }

    // -----------------------------------------------------------------------

    private static class Finder extends Traversal.HandlerBase {
	private String searched;

	public ElementModel find(Document document, String searched) {
	    this.searched = searched;
	    return (ElementModel) Traversal.traverse(document.getRootElement(),
						     this);
	}

	public Object enterElement(ElementModel element) {
	    if (element.getElementTypeName().equals(searched))
		return element;
	    else
		return null;
	}
    }

    // -----------------------------------------------------------------------

    private static final String[] expected1 = {
	"a","b","c","d","e","f","g","h","i","j","k","l","m","n","o","p","q"
    };

    private static final String[] expected2 = {
	"a","m","o","q","p","n","l","i","k","j","b","f","h","g","c","e","d"
    };

    private static final String[] expected3 = {
	"j","k","l","m","n","o","p","q"
    };

    private static final String[] expected4 = {
	"j","b","f","h","g","c","e","d"
    };

    private static final String[] expected5 = {
	"k","l","m","n","o","p","q"
    };

    private static final String[] expected6 = {
	"b","f","h","g","c","e","d"
    };

    // -----------------------------------------------------------------------

    public static void main(String[] args) {
	
	Document document = new Document();

	try {
	    (new XPDocumentLoader()).load("in/TestTraversal.xml", document);

	    Tester tester = new Tester();
	    tester.begin();
	    Traversal.traverse(document.getRootElement(), tester);
	    tester.end(expected1);

	    tester.begin();
	    Traversal.traverseBackward(document.getRootElement(), tester);
	    tester.end(expected2);

	    Finder finder = new Finder();
	    ElementModel from = finder.find(document, "j");

	    tester.begin();
	    Traversal.traverseFrom(from, tester);
	    tester.end(expected3);

	    tester.begin();
	    Traversal.traverseBackwardFrom(from, tester);
	    tester.end(expected4);

	    tester.begin();
	    Traversal.traverseAfter(from, tester);
	    tester.end(expected5);

	    tester.begin();
	    Traversal.traverseBefore(from, tester);
	    tester.end(expected6);

	} catch (Exception e) {
	    e.printStackTrace();
	    System.exit(2);
	}
    }
}
