/*
 * Copyright (c) 2000-2001 Pixware. 
 *
 * Author: Hussein Shafie
 *
 * This file is part of the XMLmind XML Editor project.
 * For conditions of distribution and use, see the accompanying legal.txt file.
 */
package com.xmlmind.xmledit.styledgadget;

import java.awt.Graphics;
import java.awt.Dimension;
import com.xmlmind.gadget.*;

public abstract class ContainerBox extends GadgetContainer implements Styled {
    protected Style style;

    // -----------------------------------------------------------------------

    protected ContainerBox() {
	this(Box.DEFAULT_STYLE);
    }

    protected ContainerBox(Style style) {
	this.style = style;
    }

    public void setStyle(Style style) {
	this.style = style;
    }

    public Style getStyle() {
	return style;
    }

    public void layout(int constrainedWidth, int constrainedHeight,
		       boolean recursive) {
	int x0 = style.borderWidth + style.paddingLeft;
	int y0 = style.borderWidth + style.paddingTop;
	int decorWidth = x0 + style.borderWidth + style.paddingRight;
	int decorHeight = y0 + style.borderWidth + style.paddingBottom;

	if (constrainedWidth > 0) {
	    constrainedWidth -= decorWidth;
	    if (constrainedWidth <= 0)
		constrainedWidth = 1;
	}
	if (constrainedHeight > 0) {
	    constrainedHeight -= decorHeight;
	    if (constrainedHeight <= 0)
		constrainedHeight = 1;
	}

	if (children.length == 0) {
	    layoutEmptyContent(constrainedWidth, constrainedHeight);
	} else {
	    layoutContent(constrainedWidth, constrainedHeight, recursive);

	    for (int i = 0; i < children.length; ++i) {
		Gadget child = children[i];

		child.x += x0;
		child.y += y0;
	    }
	}

	width += decorWidth;
	height += decorHeight;
    }

    protected void layoutEmptyContent(int constrainedWidth, 
				      int constrainedHeight) {
	Dimension size = Box.getEmptyContentSize(this, style);
	width = size.width;
	height = size.height;

	if (constrainedWidth > 0 && width < constrainedWidth)
	    width = constrainedWidth;
    }

    protected abstract void layoutContent(int constrainedWidth, 
					  int constrainedHeight,
					  boolean recursive);

    public void paint(Graphics g) {
	Box.drawBox(g, style, width, height);

	if (children.length == 0)
	    paintEmptyContent(g);
	else
	    paintContent(g);
    }

    protected void paintEmptyContent(Graphics g) {
	int x0 = style.borderWidth + style.paddingLeft;
	int y0 = style.borderWidth + style.paddingTop;
	int w = width - (x0 + style.borderWidth + style.paddingRight);
	int h = height - (y0 + style.borderWidth + style.paddingBottom);

	g.translate(x0, y0);
	Box.drawEmptyContent(g, style, w, h);
    }    

    protected void paintContent(Graphics g) {
	super.paint(g);
    }

    public void print(Graphics g) {
	Box.drawBox(g, style, width, height);

	if (children.length == 0)
	    printEmptyContent(g);
	else
	    printContent(g);
    }

    protected void printEmptyContent(Graphics g) {
	paintEmptyContent(g);
    }    

    protected void printContent(Graphics g) {
	super.print(g);
    }
}
