/*
 * Copyright (c) 2000-2001 Pixware. 
 *
 * Author: Hussein Shafie
 *
 * This file is part of the XMLmind XML Editor project.
 * For conditions of distribution and use, see the accompanying legal.txt file.
 */
package com.xmlmind.xmledit.styledgadget;

import java.awt.Dimension;
import com.xmlmind.gadget.*;

public class Division extends TextLineContainerBox {
    public Division() {
	super();
    }

    public Division(Style style) {
	super(style);
    }

    protected void layoutContent(int constrainedWidth, int constrainedHeight,
				 boolean recursive) {
	int prevBottom = 0;
	int prevMarginBottom = 0;
	width = 0;

	for (int i = 0; i < children.length; ++i) {
	    Gadget child = children[i];
	    Style childStyle = ((Styled) child).getStyle();

	    if (recursive) {
		int constrainedChildWidth;

		if (constrainedWidth > 0) { 
		    constrainedChildWidth = constrainedWidth;
		    if (childStyle.marginLeft > 0)
			constrainedChildWidth -= childStyle.marginLeft;
		    if (childStyle.marginRight > 0)
			constrainedChildWidth -= childStyle.marginRight;
		} else {
		    constrainedChildWidth = -1;
		}

		child.layout(constrainedChildWidth, -1, true);
	    }

	    int w = child.width;
	    if (childStyle.marginLeft > 0)
		w += childStyle.marginLeft;
	    if (childStyle.marginRight > 0)
		w += childStyle.marginRight;
	    if (w > width)
		width = w;

	    // Collapse vertical margins.
	    child.y = prevBottom + ((prevMarginBottom > childStyle.marginTop)?
				    prevMarginBottom : childStyle.marginTop);
	    
	    prevBottom = child.y + child.height;
	    prevMarginBottom = childStyle.marginBottom;
	}

	if (constrainedWidth > 0 && width < constrainedWidth)
	    width = constrainedWidth;
	height = prevBottom + prevMarginBottom;
	if (width < 1)
	    width = 1;
	if (height < 1)
	    height = 1;

	if (children.length > 0) {
	    for (int i = 0; i < children.length; ++i) {
		Gadget child = children[i];
		Style childStyle = ((Styled) child).getStyle();

		if (childStyle.marginLeft >= 0) {
		    // Left aligned.
		    child.x = childStyle.marginLeft;
		} else {
		    if (childStyle.marginRight >= 0)
			// Right aligned.
			child.x = width - childStyle.marginRight - child.width;
		    else
			// Centered.
			child.x = (width - child.width) / 2;
		}
	    }

	    firstBaseLine = -1;
	    lastBaseLine = -1;

	    Gadget child = children[0];
	    if (child instanceof TextLines) {
		firstBaseLine = ((TextLines) child).getFirstBaseLine();
		if (firstBaseLine >= 0)
		    firstBaseLine += child.y;
	    }

	    child = children[children.length-1];
	    if (child instanceof TextLines) {
		lastBaseLine = ((TextLines) child).getLastBaseLine();
		if (lastBaseLine >= 0)
		    lastBaseLine += child.y;
	    }
	}
    }

    public void getSizeConstraints(Gadget child, Dimension constraints) {
	Box.getContentSizeConstraints(this, style, constraints);
	constraints.height = -1;

	if (constraints.width > 0) {
	    Style childStyle = ((Styled) child).getStyle();
	    if (childStyle.marginLeft > 0)
		constraints.width -= childStyle.marginLeft;
	    if (childStyle.marginRight > 0)
		constraints.width -= childStyle.marginRight;
	}
    }

    public void paintRelayout(Gadget child, int prevWidth, int prevHeight,
			      int damagedSide, int damagedLength) {
	// Remember that if the margins of the child has been changed, the
	// client must invoke parent.refresh(), not child.refresh(). Therefore
	// we assume here that the child style has not been changed since last
	// relayout.

	// Same width and same height happens when the baseLines of the
	// child has changed. In which case, process as if height has changed.
	boolean sameWidth = (child.width == prevWidth);

	if (child.height == prevHeight && !sameWidth) {
	    // Has the new width changed the overall width of the container?

	    Style childStyle = ((Styled) child).getStyle();
	    int w = child.width;
	    int prevW = prevWidth;
	    if (childStyle.marginLeft > 0) {
		w += childStyle.marginLeft;
		prevW += childStyle.marginLeft;
	    }
	    if (childStyle.marginRight > 0) {
		w += childStyle.marginRight;
		prevW += childStyle.marginRight;
	    }

	    int contentX = style.borderWidth + style.paddingLeft;
	    int contentWidth = width - 
		(contentX + style.paddingRight + style.borderWidth);
	    if (contentWidth <= 0)
		contentWidth = 1;

	    if (prevW < contentWidth && w <= contentWidth) {
		// The new width cannot have changed the overall width of the
		// container. Adjust child.x and repaint.

		if (childStyle.marginLeft >= 0) {
		    // Left aligned: no need to adjust child.x.  

		    int fromX;
		    if (damagedSide == RIGHT_SIDE)
			fromX = child.x + child.width - damagedLength;
		    else
			fromX = child.x;
		    repaint(fromX, child.y, contentWidth-fromX, child.height);
//System.err.println("repaint 1");
		} else {
		    // Right aligned or centered: adjust child.x and repaint
		    // the whole child's slice.

		    if (childStyle.marginRight >= 0)
			child.x = contentX + 
			    (contentWidth-childStyle.marginRight-child.width);
		    else
			child.x = contentX + 
			    ((contentWidth - child.width) / 2);

		    repaint(contentX, child.y, contentWidth, child.height);
//System.err.println("repaint 2");
		}
	    } else {
		super.paintRelayout(child, prevWidth, prevHeight,
				    damagedSide, damagedLength);
//System.err.println("super.paintRelayout 1");
	    }

	    return;
	}

	if (sameWidth) {
	    // Same width: optimized relayout.

	    int delta = child.height - prevHeight;
	    int childIndex = indexOfChild(child);

	    for (int i = childIndex+1; i < children.length; ++i) {
		children[i].y += delta;
	    }
		
	    height += delta;

	    if (childIndex == 0 && (child instanceof TextLines)) {
		firstBaseLine = ((TextLines) child).getFirstBaseLine();
		if (firstBaseLine >= 0)
		    firstBaseLine += child.y;
	    }

	    if (childIndex == children.length-1 && 
		(child instanceof TextLines)) {
		lastBaseLine = ((TextLines) child).getLastBaseLine();
		if (lastBaseLine >= 0) 
		    lastBaseLine += child.y;
	    }

	    int fromY;
	    if (damagedSide == BOTTOM_SIDE)
		fromY = child.y + child.height - damagedLength;
	    else
		fromY = child.y;
	    if (parent != null)
		parent.paintRelayout(this, width, height-delta, 
				     BOTTOM_SIDE, height-fromY);
//System.err.println("parent.paintRelayout");
	} else {
	    super.paintRelayout(child, prevWidth, prevHeight,
				damagedSide, damagedLength);
//System.err.println("super.paintRelayout 2");
	}
    }
}


