/*
 * Copyright (c) 2000-2001 Pixware. 
 *
 * Author: Hussein Shafie
 *
 * This file is part of the XMLmind XML Editor project.
 * For conditions of distribution and use, see the accompanying legal.txt file.
 */
package com.xmlmind.xmledit.styledgadget;

import java.util.Hashtable;
import java.awt.Image;
import java.awt.Color;
import com.xmlmind.awtutil.Bitmap;

public class Icon {
    public static final int LINE_BREAK      = 0;
    public static final int DISC            = 1;
    public static final int CIRCLE          = 2;
    public static final int SQUARE          = 3;
    public static final int DIAMOND         = 4;
    public static final int INVISIBLE       = 5;
    public static final int LEFT_TARGET     = 6;
    public static final int RIGHT_TARGET    = 7;
    public static final int FILLED_SQUARE   = 8;
    public static final int HOLLOW_DIAMOND  = 9;
    public static final int LEFT_HALF_DISC  = 10;
    public static final int RIGHT_HALF_DISC = 11;
    public static final int UP              = 12;
    public static final int DOWN            = 13;
    public static final int LEFT            = 14;
    public static final int RIGHT           = 15;
    public static final int POP_UP          = 16;
    public static final int POP_DOWN        = 17;
    public static final int POP_LEFT        = 18;
    public static final int POP_RIGHT       = 19;
    public static final int LEFT_LINK       = 20;
    public static final int RIGHT_LINK      = 21;
    public static final int PATTERN1        = 22;
    public static final int PATTERN2        = 23;

    public static class Info {
	public int icon;
	public String name;
	public Bitmap bitmap;
	public int width, height; // Accelerators

	public Info(int icon, String name, Bitmap bitmap) {
	    this.icon = icon;
	    this.name = name;
	    this.bitmap = bitmap;
	}

	public int hashCode() {
	    return icon;
	}

	public boolean equals(Object other) {
	    if (other == null || !(other instanceof Info))
		return false;
	    return (((Info) other).icon == icon);
	}
    }

    public static final Info[] list = {
	new Info(LINE_BREAK, "line-break",
	    new Bitmap(7, 7, new byte[] {
		(byte)0xc0, (byte)0xc0, (byte)0xc4, (byte)0xc6, (byte)0xbf, 
		(byte)0x86, (byte)0x84
	    })),

	new Info(DISC, "disc",
	    new Bitmap(7, 7, new byte[] {
		(byte)0x1c, (byte)0x3e, (byte)0x7f, (byte)0x7f, (byte)0x7f, 
		(byte)0x3e, (byte)0x1c
	    })),

	new Info(CIRCLE, "circle",
	    new Bitmap(7, 7, new byte[] {
		(byte)0x1c, (byte)0x22, (byte)0x41, (byte)0x41, (byte)0x41, 
		(byte)0x22, (byte)0x1c
	    })),

	new Info(SQUARE, "square",
	    new Bitmap(7, 7, new byte[] {
		(byte)0x7f, (byte)0x41, (byte)0x41, (byte)0x41, (byte)0x41, 
		(byte)0x41, (byte)0x7f
	    })),

	new Info(DIAMOND, "diamond",
	    new Bitmap(7, 7, new byte[] {
		(byte)0x08, (byte)0x1c, (byte)0x3e, (byte)0x7f, (byte)0x3e, 
		(byte)0x1c, (byte)0x08
	    })),

	new Info(INVISIBLE, "invisible",
	    new Bitmap(1, 1, new byte[] {
		(byte)0x00
	    })),

	new Info(LEFT_TARGET, "left-target",
	    new Bitmap(9, 9, new byte[] {
		(byte)0x02, (byte)0x00, (byte)0x17, (byte)0x00, (byte)0x5e, 
		(byte)0x00, (byte)0x9c, (byte)0x00, (byte)0x9e, (byte)0x00, 
		(byte)0x80, (byte)0x00, (byte)0x44, (byte)0x00, (byte)0x38, 
		(byte)0x00, (byte)0x00, (byte)0x00
	    })),

	new Info(RIGHT_TARGET, "right-target",
	    new Bitmap(9, 9, new byte[] {
		(byte)0x80, (byte)0x00, (byte)0xd0, (byte)0x01, (byte)0xf4, 
		(byte)0x00, (byte)0x72, (byte)0x00, (byte)0xf2, (byte)0x00, 
		(byte)0x02, (byte)0x00, (byte)0x44, (byte)0x00, (byte)0x38, 
		(byte)0x00, (byte)0x00, (byte)0x00
	    })),

	new Info(FILLED_SQUARE, "filled-square",
	    new Bitmap(7, 7, new byte[] {
		(byte)0x7f, (byte)0x7f, (byte)0x7f, (byte)0x7f, (byte)0x7f, 
		(byte)0x7f, (byte)0x7f
	    })),

	new Info(HOLLOW_DIAMOND, "hollow-diamond",
	    new Bitmap(7, 7, new byte[] {
		(byte)0x08, (byte)0x14, (byte)0x22, (byte)0x41, (byte)0x22, 
		(byte)0x14, (byte)0x08
	    })),

	new Info(LEFT_HALF_DISC, "left-half-disc",
	    new Bitmap(7, 7, new byte[] {
		(byte)0x18, (byte)0x1c, (byte)0x1e, (byte)0x1e, (byte)0x1e, 
		(byte)0x1c, (byte)0x18
	    })),

	new Info(RIGHT_HALF_DISC, "right-half-disc",
	    new Bitmap(7, 7, new byte[] {
		(byte)0x0c, (byte)0x1c, (byte)0x3c, (byte)0x3c, (byte)0x3c, 
		(byte)0x1c, (byte)0x0c
	    })),

	new Info(UP, "up",
	    new Bitmap(7, 7, new byte[] {
		(byte)0x08, (byte)0x1c, (byte)0x1c, (byte)0x3e, (byte)0x3e, 
		(byte)0x7f, (byte)0x7f
	    })),

	new Info(DOWN, "down",
	    new Bitmap(7, 7, new byte[] {
		(byte)0x7f, (byte)0x7f, (byte)0x3e, (byte)0x3e, (byte)0x1c, 
		(byte)0x1c, (byte)0x08
	    })),

	new Info(LEFT, "left",
	    new Bitmap(7, 7, new byte[] {
		(byte)0x60, (byte)0x78, (byte)0x7e, (byte)0x7f, (byte)0x7e, 
		(byte)0x78, (byte)0x60
	    })),

	new Info(RIGHT, "right",
	    new Bitmap(7, 7, new byte[] {
		(byte)0x03, (byte)0x0f, (byte)0x3f, (byte)0x7f, (byte)0x3f, 
		(byte)0x0f, (byte)0x03
	    })),

	new Info(POP_UP, "pop-up",
	    new Bitmap(9, 9, new byte[] {
		(byte)0x00, (byte)0x00, (byte)0x10, (byte)0x00, (byte)0x38, 
		(byte)0x00, (byte)0x7c, (byte)0x00, (byte)0xfe, (byte)0x00, 
		(byte)0xff, (byte)0x01, (byte)0x00, (byte)0x00, (byte)0x00, 
		(byte)0x00, (byte)0x00, (byte)0x00
	    })),

	new Info(POP_DOWN, "pop-down",
	    new Bitmap(9, 9, new byte[] {
		(byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, 
		(byte)0x00, (byte)0xff, (byte)0x01, (byte)0xfe, (byte)0x00, 
		(byte)0x7c, (byte)0x00, (byte)0x38, (byte)0x00, (byte)0x10, 
		(byte)0x00, (byte)0x00, (byte)0x00
	    })),

	new Info(POP_LEFT, "pop-left",
	    new Bitmap(9, 9, new byte[] {
		(byte)0x20, (byte)0x00, (byte)0x30, (byte)0x00, (byte)0x38, 
		(byte)0x00, (byte)0x3c, (byte)0x00, (byte)0x3e, (byte)0x00, 
		(byte)0x3c, (byte)0x00, (byte)0x38, (byte)0x00, (byte)0x30, 
		(byte)0x00, (byte)0x20, (byte)0x00
	    })),

	new Info(POP_RIGHT, "pop-right",
	    new Bitmap(9, 9, new byte[] {
		(byte)0x08, (byte)0x00, (byte)0x18, (byte)0x00, (byte)0x38, 
		(byte)0x00, (byte)0x78, (byte)0x00, (byte)0xf8, (byte)0x00, 
		(byte)0x78, (byte)0x00, (byte)0x38, (byte)0x00, (byte)0x18, 
		(byte)0x00, (byte)0x08, (byte)0x00
	    })),

	new Info(LEFT_LINK, "left-link",
	    new Bitmap(9, 9, new byte[] {
		(byte)0x02, (byte)0x00, (byte)0x17, (byte)0x00, (byte)0x2e, 
		(byte)0x00, (byte)0x4c, (byte)0x00, (byte)0x82, (byte)0x00, 
		(byte)0x64, (byte)0x00, (byte)0xe8, (byte)0x00, (byte)0xd0, 
		(byte)0x01, (byte)0x80, (byte)0x00
	    })),

	new Info(RIGHT_LINK, "right-link",
	    new Bitmap(9, 9, new byte[] {
		(byte)0x80, (byte)0x00, (byte)0xd0, (byte)0x01, (byte)0xe8, 
		(byte)0x00, (byte)0x64, (byte)0x00, (byte)0x82, (byte)0x00, 
		(byte)0x4c, (byte)0x00, (byte)0x2e, (byte)0x00, (byte)0x17, 
		(byte)0x00, (byte)0x02, (byte)0x00
	    })),

	new Info(PATTERN1, "pattern1",
	    new Bitmap(80, 20, new byte[] {
		(byte)0x11, (byte)0x11, (byte)0x11, (byte)0x11, (byte)0x11, 
		(byte)0x11, (byte)0x11, (byte)0x11, (byte)0x11, (byte)0x11, 
		(byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, 
		(byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, 
		(byte)0x44, (byte)0x44, (byte)0x44, (byte)0x44, (byte)0x44, 
		(byte)0x44, (byte)0x44, (byte)0x44, (byte)0x44, (byte)0x44, 
		(byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, 
		(byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, 
		(byte)0x11, (byte)0x11, (byte)0x11, (byte)0x11, (byte)0x11, 
		(byte)0x11, (byte)0x11, (byte)0x11, (byte)0x11, (byte)0x11, 
		(byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, 
		(byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
		(byte)0x44, (byte)0x44, (byte)0x44, (byte)0x44, (byte)0x44, 
		(byte)0x44, (byte)0x44, (byte)0x44, (byte)0x44, (byte)0x44, 
		(byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, 
		(byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, 
		(byte)0x11, (byte)0x11, (byte)0x11, (byte)0x11, (byte)0x11, 
		(byte)0x11, (byte)0x11, (byte)0x11, (byte)0x11, (byte)0x11, 
		(byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, 
		(byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, 
		(byte)0x44, (byte)0x44, (byte)0x44, (byte)0x44, (byte)0x44, 
		(byte)0x44, (byte)0x44, (byte)0x44, (byte)0x44, (byte)0x44, 
		(byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, 
		(byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
		(byte)0x11, (byte)0x11, (byte)0x11, (byte)0x11, (byte)0x11, 
		(byte)0x11, (byte)0x11, (byte)0x11, (byte)0x11, (byte)0x11, 
		(byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, 
		(byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, 
		(byte)0x44, (byte)0x44, (byte)0x44, (byte)0x44, (byte)0x44, 
		(byte)0x44, (byte)0x44, (byte)0x44, (byte)0x44, (byte)0x44, 
		(byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, 
		(byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, 
		(byte)0x11, (byte)0x11, (byte)0x11, (byte)0x11, (byte)0x11, 
		(byte)0x11, (byte)0x11, (byte)0x11, (byte)0x11, (byte)0x11, 
		(byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, 
		(byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
		(byte)0x44, (byte)0x44, (byte)0x44, (byte)0x44, (byte)0x44, 
		(byte)0x44, (byte)0x44, (byte)0x44, (byte)0x44, (byte)0x44, 
		(byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, 
		(byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00
	    })),

	new Info(PATTERN2, "pattern2",
	    new Bitmap(80, 20, new byte[] {
		(byte)0x55, (byte)0x55, (byte)0x55, (byte)0x55, (byte)0x55, 
		(byte)0x55, (byte)0x55, (byte)0x55, (byte)0x55, (byte)0x55, 
		(byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, 
		(byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, 
		(byte)0x55, (byte)0x55, (byte)0x55, (byte)0x55, (byte)0x55, 
		(byte)0x55, (byte)0x55, (byte)0x55, (byte)0x55, (byte)0x55, 
		(byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, 
		(byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, 
		(byte)0x55, (byte)0x55, (byte)0x55, (byte)0x55, (byte)0x55, 
		(byte)0x55, (byte)0x55, (byte)0x55, (byte)0x55, (byte)0x55, 
		(byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, 
		(byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
		(byte)0x55, (byte)0x55, (byte)0x55, (byte)0x55, (byte)0x55, 
		(byte)0x55, (byte)0x55, (byte)0x55, (byte)0x55, (byte)0x55, 
		(byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, 
		(byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, 
		(byte)0x55, (byte)0x55, (byte)0x55, (byte)0x55, (byte)0x55, 
		(byte)0x55, (byte)0x55, (byte)0x55, (byte)0x55, (byte)0x55, 
		(byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, 
		(byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, 
		(byte)0x55, (byte)0x55, (byte)0x55, (byte)0x55, (byte)0x55, 
		(byte)0x55, (byte)0x55, (byte)0x55, (byte)0x55, (byte)0x55, 
		(byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, 
		(byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
		(byte)0x55, (byte)0x55, (byte)0x55, (byte)0x55, (byte)0x55, 
		(byte)0x55, (byte)0x55, (byte)0x55, (byte)0x55, (byte)0x55, 
		(byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, 
		(byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, 
		(byte)0x55, (byte)0x55, (byte)0x55, (byte)0x55, (byte)0x55, 
		(byte)0x55, (byte)0x55, (byte)0x55, (byte)0x55, (byte)0x55, 
		(byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, 
		(byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, 
		(byte)0x55, (byte)0x55, (byte)0x55, (byte)0x55, (byte)0x55, 
		(byte)0x55, (byte)0x55, (byte)0x55, (byte)0x55, (byte)0x55, 
		(byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, 
		(byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, 
		(byte)0x55, (byte)0x55, (byte)0x55, (byte)0x55, (byte)0x55, 
		(byte)0x55, (byte)0x55, (byte)0x55, (byte)0x55, (byte)0x55, 
		(byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, 
		(byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00
	    }))
    };

    private static Hashtable iconToInfo = new Hashtable();
    private static Hashtable nameToInfo = new Hashtable();
    static {
	for (int i = 0; i < list.length; ++i) {
	    Info info = list[i];

	    Bitmap bitmap = info.bitmap;
	    info.width = bitmap.getWidth();
	    info.height = bitmap.getHeight();

	    iconToInfo.put(info, info);
	    nameToInfo.put(info.name, info);
	}
    }

    // -----------------------------------------------------------------------

    private static class CacheEntry {
	public int icon;
	public Color foreground;
	public Color background;
	public Image image;

	public CacheEntry(int icon, Color foreground, Color background, 
			  Image image) {
	    this.icon = icon;
	    this.foreground = foreground;
	    this.background = background;
	    this.image = image;
	}

	public int hashCode() {
	    return icon;
	}

	public boolean equals(Object other) {
	    if (other == null || !(other instanceof CacheEntry))
		return false;
	
	    CacheEntry e = (CacheEntry) other;

	    return (icon == e.icon &&
		    foreground.equals(e.foreground) &&
		    ((background == null && e.background == null) ||
		     (background != null && background.equals(e.background))));
	}

    }
    private static CacheEntry probe = new CacheEntry(-1, null, null, null);
    private static Hashtable cache = new Hashtable();

    // -----------------------------------------------------------------------

    public static Image get(String name, Color foreground) {
	return get(name, foreground, null);
    }

    public static Image get(String name, Color foreground, Color background) {
	Info info = (Info) nameToInfo.get(name);

	return get(((info == null)? -1 : info.icon), foreground, background);
    }

    public static Image get(int icon, Color foreground) {
	return get(icon, foreground, null);
    }

    public static Image get(int icon, Color foreground, Color background) {
	probe.icon = icon;
	probe.foreground = foreground;
	probe.background = background;
	CacheEntry entry = (CacheEntry) cache.get(probe);

	if (entry == null) {
	    if (icon < 0 || icon >= list.length)
		icon = DISC;
	    entry = new CacheEntry(icon, foreground, background, 
				   list[icon].bitmap.getImage(foreground, 
							      background));
	    cache.put(entry, entry);
	}

	return entry.image;
    }
}


