/*
 * Copyright (c) 2000-2001 Pixware. 
 *
 * Author: Hussein Shafie
 *
 * This file is part of the XMLmind XML Editor project.
 * For conditions of distribution and use, see the accompanying legal.txt file.
 */
package com.xmlmind.xmledit.styledgadget;

import java.net.URL;
import java.net.MalformedURLException;
import java.awt.Graphics;
import java.awt.Toolkit;
import java.awt.Image;
import com.xmlmind.awtutil.ImageResource;

public class ImageLabel extends Box {
    public static Image DEFAULT_IMAGE = null;
    static {
	DEFAULT_IMAGE = ImageResource.get(ImageLabel.class, 
					  "defaultimage.gif");
	ImageResource.loadImage(DEFAULT_IMAGE);
    }

    private Image image;

    // -----------------------------------------------------------------------

    public ImageLabel() {
	this(Box.DEFAULT_STYLE, null);
    }

    public ImageLabel(Style style) {
	this(style, null);
    }

    public ImageLabel(int icon) {
	this(Box.DEFAULT_STYLE, Icon.get(icon, Box.DEFAULT_STYLE.color));
    }

    public ImageLabel(Style style, Image image) {
	super(style);
	setImage(image, -1, -1);
    }

    public void setImage(int icon) {
	setImage(Icon.get(icon, style.color), -1, -1);
    }

    public void setImage(String url) {
	setImage(url, -1, -1);
    }

    public void setImage(String url, int scaledWidth, int scaledHeight) {
	URL location = null;
	try {
	    location = new URL(url);
	} catch (MalformedURLException e) {
	    location = null;
	}
	setImage(location, scaledWidth, scaledHeight);
    }

    public void setImage(URL url, int scaledWidth, int scaledHeight) {
	Image img = null;

	if (url != null) {
	    img = Toolkit.getDefaultToolkit().createImage(url);
	    if (img != null) 
		img = ImageResource.loadImage(img);
	}    

	setImage(img, scaledWidth, scaledHeight);
    }

    public void setImage(Image image) {
	setImage(image, -1, -1);
    }

    public void setImage(Image img, int scaledWidth, int scaledHeight) {
	if (img == null) 
	    img = DEFAULT_IMAGE;

	int imgW = img.getWidth(null);
	int imgH = img.getHeight(null);
	if ((scaledWidth > 0 && scaledWidth != imgW) || 
	    (scaledHeight > 0 && scaledHeight != imgH)) {
	    if (scaledWidth <= 0)
		scaledWidth = imgW;
	    if (scaledHeight <= 0)
		scaledHeight = imgH;
	    img = img.getScaledInstance(scaledWidth, scaledHeight, 
					Image.SCALE_DEFAULT);
	    ImageResource.loadImage(img);
	}

	this.image = img;
    }

    public Image getImage() {
	return image;
    }

    protected void layoutContent(int constrainedWidth, int constrainedHeight,
				 boolean recursive) {
	width = image.getWidth(null);
	height = image.getHeight(null);
    }

    protected void paintContent(Graphics g) {
	g.drawImage(image, 0, 0, null);
    }
}

