/*
 * Copyright (c) 2001 Pixware. 
 *
 * Author: Hussein Shafie
 *
 * This file is part of the XMLmind XML Editor project.
 * For conditions of distribution and use, see the accompanying legal.txt file.
 */
package com.xmlmind.xmledit.styledgadget;

import com.xmlmind.gadget.*;

public abstract class TextLineContainerBox extends ContainerBox 
                                           implements TextLines {
    protected int firstBaseLine, lastBaseLine;

    protected TextLineContainerBox() {
	super();
    }

    protected TextLineContainerBox(Style style) {
	super(style);
    }

    public int getFirstBaseLine() {
	return firstBaseLine;
    }

    public int getLastBaseLine() {
	return lastBaseLine;
    }

    public void refresh() {
	int oldWidth = width;
	int oldHeight = height;
	int oldFirstBaseLine = firstBaseLine;
	int oldLastBaseLine = lastBaseLine;

	relayout(true);

	if (width == oldWidth && 
	    height == oldHeight &&
	    firstBaseLine == oldFirstBaseLine && 
	    lastBaseLine == oldLastBaseLine) {
	    repaint(0, 0, width, height);
	} else {
	    if (parent != null)
		parent.paintRelayout(this, oldWidth, oldHeight, 
				     GadgetContainer.NO_SIDE, -1);
	}
    }

    public void layout(int constrainedWidth, int constrainedHeight,
		       boolean recursive) {
	super.layout(constrainedWidth, constrainedHeight, recursive);

	if (firstBaseLine >= 0)
	    firstBaseLine += style.borderWidth + style.paddingTop;
	if (lastBaseLine >= 0)
	    lastBaseLine += style.borderWidth + style.paddingTop;
    }

    public void paintRelayout(Gadget child, int prevWidth, int prevHeight,
			      int damagedSide, int damagedLength) {
	int oldWidth = width;
	int oldHeight = height;
	int oldFirstBaseLine = firstBaseLine;
	int oldLastBaseLine = lastBaseLine;

	relayout(false);

	if (width == oldWidth && 
	    height == oldHeight &&
	    firstBaseLine == oldFirstBaseLine && 
	    lastBaseLine == oldLastBaseLine) {
	    repaint(0, 0, width, height);
	} else {
	    if (parent != null)
		parent.paintRelayout(this, oldWidth, oldHeight, 
				     GadgetContainer.NO_SIDE, -1);
	}
    }
}

