/*
 * Copyright (c) 2000-2001 Pixware. 
 *
 * Author: Hussein Shafie
 *
 * This file is part of the XMLmind XML Editor project.
 * For conditions of distribution and use, see the accompanying legal.txt file.
 */

import java.awt.Graphics;
import java.awt.Color;
import java.awt.BorderLayout;
import java.awt.event.WindowAdapter;
import java.awt.event.WindowEvent;
import javax.swing.JFrame;
import javax.swing.JPanel;
import javax.swing.border.EmptyBorder;
import com.xmlmind.gadget.JGadgetPanel;
import com.xmlmind.gadget.RootGadget;
import com.xmlmind.xmledit.styledgadget.*;

public class TestBox {
    public static void main(String[] args) throws Exception {
	Style style = new Style();
	style.backgroundColor = Color.white;
	style.borderStyle = Style.BORDER_STYLE_GROOVE;
	style.borderWidth = 8;
	style.borderTopColor = Color.gray;
	if (args.length == 0) {
	    style.borderRightColor = style.borderBottomColor =
		style.borderLeftColor = style.borderTopColor;
	} else {
	    style.borderRightColor = Color.blue.darker();
	    style.borderBottomColor = Color.red.darker();
	    style.borderLeftColor = Color.green.darker();
	}

	switch (args.length) {
	case 3:
	    if (args[2].indexOf('t') >= 0)
		style.borderTopColor = null;
	    if (args[2].indexOf('r') >= 0)
		style.borderRightColor = null;
	    if (args[2].indexOf('b') >= 0)
		style.borderBottomColor = null;
	    if (args[2].indexOf('l') >= 0)
		style.borderLeftColor = null;
	    /*FALLTHROUGH*/

	case 2:
	    style.borderWidth = Integer.parseInt(args[1]);
	    if (style.borderWidth <= 0)
		style.borderWidth = 0;
	    /*FALLTHROUGH*/

	case 1:
	    if (args[0].length() > 0) {
		switch (args[0].charAt(0)) {
		case 'i':
		    style.borderStyle = Style.BORDER_STYLE_INSET;
		    break;
		case 'o':
		    style.borderStyle = Style.BORDER_STYLE_OUTSET;
		    break;
		case 'g':
		    style.borderStyle = Style.BORDER_STYLE_GROOVE;
		    break;
		case 'r':
		    style.borderStyle = Style.BORDER_STYLE_RIDGE;
		    break;
		case 'd':
		    style.borderStyle = Style.BORDER_STYLE_DOUBLE;
		    break;
		case '.':
		    style.borderStyle = Style.BORDER_STYLE_DOTTED;
		    break;
		case '-':
		    style.borderStyle = Style.BORDER_STYLE_DASHED;
		    break;
		case 'n':
		    style.borderStyle = Style.BORDER_STYLE_NONE;
		    break;
		case 's':
		default:
		    style.borderStyle = Style.BORDER_STYLE_SOLID;
		}
	    }
	    break;
	}

	JFrame frame = new JFrame();
   	frame.addWindowListener(new WindowAdapter() {
   	    public void windowClosing(WindowEvent e) {
   	        System.exit(0);
   	    }
   	});

	Box box = new Box() {
	    protected void layoutContent(int constrainedWidth, 
					 int constrainedHeight,
					 boolean recursive) {
		width = 200;
		height = 200;
	    }
	    protected void paintContent(Graphics g) {}
	};

	box.setStyle(style);

	JPanel workArea = (JPanel) frame.getContentPane();
	workArea.setBackground(Color.white);
	workArea.setBorder(new EmptyBorder(20, 20, 20, 20));

	JGadgetPanel panel = new JGadgetPanel();
	RootGadget root = panel.getRoot();
	root.addChild(box);
	root.refresh();

	workArea.add(panel, BorderLayout.CENTER);

	frame.pack();
	frame.show();
    }
}
