/*
 * Copyright (c) 2000-2001 Pixware. 
 *
 * Author: Hussein Shafie
 *
 * This file is part of the XMLmind XML Editor project.
 * For conditions of distribution and use, see the accompanying legal.txt file.
 */

import java.awt.Dimension;
import java.awt.Graphics;
import java.awt.Color;
import java.awt.BorderLayout;
import java.awt.Color;
import java.awt.Font;
import java.awt.event.*;
import javax.swing.JFrame;
import javax.swing.JPanel;
import com.xmlmind.gadget.JGadgetPanel;
import com.xmlmind.gadget.RootGadget;
import com.xmlmind.xmledit.styledgadget.*;

public class TestLabeledItem {
    public static void main(String[] args) throws Exception {
	JFrame frame = new JFrame();
   	frame.addWindowListener(new WindowAdapter() {
   	    public void windowClosing(WindowEvent e) {
   	        System.exit(0);
   	    }
   	});

	Division division = new Division();

	ImageLabel img1 = new ImageLabel();
	img1.setImage(Icon.CIRCLE);
	ImageLabel img2 = new ImageLabel();
	img2.setImage(Icon.LINE_BREAK);
	LabeledItem li = new LabeledItem();
	li.setEndLabel(img2, 5);
	li.setStartLabel(img1, 5);
	division.addChild(li);

	img1 = new ImageLabel();
	img1.setImage(Icon.DISC);
	li = newLabeledItem(img1, null);
	division.addChild(li);

	img2 = new ImageLabel();
	img2.setImage(Icon.CIRCLE);
	li = newLabeledItem(null, img2);
	division.addChild(li);

	img1 = new ImageLabel();
	img1.setImage(Icon.DIAMOND);
	img2 = new ImageLabel();
	img2.setImage(Icon.INVISIBLE);
	li = newLabeledItem(img1, img2);
	division.addChild(li);

	img1 = new ImageLabel();
	img1.setImage("", -1, 50);
	img2 = new ImageLabel();
	img2.setImage("", -1, 80);
	li = newLabeledItem(img1, img2);
	division.addChild(li);

	TextLabel txt1 = new TextLabel();
	txt1.setText("1.");
	TextLabel txt2 = new TextLabel();
	txt2.setText(".2");
	li = newLabeledItem(txt1, txt2);
	division.addChild(li);

	txt1 = new TextLabel();
	txt1.setText("1.\n1.\n1.\n1.");
	txt2 = new TextLabel();
	txt2.setText(".2");
	li = newLabeledItem(txt1, txt2);
	Style s = txt1.getStyle();
	s.font = new Font("SansSerif", Font.BOLD, 16);
	s = txt2.getStyle();
	s.font = new Font("SansSerif", Font.BOLD, 60);
	division.addChild(li);

	txt1 = new TextLabel();
	txt1.setText("1.\n1.\n1.\n1.");
	txt2 = new TextLabel();
	txt2.setText(".2");
	li = newLabeledItem(txt2, txt1);
	s = txt1.getStyle();
	s.font = new Font("SansSerif", Font.BOLD, 16);
	s = txt2.getStyle();
	s.font = new Font("SansSerif", Font.BOLD, 60);
	division.addChild(li);

	txt1 = new TextLabel("1.");
	txt2 = new TextLabel(".2");
	Division paragraphs = new Division(newTestStyle());
	String sampleText = "Paragraph first line.\nParagraph second line.";
	//paragraphs.addChild(new ImageLabel(Icon.DIAMOND));
	paragraphs.addChild(new TextLabel(sampleText));
	paragraphs.addChild(new ImageLabel(Icon.DIAMOND));
	paragraphs.addChild(new TextLabel(sampleText));
	//paragraphs.addChild(new ImageLabel(Icon.DIAMOND));
	li = new LabeledItem();
	li.setStartLabel(txt1, 5);
	li.setEndLabel(txt2, 5);
	li.setItem(paragraphs);
	division.addChild(li);

	JGadgetPanel panel = new JGadgetPanel();
	final RootGadget root = panel.getRoot();
	root.addChild(division);
	root.refresh();

	final JPanel workArea = (JPanel) frame.getContentPane();
	workArea.add(panel, BorderLayout.CENTER);

	workArea.addComponentListener(new ComponentAdapter() {
	    private Dimension dim = new Dimension();

	    public void componentResized(ComponentEvent e) {
		workArea.getSize(dim);
		root.layout(dim.width, dim.height);
		root.repaint();
	    }
	});
	
	frame.pack();
	frame.show();
    }

    private static LabeledItem newLabeledItem(Box startLabel, 
					      Box endLabel) {
	LabeledItem li = new LabeledItem();

	TextLabel item = 
	    new TextLabel(newTestStyle(), 
			  "Hello world!\nGoodbye beautiful world!");

	li.setItem(item);
	if (startLabel != null) {
	    startLabel.setStyle(newTestStyle());
	    li.setStartLabel(startLabel, 5);
	}
	if (endLabel != null) {
	    endLabel.setStyle(newTestStyle());
	    li.setEndLabel(endLabel, 5);
	}

	return li;
    }

    private static Style newTestStyle() {
	Style style = new Style();
	style.marginLeft = style.marginRight = 100;
	style.marginTop = style.marginBottom = 10;
	style.paddingTop = style.paddingRight = 
	    style.paddingBottom = style.paddingLeft = 2;
	style.backgroundColor = Color.white;
	style.borderWidth = 1;
	style.borderStyle = Style.BORDER_STYLE_SOLID;
	return style;
    }
}
