/*
 * Copyright (c) 2000-2001 Pixware. 
 *
 * Author: Hussein Shafie
 *
 * This file is part of the XMLmind XML Editor project.
 * For conditions of distribution and use, see the accompanying legal.txt file.
 */

import java.awt.Dimension;
import java.awt.Graphics;
import java.awt.Color;
import java.awt.BorderLayout;
import java.awt.Color;
import java.awt.Font;
import java.awt.event.*;
import javax.swing.JFrame;
import javax.swing.JPanel;
import com.xmlmind.gadget.JGadgetPanel;
import com.xmlmind.gadget.RootGadget;
import com.xmlmind.xmledit.styledgadget.*;

public class TestParagraph {
    public static void main(String[] args) throws Exception {
	JFrame frame = new JFrame();
   	frame.addWindowListener(new WindowAdapter() {
   	    public void windowClosing(WindowEvent e) {
   	        System.exit(0);
   	    }
   	});

	Division division = new Division();

	Style style = new Style();
	//style.whiteSpace = Style.WHITE_SPACE_NOWRAP;
	style.font = new Font("SansSerif", Font.PLAIN, 20);
	style.backgroundColor = new Color(128,128,255);
	style.marginLeft = style.marginRight = 10;
	style.marginTop = style.marginBottom = 10;

	test1(division, style);
	//test2(division, style);

	JGadgetPanel panel = new JGadgetPanel();
	final RootGadget root = panel.getRoot();
	root.addChild(division);
	root.refresh();

	final JPanel workArea = (JPanel) frame.getContentPane();
	workArea.add(panel, BorderLayout.CENTER);

	workArea.addComponentListener(new ComponentAdapter() {
	    private Dimension dim = new Dimension();

	    public void componentResized(ComponentEvent e) {
		workArea.getSize(dim);
		root.layout(dim.width, dim.height);
		root.repaint();
	    }
	});
	
	frame.pack();
	frame.show();
    }

    private static void test1(Division division, Style paragraphStyle) {
	Style style = newChildStyle();
	String text = "Copyright (c) 1999,2000 Pixware.\n\n" +
	    "This file is part of the Pixware APT tools.\n" +
	    "For conditions of distribution and use," +
	    " see the accompanying legal.txt file.\n\n";
	String text2 = 
	    "This program is distributed in the hope that it will be useful";
	String text3 = 
	    " but_WITHOUT_ANY_WARRANTY;_without_even_the_implied_warranty_of" +
	    "_MERCHANTABILITY_or_FITNESS_FOR_A_PARTICULAR_PURPOSE.";

	Paragraph p;
	p = new Paragraph(paragraphStyle);
	division.addChild(p);

	p = new Paragraph(paragraphStyle);
	p.addChild(new ParagraphText(style, ""));
	division.addChild(p);

	p = new Paragraph(paragraphStyle);
	p.addChild(new ParagraphText(style, text));
	p.addChild(new ParagraphText(style, text2));
	p.addChild(new ParagraphText(style, text3));
	division.addChild(p);

	p = new Paragraph(paragraphStyle);
	fill1(p);
	division.addChild(p);

	p = new Paragraph(paragraphStyle);
	fill2(p);
	division.addChild(p);
    }

    private static void test2(Division division, Style paragraphStyle) {
	Style style = newChildStyle();
	String text = 
	"Pixware APT tools. Generate, parse, convert APT documents.\n" +
	"Copyright (c) 1999,2000 Pixware\n\n" +
	"This program is free software; you can redistribute it" + 
	" and/or modify it\n" +
	"under the terms of the GNU General Public License Version 2" + 
	" as published by\n" +
	"the Free Software Foundation.\n\n";
	String text2 = 
	"This program is distributed in the hope that it will be useful,\n" +
	"but WITHOUT ANY WARRANTY; without even the implied warranty of\n" +
	"MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the\n" +
	"GNU General Public License for more details.\n\n" +
	"You should have received a copy of the GNU General Public License\n" +
	"along with this program; if not, write to the Free Software\n" +
	"Foundation, Inc., 59 Temple Place, Suite 330, Boston," + 
	" MA	02111-1307	USA\n\n";

	Style paragraphStyle2 = paragraphStyle.duplicate();
	paragraphStyle2.textAlign = Style.TEXT_ALIGN_LEFT;
	paragraphStyle2.textIndent = 50;
	Paragraph p = new Paragraph(paragraphStyle2);
	p.addChild(new ParagraphText(style, text));
	division.addChild(p);

	paragraphStyle2 = paragraphStyle.duplicate();
	paragraphStyle2.textAlign = Style.TEXT_ALIGN_LEFT;
	paragraphStyle2.textIndent = -50;
	p = new Paragraph(paragraphStyle2);
	Style style2 = style.duplicate();
	style2.textDecoration = Style.TEXT_DECORATION_UNDERLINE;
	p.addChild(new ParagraphText(style2, text));
	division.addChild(p);

	paragraphStyle2 = paragraphStyle.duplicate();
	paragraphStyle2.textAlign = Style.TEXT_ALIGN_CENTER;
	p = new Paragraph(paragraphStyle2);
	style2 = style.duplicate();
	style2.textDecoration = Style.TEXT_DECORATION_OVERLINE;
	p.addChild(new ParagraphText(style2, text));
	division.addChild(p);

	paragraphStyle2 = paragraphStyle.duplicate();
	paragraphStyle2.textAlign = Style.TEXT_ALIGN_RIGHT;
	p = new Paragraph(paragraphStyle2);
	style2 = style.duplicate();
	style2.textDecoration = Style.TEXT_DECORATION_LINE_THROUGH;
	p.addChild(new ParagraphText(style2, text));
	division.addChild(p);
    }

    private static void fill1(Paragraph p) {
	Style style = newChildStyle();
	style.verticalAlign = Style.VERTICAL_ALIGN_TOP;
	ImageLabel img = new ImageLabel(style);
	img.setImage(Icon.SQUARE);
	p.addChild(img);

	style = newChildStyle();
	style.verticalAlign = Style.VERTICAL_ALIGN_BOTTOM;
	img = new ImageLabel(style);
	img.setImage(Icon.SQUARE);
	p.addChild(img);

	style = newChildStyle();
	img = new ImageLabel(style);
	img.setImage(Icon.SQUARE);
	p.addChild(img);
	
	style = newChildStyle();
	p.addChild(new ParagraphText(style, "   baseline   "));
	
	style = newChildStyle();
	style.verticalAlign = Style.VERTICAL_ALIGN_SUPER;
	img = new ImageLabel(style);
	img.setImage(Icon.SQUARE);
	p.addChild(img);

	style = newChildStyle();
	style.verticalAlign = Style.VERTICAL_ALIGN_SUPER;
	p.addChild(new ParagraphText(style, "super"));
	
	style = newChildStyle();
	style.verticalAlign = Style.VERTICAL_ALIGN_SUB;
	img = new ImageLabel(style);
	img.setImage(Icon.SQUARE);
	p.addChild(img);

	style = newChildStyle();
	style.verticalAlign = Style.VERTICAL_ALIGN_SUB;
	p.addChild(new ParagraphText(style, "sub\n"));
	
	style = newChildStyle();
	style.verticalAlign = Style.VERTICAL_ALIGN_TEXT_TOP;
	p.addChild(new ParagraphText(style, "text top"));
	
	style = newChildStyle();
	p.addChild(new ParagraphText(style, "base"));
	
	style = newChildStyle();
	style.verticalAlign = Style.VERTICAL_ALIGN_TEXT_BOTTOM;
	p.addChild(new ParagraphText(style, "text bottom"));
	
	style = newChildStyle();
	p.addChild(new ParagraphText(style, "line"));
	
	style = newChildStyle();
	style.verticalAlign = Style.VERTICAL_ALIGN_MIDDLE;
	p.addChild(new ParagraphText(style, "middle\n"));
	
	style = newChildStyle();
	style.verticalAlign = Style.VERTICAL_ALIGN_TOP;
	style.marginLeft = style.marginRight = 10;
	img = new ImageLabel(style);
	img.setImage("", -1, 30);
	p.addChild(img);

	style = newChildStyle();
	style.verticalAlign = Style.VERTICAL_ALIGN_BOTTOM;
	style.marginLeft = style.marginRight = 10;
	img = new ImageLabel(style);
	img.setImage("", -1, 20);
	p.addChild(img);

	style = newChildStyle();
	p.addChild(new ParagraphText(style, "baseline\n"));

	style = newChildStyle();
	style.verticalAlign = Style.VERTICAL_ALIGN_BOTTOM;
	style.marginLeft = style.marginRight = 10;
	img = new ImageLabel(style);
	img.setImage("", -1, 20);
	p.addChild(img);

	style = newChildStyle();
	style.verticalAlign = Style.VERTICAL_ALIGN_TOP;
	style.marginLeft = style.marginRight = 10;
	img = new ImageLabel(style);
	img.setImage("", -1, 30);
	p.addChild(img);
    }

    private static void fill2(Paragraph p) {
	Style style = newChildStyle();
	ImageLabel img = new ImageLabel(style);
	img.setImage(Icon.DISC);
	p.addChild(img);

	style = newChildStyle();
	p.addChild(new ParagraphText(style, "This is the square icon "));

	style = newChildStyle();
	img = new ImageLabel(style);
	img.setImage(Icon.SQUARE);
	p.addChild(img);

	style = newChildStyle();
	p.addChild(new ParagraphText(style, " and this is the circle icon "));

	style = newChildStyle();
	img = new ImageLabel(style);
	img.setImage(Icon.CIRCLE);
	p.addChild(img);

	style = newChildStyle();
	p.addChild(new ParagraphText(style, " ."));

	style = newChildStyle();
	p.addChild(new ParagraphText(style, ""));

	style = newChildStyle();
	p.addChild(new ParagraphText(style, "\nThere are many more "));

	style = newChildStyle();
	img = new ImageLabel(style);
	img.setImage(Icon.DISC);
	p.addChild(img);

	style = newChildStyle();
	p.addChild(new ParagraphText(style, "icons"));

	style = newChildStyle();
	img = new ImageLabel(style);
	img.setImage(Icon.DISC);
	p.addChild(img);

	style = newChildStyle();
	p.addChild(new ParagraphText(style, " we are not showing here.\t\t"));
    }

    private static Style newChildStyle() {
	Style style = new Style();
	style.font = new Font("SansSerif", Font.PLAIN, 10);
	style.backgroundColor = Color.white;
	//style.lineHeight = 2.0;
	return style;
    }
}
