/*
 * Copyright (c) 2001 Pixware. 
 *
 * Author: Hussein Shafie
 *
 * This file is part of the XMLmind XML Editor project.
 * For conditions of distribution and use, see the accompanying legal.txt file.
 */
package com.xmlmind.xmledit.styledview;

import java.awt.Component;
import java.awt.event.ItemListener;
import java.awt.event.ItemEvent;
import javax.swing.JCheckBox;
import com.xmlmind.xmledit.model.ElementModel;
import com.xmlmind.xmledit.stylesheet.StyleValue;
import com.xmlmind.xmledit.styledgadget.Style;
import com.xmlmind.xmledit.modeltool.ElementUtil;

public class AttrCheckBoxFactory implements ComponentFactory {
    public Component createComponent(ElementModel element, 
				     Style style, StyleValue[] parameters, 
				     StyledViewFactory viewFactory,
				     boolean[] stretch) {
	if (parameters.length != 3)
	    return null;
	String attributeName = parameters[0].stringValue();
	if (attributeName == null)
	    return null;
	String offValue = parameters[1].stringValue();
	if (offValue == null)
	    return null;
	String onValue = parameters[2].stringValue();
	if (onValue == null)
	    return null;

	String attributeValue = 
	    ElementUtil.getElementAttribute(element, attributeName);
	if (attributeValue == null)
	    return null;

	AttrCheckBox checkBox =
	    new AttrCheckBox(element, attributeName, attributeValue,
			     offValue, onValue);

	checkBox.setFont(style.font);
	checkBox.setForeground(style.color);
	if (style.backgroundColor == null) {
	    checkBox.setOpaque(false);
	} else {
	    checkBox.setOpaque(true);
	    checkBox.setBackground(style.backgroundColor);
	}

	return checkBox;
    }

    private static class AttrCheckBox extends JCheckBox {
	private ElementModel element;
	private String attributeName;
	private String offValue;
	private String onValue;

	public AttrCheckBox(final ElementModel element, 
			    final String attributeName, String attributeValue, 
			    final String offValue, final String onValue) {
	    super(attributeName, attributeValue.equals(onValue));

	    this.element = element;
	    this.attributeName = attributeName;
	    this.offValue = offValue;
	    this.onValue = onValue;

	    addItemListener(new ItemListener() {
		public void itemStateChanged(ItemEvent e) {
		    String value = ((e.getStateChange()==ItemEvent.SELECTED)? 
				    onValue : offValue);
		    element.putElementAttribute(attributeName, value);
		}
	    });
	}
    }
}
