/*
 * Copyright (c) 2001 Pixware. 
 *
 * Author: Hussein Shafie
 *
 * This file is part of the XMLmind XML Editor project.
 * For conditions of distribution and use, see the accompanying legal.txt file.
 */
package com.xmlmind.xmledit.styledview;

import com.xmlmind.gadget.Gadget;
import com.xmlmind.xmledit.GadgetList;
import com.xmlmind.xmledit.model.ElementModel;
import com.xmlmind.xmledit.styledgadget.Style;

public class BlockGroupView extends GroupView {
    private Gadget startLabelGadget = null;
    private Gadget customViewGadget = null;
    private Gadget endLabelGadget = null;

    public BlockGroupView(ElementModel element, Style style) {
	super(element, style);
    }

    public void initView(ViewParameters param,
			 ViewParameters paramBefore, Style styleBefore,
			 ViewParameters paramAfter, Style styleAfter, 
			 StyledViewFactory viewFactory) {
	if (param.content != null)
	    customViewGadget = 
		contentToGadget(param.content, style, 
				StyledElementViewPart.ROLE_CUSTOM_VIEW, 
				/*noWrap*/ false, viewFactory);

	if (paramBefore != null && paramBefore.content != null)
	    startLabelGadget = 
		contentToGadget(paramBefore.content, styleBefore, 
				StyledElementViewPart.ROLE_START_LABEL, 
				/*noWrap*/ false, viewFactory);

	if (paramAfter != null && paramAfter.content != null)
	    endLabelGadget = 
		contentToGadget(paramAfter.content, styleAfter, 
				StyledElementViewPart.ROLE_END_LABEL, 
				/*noWrap*/ false, viewFactory);
    }

    public boolean isCustomView() {
	return (customViewGadget != null);
    }

    public boolean isInlineView() {
	return false;
    }

    public Gadget getStartLabelGadget() {
	return startLabelGadget;
    }

    public Gadget getCustomViewGadget() {
	return customViewGadget;
    }

    public Gadget getEndLabelGadget() {
	return endLabelGadget;
    }

    public void getStartLabelGadgets(GadgetList gadgetList) {
	if (startLabelGadget != null)
	    gadgetList.appendGadget(startLabelGadget);
    }

    public void getCustomViewGadgets(GadgetList gadgetList) {
	if (customViewGadget != null)
	    gadgetList.appendGadget(customViewGadget);
    }

    public void getEndLabelGadgets(GadgetList gadgetList) {
	if (endLabelGadget != null)
	    gadgetList.appendGadget(endLabelGadget);
    }
}
