/*
 * Copyright (c) 2001 Pixware. 
 *
 * Author: Hussein Shafie
 *
 * This file is part of the XMLmind XML Editor project.
 * For conditions of distribution and use, see the accompanying legal.txt file.
 */
package com.xmlmind.xmledit.styledview;

import com.xmlmind.gadget.Gadget;
import com.xmlmind.xmledit.GadgetList;
import com.xmlmind.xmledit.SubelementView;
import com.xmlmind.xmledit.model.ElementModel;
import com.xmlmind.xmledit.stylesheet.StyleValue;
import com.xmlmind.xmledit.styledgadget.Style;

public abstract class ContainerView extends ViewBase {
    protected static final byte CUSTOM_VIEW = 0x1;
    protected static final byte INLINE_VIEW = 0x2;

    protected byte flags = 0x0;
    private Gadget decorGadget = null;

    protected ContainerView(ElementModel element, Style style) {
	super(element, style);
    }

    public Gadget getGadget() {
	return ((decorGadget == null)? getViewGadget() : decorGadget);
    }

    public void getGadgets(GadgetList gadgetList, int viewIndex) {
	gadgetList.appendGadget((decorGadget == null)? 
				getViewGadget() : decorGadget);
    }

    protected abstract Gadget getViewGadget();

    public boolean isCustomView() {
	return ((flags & CUSTOM_VIEW) != 0);
    }

    public boolean isInlineView() {
	return ((flags & INLINE_VIEW) != 0);
    }

    public void initView(ViewParameters param,
			 ViewParameters paramBefore, 
			 Style styleBefore,
			 ViewParameters paramAfter,
			 Style styleAfter,
			 StyledViewFactory viewFactory) {
	StyledElementViewPart contentBefore = null;
	boolean markerBefore = false;
	StyledElementViewPart contentAfter = null;
	boolean markerAfter = false;

	if (paramBefore != null && paramBefore.content != null) {
	    markerBefore = (paramBefore.display == StyleValue.MARKER);
	    contentBefore = (StyledElementViewPart)
		contentToGadget(paramBefore.content, styleBefore, 
				StyledElementViewPart.ROLE_START_LABEL, 
				/*noWrap*/ markerBefore, viewFactory);
	} 
	if (paramAfter != null && paramAfter.content != null) {
	    markerAfter = (paramAfter.display == StyleValue.MARKER);
	    contentAfter = (StyledElementViewPart)
		contentToGadget(paramAfter.content, styleAfter,
				StyledElementViewPart.ROLE_END_LABEL, 
				/*noWrap*/ markerAfter, viewFactory);
	} 

	if (contentBefore == null && contentAfter == null)
	    // No decor.
	    return;

	StyledElementViewPart decoratedVP = 
	    (StyledElementViewPart) getViewGadget();
	int role = decoratedVP.getRole();

	if (markerBefore || markerAfter) {
	    // Move marginTop, marginBottom values from item to labeledItem ---

	    Style anonymousStyle = new Style();

	    anonymousStyle.marginTop = style.marginTop;
	    anonymousStyle.marginBottom = style.marginBottom;

	    Style noMarginStyle = style.duplicate();
	    noMarginStyle.marginTop = noMarginStyle.marginBottom = 0;
	    decoratedVP.setStyle(viewFactory.shareStyle(noMarginStyle));

	    LabeledItemVP labeledItem = 
		new LabeledItemVP(viewFactory.shareStyle(anonymousStyle), 
				  this, role);

	    labeledItem.setItem((Gadget) decoratedVP);
	    if (markerBefore) {
		labeledItem.setStartLabel((Gadget) contentBefore,
					  paramBefore.markerOffset);
		contentBefore = null;
	    }
	    if (markerAfter) {
		labeledItem.setEndLabel((Gadget) contentAfter,
					paramAfter.markerOffset);
		contentAfter = null;
	    }

	    decoratedVP = labeledItem;
	    decorGadget = labeledItem;
	}

	if (contentBefore != null || contentAfter != null) {
	    // Move marginTop for first block to div ---

	    Style anonymousStyle = new Style();

	    StyledElementViewPart beforeVP = 
		((contentBefore == null)? decoratedVP : contentBefore);
	    Style beforeVPStyle = beforeVP.getStyle();

	    anonymousStyle.marginTop = beforeVPStyle.marginTop;

	    Style noMarginTopStyle = beforeVPStyle.duplicate();
	    noMarginTopStyle.marginTop = 0;
	    beforeVP.setStyle(viewFactory.shareStyle(noMarginTopStyle));

	    // Move marginBottom from last block to div ---

	    StyledElementViewPart afterVP = 
		((contentAfter == null)? decoratedVP : contentAfter);
	    Style afterVPStyle = afterVP.getStyle();

	    anonymousStyle.marginBottom = afterVPStyle.marginBottom;

	    Style noMarginBottomStyle = afterVPStyle.duplicate();
	    noMarginBottomStyle.marginBottom = 0;
	    afterVP.setStyle(viewFactory.shareStyle(noMarginBottomStyle));

	    DivisionVP div = 
		new DivisionVP(viewFactory.shareStyle(anonymousStyle), 
			       this, role);

	    if (contentBefore != null)
		div.addChild((Gadget) contentBefore);
	    div.addChild((Gadget) decoratedVP);
	    if (contentAfter != null)
		div.addChild((Gadget) contentAfter);

	    decorGadget = div;
	}
    }
}
