/*
 * Copyright (c) 2001 Pixware. 
 *
 * Author: Hussein Shafie
 *
 * This file is part of the XMLmind XML Editor project.
 * For conditions of distribution and use, see the accompanying legal.txt file.
 */
package com.xmlmind.xmledit.styledview;

import com.xmlmind.gadget.Gadget;
import com.xmlmind.xmledit.SubelementView;
import com.xmlmind.xmledit.ElementView;
import com.xmlmind.xmledit.GadgetList;
import com.xmlmind.xmledit.model.SubelementModel;
import com.xmlmind.xmledit.model.ElementModel;
import com.xmlmind.xmledit.styledgadget.Style;

public abstract class GroupView extends ViewBase {
    protected GroupView(ElementModel element, Style style) {
	super(element, style);
    }

    public void getGadgets(GadgetList gadgetList, int viewIndex) {
	getStartLabelGadgets(gadgetList);

	if (isCustomView()) {
	    getCustomViewGadgets(gadgetList);
	} else {
	    SubelementModel sub = element.getFirstSubelement();
	    while (sub != null) {
		SubelementView subView = 
		    (SubelementView) sub.getDocumentListenerData(viewIndex);

		if (subView != null)
		    subView.getGadgets(gadgetList, viewIndex);

		sub = sub.getNextSubelement();
	    }
	}

	getEndLabelGadgets(gadgetList);
    }

    public abstract void getStartLabelGadgets(GadgetList gadgetList);
    public abstract void getCustomViewGadgets(GadgetList gadgetList);
    public abstract void getEndLabelGadgets(GadgetList gadgetList);

    public Gadget addChildViewGadgets(SubelementView childView, 
				      int viewIndex) {
	// If the GroupView has not yet been ``attached'' to a container
	// findContainerView() returns null. Otherwise, it always returns a
	// ContainerView ancestor because the root element cannot be a group.

	ContainerView containerView = findContainerView(element, viewIndex);
	if (containerView == null)
	    return null;
	else
	    return containerView.addChildViewGadgets(childView, viewIndex);
    }

    public Gadget removeChildViewGadgets(SubelementView childView, 
					 int viewIndex) {
	ContainerView containerView = findContainerView(element, viewIndex);
	if (containerView == null)
	    return null;
	else
	    return containerView.removeChildViewGadgets(childView, viewIndex);
    }

    private static final ContainerView findContainerView(ElementModel element, 
							 int viewIndex) {
	while (element != null) {
	    ElementView view = 
		(ElementView) element.getDocumentListenerData(viewIndex);

	    if (view == null)
		// Ancestor not yet ``attached'' to a container.
		return null;

	    if (view instanceof ContainerView)
		return (ContainerView) view;

	    element = element.getParentElement();
	}

	return null;
    }
}
