/*
 * Copyright (c) 2001 Pixware. 
 *
 * Author: Hussein Shafie
 *
 * This file is part of the XMLmind XML Editor project.
 * For conditions of distribution and use, see the accompanying legal.txt file.
 */
package com.xmlmind.xmledit.styledview;

import com.xmlmind.gadget.Gadget;
import com.xmlmind.xmledit.GadgetList;
import com.xmlmind.xmledit.model.ElementModel;
import com.xmlmind.xmledit.model.TextAccess;
import com.xmlmind.xmledit.stylesheet.StyleValue;
import com.xmlmind.xmledit.styledgadget.Style;
import com.xmlmind.xmledit.styledgadget.Paragraph;
import com.xmlmind.xmledit.styledgadget.ParagraphText;

public class InlineGroupView extends GroupView {
    private Gadget[] startLabelGadgets = null;
    private Gadget[] customViewGadgets = null;
    private Gadget[] endLabelGadgets = null;

    public InlineGroupView(ElementModel element, Style style) {
	super(element, style);
    }

    public void initView(ViewParameters param,
			 ViewParameters paramBefore,
			 Style styleBefore,
			 ViewParameters paramAfter,
			 Style styleAfter,
			 StyledViewFactory viewFactory) {
	if (paramBefore != null && paramBefore.content != null)
	    startLabelGadgets = 
		convertTextLabels(paramBefore.content, 
				  StyledElementViewPart.ROLE_START_LABEL);

	if (param.content != null)
	    customViewGadgets = 
		convertTextLabels(param.content, 
				  StyledElementViewPart.ROLE_CUSTOM_VIEW);

	if (paramAfter != null && paramAfter.content != null)
	    endLabelGadgets = 
		convertTextLabels(paramAfter.content, 
				  StyledElementViewPart.ROLE_END_LABEL);
    }

    /**
     * Convert TextLabelVPs that does not support word wrap to ParagraphTextVPs
     * that support word wrap when added to ParagraphVPs.
     *
     * Note that CounterManager.CounterVP is a subclass of TextLabel 
     * and not of TextLabelVP.
     */
    private Gadget[] convertTextLabels(StyledElementViewPart[] content,
				       int role) {
	Gadget[] gadgets = new Gadget[content.length];

	for (int i = 0; i < content.length; ++i) {
	    StyledElementViewPart part = content[i];

	    if (part instanceof TextLabelVP) {
		TextLabelVP textLabel = (TextLabelVP) part;

		part = new ParagraphTextVP(textLabel.getStyle(), 
					   textLabel.getText(),
					   this, role);
	    }

	    gadgets[i] = (Gadget) part;
	}

	return gadgets;
    }

    public boolean isCustomView() {
	return (customViewGadgets != null);
    }

    public boolean isInlineView() {
	return true;
    }

    public Gadget[] getStartLabelGadgets() {
	return startLabelGadgets;
    }

    public Gadget[] getCustomViewGadgets() {
	return customViewGadgets;
    }

    public Gadget[] getEndLabelGadgets() {
	return endLabelGadgets;
    }

    public void getStartLabelGadgets(GadgetList gadgetList) {
	if (startLabelGadgets != null)
	    appendGadgets(startLabelGadgets, gadgetList);
    }

    public void getCustomViewGadgets(GadgetList gadgetList) {
	if (customViewGadgets != null)
	    appendGadgets(customViewGadgets, gadgetList);
    }

    public void getEndLabelGadgets(GadgetList gadgetList) {
	if (endLabelGadgets != null)
	    appendGadgets(endLabelGadgets, gadgetList);
    }

    private static final void appendGadgets(Gadget[] gadgets, 
					    GadgetList gadgetList) {
	for (int i = 0; i < gadgets.length; ++i) {
	    Gadget gadget = gadgets[i];

	    if (gadget instanceof ParagraphText && gadget.parent != null) {
		TextAccess text = ((ParagraphText) gadget).getTextAccess();

		((Paragraph) gadget.parent).getParagraphTexts(text, 
							      gadgetList);
	    } else {
		gadgetList.appendGadget(gadget);
	    }
	}
    }
}
