/*
 * Copyright (c) 2000-2001 Pixware. 
 *
 * Author: Hussein Shafie
 *
 * This file is part of the XMLmind XML Editor project.
 * For conditions of distribution and use, see the accompanying legal.txt file.
 */
package com.xmlmind.xmledit.styledview;

import java.awt.Graphics;
import java.awt.Color;
import java.awt.FontMetrics;
import com.xmlmind.awtutil.Bitmap;
import com.xmlmind.gadget.Gadget;
import com.xmlmind.xmledit.SubelementView;
import com.xmlmind.xmledit.TextView;
import com.xmlmind.xmledit.RectangleList;
import com.xmlmind.xmledit.TextViewPart;
import com.xmlmind.xmledit.model.TextModel;
import com.xmlmind.xmledit.styledgadget.*;

public class ParagraphTextViewPart extends ParagraphText 
                                   implements TextViewPart {

    // -----------------------------------------------------------------------
    // ParagraphText
    // -----------------------------------------------------------------------

    public ParagraphText copy() {
	ParagraphTextViewPart copy = 
	    new ParagraphTextViewPart(style, (TextModel) text);
	copy.parent = parent;

	//Style style2 = this.style.duplicate();
	//style2.backgroundColor = Color.orange;
	//copy.style = style2;

	return copy;
    }

    public ParagraphTextViewPart(Style style, TextModel text) {
	super(style, text);
    }

    public void paint(Graphics g) {
	if (style.backgroundColor != null) {
	    g.setColor(style.backgroundColor);
	    g.fillRect(0, 0, width, height);
	}
    }

    // -----------------------------------------------------------------------
    // TextViewPart
    // -----------------------------------------------------------------------

    public SubelementView getView() {
	return getTextView();
    }

    public TextView getTextView() {
	return (TextView) ((Paragraph) parent).getFirstParagraphText(text);
    }

    public int gadgetToModel(int x, int y) {
	char[] textChars = text.getTextChars();
	int textLength = text.getTextLength();
	int offset = rangeOffset;
	int length = rangeLength;

	// The text accessed may have changed and we may have a range
	// range temporarily out of sync.
	if (offset >= textLength)
	    return textLength;

	if (offset + length > textLength)
	    length = textLength - offset;

	FontMetrics metrics = getFontMetrics(style.font);
	int w;
	while (length > 1) {
	    int halfLength = length/2;
	    w = metrics.charsWidth(textChars, offset, halfLength);
	    if (x < w) {
		length = halfLength;
	    } else {
		x -= w;
		offset += halfLength;
		length -= halfLength;
	    }
	}
	// A char such as '\n' has no width: do not systematically skip it.
        w = metrics.charWidth(textChars[offset])/2;
	if (w > 0 && x >= w)
	    ++offset;

	return offset;
    }

    public int modelToGadget(int offset, int length, 
			     RectangleList rectangles) {
	char[] textChars = text.getTextChars();
	int textLength = text.getTextLength();
	int firstChar = rangeOffset;
	int charCount = rangeLength;

	// The text accessed may have changed and we may have a range
	// range temporarily out of sync.
	if (firstChar > textLength)
	    return 0;

	if (firstChar + charCount > textLength)
	    charCount = textLength - firstChar;

	FontMetrics metrics = getFontMetrics(style.font);
	int lineHeight = (int) (0.5 + metrics.getHeight()*style.lineHeight);

	if (charCount == 0) {
	    if (offset == firstChar) {
		rectangles.appendRectangle(0, 0, 0, lineHeight);
		return 1;
	    } else {
		return 0;
	    }
	}

	if (offset < firstChar) {
	    length -= (firstChar - offset);
	    if (length < 0)
		// No intersection.
		return 0;
	    offset = firstChar;
	}

	int endChar = firstChar + charCount;
	if (offset + length > endChar) {
	    length = endChar - offset;
	    if (length < 0)
		// No intersection.
		return 0;
	}

	int rx, rw;
	if (offset == endChar) {
	    if (offset != textLength)
		// Offset inside next TextViewPart.
		return 0;
		
	    if (textChars[endChar-1] == '\n') 
		rx = metrics.charsWidth(textChars, firstChar, charCount-1) +
		    Icon.list[Icon.LINE_BREAK].width;
	    else 
		rx = metrics.charsWidth(textChars, firstChar, charCount);

	    rw = 0;
	} else {
	    rx = metrics.charsWidth(textChars, firstChar, offset-firstChar);

	    if (offset + length == endChar) {
		// Note that in this branch, length cannot be null.
		rw = metrics.charsWidth(textChars, offset, length-1);

		switch (textChars[endChar-1]) {
		case '\n':
		    if (endChar == textLength)
			rw += Icon.list[Icon.LINE_BREAK].width;
		    break;
		case ' ': case '\r': case '\t':
		    if (endChar != textLength)
			// Space char where the word wrap occurs is not drawn.
			break;
		    /*FALLTHROUGH*/
		default:
		    rw += metrics.charWidth(textChars[endChar-1]);
		}
	    } else {
		rw = metrics.charsWidth(textChars, offset, length);
	    }
	}

	rectangles.appendRectangle(rx, 0, rw, lineHeight);
	return 1;
    }
}

