/*
 * Copyright (c) 2001 Pixware. 
 *
 * Author: Hussein Shafie
 *
 * This file is part of the XMLmind XML Editor project.
 * For conditions of distribution and use, see the accompanying legal.txt file.
 */
package com.xmlmind.xmledit.styledview;

import com.xmlmind.gadget.Gadget;
import com.xmlmind.xmledit.DocumentView;
import com.xmlmind.xmledit.model.SubelementModel;
import com.xmlmind.xmledit.model.ElementModel;
import com.xmlmind.xmledit.styledgadget.Style;

public abstract class ViewBase implements StyledElementView {
    protected ElementModel element;
    protected Style style;

    protected ViewBase(ElementModel element, Style style) {
	this.element = element;
	this.style = style;
    }

    public Style getStyle() {
	return style;
    }

    public SubelementModel getModel() {
	return element;
    }

    public ElementModel getElement() {
	return element;
    }

    protected Gadget contentToGadget(StyledElementViewPart[] content,
				     Style contentStyle,
				     int role,
				     boolean noWrap, 
				     StyledViewFactory viewFactory) {
	if (content.length == 1) {
	    StyledElementViewPart part = content[0];

	    // If word wrap is needed, convert TextLabelVP to a ParagraphVP
	    // containing a ParagraphTextVP.

	    if (noWrap || !(part instanceof TextLabelVP)) {
		// Content parts cannot have a Box around them.
		// This single part being the whole generated content,
		// attach the right style (possibly having a box) to it.
		part.setStyle(contentStyle);

		return (Gadget) part;
	    }
	}

	Style paragraphStyle;
	if (noWrap) {
	    if (contentStyle.whiteSpace == Style.WHITE_SPACE_NOWRAP) {
		paragraphStyle = contentStyle;
	    } else {
		paragraphStyle = contentStyle.duplicate();
		paragraphStyle.whiteSpace = Style.WHITE_SPACE_NOWRAP;
		paragraphStyle = viewFactory.shareStyle(paragraphStyle);
	    } 
	} else {
	    paragraphStyle = contentStyle;
	}

	ParagraphVP paragraph = new ParagraphVP(paragraphStyle, this, role);

	for (int i = 0; i < content.length; ++i) {
	    Gadget child;

	    // Convert TextLabelVPs that does not support word wrap to
	    // ParagraphTextVPs that support word wrap when added to
	    // ParagraphVPs.
	    //
	    // Note that CounterManager.CounterVP is a subclass of
	    // TextLabel and not of TextLabelVP.

	    if (content[i] instanceof TextLabelVP) {
		TextLabelVP textLabel = (TextLabelVP) content[i];

		child = new ParagraphTextVP(textLabel.getStyle(), 
					    textLabel.getText(),
					    this, role);
	    } else {
		child = (Gadget) content[i];
	    }

	    paragraph.addChild(child);
	}

	return paragraph;
    }

    protected StyledViewFactory getViewFactory(int viewIndex) {
	DocumentView docView = (DocumentView) 
	    element.getDocument().getDocumentListener(viewIndex, 
                                                      /*hasData*/ true);
	return (StyledViewFactory) docView.getViewFactory();
    }
}
