/*
 * Copyright (c) 2000-2001 Pixware. 
 *
 * Author: Hussein Shafie
 *
 * This file is part of the XMLmind XML Editor project.
 * For conditions of distribution and use, see the accompanying legal.txt file.
 */
package com.xmlmind.xmledit.stylesheet;

public class StyleSpec implements Cloneable {
    public StyleValue marginTop = null;
    public StyleValue marginRight = null;
    public StyleValue marginBottom = null;
    public StyleValue marginLeft = null;

    public StyleValue paddingTop = null;
    public StyleValue paddingRight = null;
    public StyleValue paddingBottom = null;
    public StyleValue paddingLeft = null;

    public StyleValue borderStyle = null;
    public StyleValue borderWidth = null;
    public StyleValue borderTopColor = null;
    public StyleValue borderRightColor = null;
    public StyleValue borderBottomColor = null;
    public StyleValue borderLeftColor = null;

    public StyleValue backgroundColor = null;
    public StyleValue color = null;

    public StyleValue fontFamily = null;
    public StyleValue fontStyle = null;
    public StyleValue fontWeight = null;
    public StyleValue fontSize = null;

    public StyleValue textDecoration = null;

    public StyleValue textAlign = null;
    public StyleValue textIndent = null;

    public StyleValue verticalAlign = null;

    public StyleValue lineHeight = null;

    public StyleValue whiteSpace = null;

    // Cannot be expressed in terms of Style and thus cannot be inherited.
    // However these properties are used by the ViewFactory. ---

    public StyleValue display = null;

    public StyleValue content = null;

    public StyleValue markerOffset = null;

    public StyleValue width = null;
    public StyleValue height = null;

    public StyleValue captionSide = null;

    public StyleValue borderHorizontalSpacing = null;
    public StyleValue borderVerticalSpacing = null;

    public StyleValue rowSpan = null;
    public StyleValue columnSpan = null;

    // -----------------------------------------------------------------------

    public void clear() {
        marginTop = null;
        marginRight = null;
        marginBottom = null;
        marginLeft = null;

        paddingTop = null;
        paddingRight = null;
        paddingBottom = null;
        paddingLeft = null;

        borderStyle = null;
        borderWidth = null;
        borderTopColor = null;
        borderRightColor = null;
        borderBottomColor = null;
        borderLeftColor = null;

        backgroundColor = null;
        color = null;

        fontFamily = null;
        fontStyle = null;
        fontWeight = null;
        fontSize = null;

        textDecoration = null;

        textAlign = null;
        textIndent = null;

        verticalAlign = null;

        lineHeight = null;

        whiteSpace = null;

        display = null;

        content = null;

        markerOffset = null;

        width = null;
        height = null;

	captionSide = null;

        borderHorizontalSpacing = null;
        borderVerticalSpacing = null;

        rowSpan = null;
        columnSpan = null;
    }

    public void put(StyleSpec other) {
        if (other.marginTop != null)
	    marginTop = other.marginTop;
        if (other.marginRight != null)
	    marginRight = other.marginRight;
        if (other.marginBottom != null)
	    marginBottom = other.marginBottom;
        if (other.marginLeft != null)
	    marginLeft = other.marginLeft;

        if (other.paddingTop != null)
	    paddingTop = other.paddingTop;
        if (other.paddingRight != null)
	    paddingRight = other.paddingRight;
        if (other.paddingBottom != null)
	    paddingBottom = other.paddingBottom;
        if (other.paddingLeft != null)
	    paddingLeft = other.paddingLeft;

        if (other.borderStyle != null)
	    borderStyle = other.borderStyle;
        if (other.borderWidth != null)
	    borderWidth = other.borderWidth;
        if (other.borderTopColor != null)
	    borderTopColor = other.borderTopColor;
        if (other.borderRightColor != null)
	    borderRightColor = other.borderRightColor;
        if (other.borderBottomColor != null)
	    borderBottomColor = other.borderBottomColor;
        if (other.borderLeftColor != null)
	    borderLeftColor = other.borderLeftColor;

        if (other.backgroundColor != null)
	    backgroundColor = other.backgroundColor;
        if (other.color != null)
	    color = other.color;

        if (other.fontFamily != null)
	    fontFamily = other.fontFamily;
        if (other.fontStyle != null)
	    fontStyle = other.fontStyle;
        if (other.fontWeight != null)
	    fontWeight = other.fontWeight;
        if (other.fontSize != null)
	    fontSize = other.fontSize;

        if (other.textDecoration != null)
	    textDecoration = other.textDecoration;

        if (other.textAlign != null)
	    textAlign = other.textAlign;
        if (other.textIndent != null)
	    textIndent = other.textIndent;

        if (other.verticalAlign != null)
	    verticalAlign = other.verticalAlign;

        if (other.lineHeight != null)
	    lineHeight = other.lineHeight;

        if (other.whiteSpace != null)
	    whiteSpace = other.whiteSpace;

        if (other.display != null)
	    display = other.display;

        if (other.content != null)
	    content = other.content;

        if (other.markerOffset != null)
	    markerOffset = other.markerOffset;

        if (other.width != null)
	    width = other.width;
        if (other.height != null)
	    height = other.height;

        if (other.captionSide != null)
	    captionSide = other.captionSide;

        if (other.borderHorizontalSpacing != null)
	    borderHorizontalSpacing = other.borderHorizontalSpacing;
        if (other.borderVerticalSpacing != null)
	    borderVerticalSpacing = other.borderVerticalSpacing;

        if (other.rowSpan != null)
	    rowSpan = other.rowSpan;
        if (other.columnSpan != null)
	    columnSpan = other.columnSpan;
    }

    public StyleSpec duplicate() {
	StyleSpec copy;

	try {
	    copy = (StyleSpec) clone();
	} catch (CloneNotSupportedException e) {
	    e.printStackTrace();
	    copy = null;
	}

	return copy;
    }
}


