/*
 * Copyright (c) 2000-2001 Pixware. 
 *
 * Author: Hussein Shafie
 *
 * This file is part of the XMLmind XML Editor project.
 * For conditions of distribution and use, see the accompanying legal.txt file.
 */

import com.xmlmind.xmledit.model.*;
import com.xmlmind.xmledit.modeltool.*;
import com.xmlmind.xmledit.modelimpl.*;
import com.xmlmind.xmledit.stylesheet.*;

public class TestLoader {
    public static void main(String[] args) throws Exception {
	if (args.length != 2) {
	    System.err.println(
		"usage: java TestLoader css_in_file css_out_file");
	    System.exit(1);
	}

	StyleSheetLoader loader = new StyleSheetLoader();
	StyleSheet styleSheet = new StyleSheet();

	loader.load(args[0], styleSheet);

	StyleSheetLoader.Warning[] warnings = loader.getWarnings();
	if (warnings.length > 0) {
	    for (int i = 0; i < warnings.length; ++i) {
		StyleSheetLoader.Warning w = warnings[i];
		String description;

		switch (w.type) {
		case StyleSheetLoader.UNSUPPORTED_PROPERTY:
		    description = "unsupported property";
		    break;
		case StyleSheetLoader.UNSUPPORTED_PROPERTY_VALUE:
		    description = "unsupported property value";
		    break;
		default:
		    description = "parse error";
		}

		System.err.println(description + 
				   " in " + w.url.toExternalForm() +
				   " at line " + w.lineNumber + 
				   " , col. " +  w.columnNumber + 
				   ": " + w.detail);
	    }
	}

	StyleSheetWriter.writeStyleSheet(styleSheet, args[1]);
    }
}
