/*
 * Copyright (c) 2000-2001 Pixware. 
 *
 * Author: Hussein Shafie
 *
 * This file is part of the XMLmind XML Editor project.
 * For conditions of distribution and use, see the accompanying legal.txt file.
 */

import java.io.*;
import com.xmlmind.xmledit.model.*;
import com.xmlmind.xmledit.modeltool.*;
import com.xmlmind.xmledit.modelimpl.*;
import com.xmlmind.xmledit.stylesheet.*;

public class TestMatcher {
    public static void main(String[] args) throws Exception {
	if (args.length != 3) {
	    System.err.println(
		"usage: java TestMatcher xml_in_file css_in_file out_file");
	    System.exit(1);
	}

	Document document = new Document();
	XPDocumentLoader docLoader = new XPDocumentLoader();
	docLoader.setGuessingElementContent(true);
	docLoader.load(args[0], document);

	StyleSheetLoader loader = new StyleSheetLoader();
	final StyleSheet styleSheet = new StyleSheet();

	loader.load(args[1], styleSheet);

	StyleSheetLoader.Warning[] warnings = loader.getWarnings();
	if (warnings.length > 0) {
	    for (int i = 0; i < warnings.length; ++i) {
		StyleSheetLoader.Warning w = warnings[i];
		String description;

		switch (w.type) {
		case StyleSheetLoader.UNSUPPORTED_PROPERTY:
		    description = "unsupported property";
		    break;
		case StyleSheetLoader.UNSUPPORTED_PROPERTY_VALUE:
		    description = "unsupported property value";
		    break;
		default:
		    description = "parse error";
		}

		System.err.println(description + 
				   " in " + w.url.toExternalForm() +
				   " at line " + w.lineNumber + 
				   " , col. " +  w.columnNumber + 
				   ": " + w.detail);
	    }
	    System.exit(2);
	}

	final PrintWriter out = new PrintWriter(new FileWriter(args[2]));

	try {
	    Traversal.traverse(document.getRootElement(), 
			       new Traversal.HandlerBase() {
		private StyleSpec[] specs = new StyleSpec[3]; 
                {
		    for (int j = 0; j < 3; ++j)
			specs[j] = new StyleSpec();
		}

		public Object enterElement(ElementModel element) {
		    for (int j = 0; j < 3; ++j)
			specs[j].clear();

		    int found = styleSheet.findStyleSpec(element, specs);

		    for (int j = 0; j < 3; ++j) {
			if ((found & (1 << j)) != 0)
			    print(element, j, specs[j]);
		    }

		    return null;
		}

		private void print(ElementModel element, int pseudoElement, 
				   StyleSpec spec) {
		    out.print(element.getElementTypeName());
		    switch (pseudoElement) {
		    case StyleSheet.BEFORE_ELEMENT:
			out.print(":before");
			break;
		    case StyleSheet.AFTER_ELEMENT:
			out.print(":after");
			break;
		    }
		    out.print(' ');

		    try {
			StyleSheetWriter.writeStyleSpec(spec, out);
		    } catch (IOException ignored) {
			ignored.printStackTrace();
		    }

		    out.println();
		}
            });
	} finally {
	    out.flush();
	    out.close();
	}
    }
}
