/*
 * Copyright (c) 2001 Pixware. 
 *
 * Author: Hussein Shafie
 *
 * This file is part of the XMLmind XML Editor project.
 * For conditions of distribution and use, see the accompanying legal.txt file.
 */
package com.xmlmind.xmleditapp;

import java.util.ResourceBundle;
import java.util.MissingResourceException;
import java.awt.*;
import java.awt.event.*;
import javax.swing.*;
import com.xmlmind.xmledit.model.DocumentModel;
import com.xmlmind.xmledit.model.ElementModel;
import com.xmlmind.attedit.JAttributesPane;

public class AttributesTool extends Tool implements ActionListener {
    private JAttributesPane attrPane;

    // -----------------------------------------------------------------------

    private static ResourceBundle resourceBundle = null;
    static {
	try {
	    resourceBundle = ResourceBundle.getBundle(
		"com.xmlmind.xmleditapp.AttributesToolRes");
	} catch (MissingResourceException ignored) {}
    }

    private static String msg(String id) {
	String message = null;
	try {
	    message = resourceBundle.getString(id);
	} catch (Exception e) {
	    return id;
	}
	return message;
    }

    // -----------------------------------------------------------------------

    public AttributesTool(Frame frame) {
	super(frame, msg("title"), /*top*/ true, /*right*/ true);
	
        // workArea is a JPanel with a BorderLayout.
	JPanel workArea = (JPanel) getContentPane();
	workArea.setLayout(new GridBagLayout());

        GridBagConstraints constraints = new GridBagConstraints();
        constraints.insets.top = 5;
        constraints.insets.left = 5;
        constraints.insets.right = 5;
        constraints.insets.bottom = 5;
        constraints.gridx = 0;
        constraints.gridy = 0;

	attrPane = new JAttributesPane();
	constraints.fill = GridBagConstraints.BOTH;
	constraints.weightx = 1;
	constraints.weighty = 1;
	workArea.add(attrPane, constraints);
	++constraints.gridy;

	JButton closeButton = new JButton(msg("close"));
        constraints.insets.top = 0;
        constraints.fill = GridBagConstraints.NONE;
        constraints.weightx = 0;
	constraints.weighty = 0;
	workArea.add(closeButton, constraints);
	closeButton.addActionListener(this);
	closeButton.setMnemonic(closeButton.getText().charAt(0));

	pack();
	setResizable(true);
    }

    public void actionPerformed(ActionEvent e) {
	close();
    }

    protected void close() {
	setElement(null);

	hide();
	dispose();
    }

    public void setDocument(DocumentModel document) {
	attrPane.setDocument(document);
    }

    public DocumentModel getDocument() {
	return attrPane.getDocument();
    }

    public void setElement(ElementModel element) {
	attrPane.setElement(element);

	String title = getTitle();
	int pos = title.indexOf(" : ");
	if (pos >= 0)
	    title = title.substring(0, pos);

	if (element != null) {
	    StringBuffer buffer = new StringBuffer();
	    buffer.append(title);
	    buffer.append(" : ");
	    buffer.append(element.getElementTypeName());
	    title = buffer.toString();
	}

	setTitle(title);
    }

    public ElementModel getElement() {
	return attrPane.getElement();
    }
}
