/*
 * Copyright (c) 2000-2001 Pixware. 
 *
 * Author: Hussein Shafie
 *
 * This file is part of the XMLmind XML Editor project.
 * For conditions of distribution and use, see the accompanying legal.txt file.
 */
package com.xmlmind.xmleditapp;

import java.io.File;
import java.net.URL;
import java.net.MalformedURLException;
import java.util.Vector;
import java.util.ResourceBundle;
import java.util.MissingResourceException;
import java.text.MessageFormat;
import java.awt.*;
import java.awt.event.*;
import javax.swing.*;
import javax.swing.event.ListSelectionListener;
import javax.swing.event.ListSelectionEvent;
import fr.pixware.util.FileUtil;
import com.xmlmind.swingutil.FileChooserUtil;
import com.xmlmind.awtutil.ImageResource;

public class CreateDialog extends JDialog 
                          implements ActionListener, ListSelectionListener {
    private Frame frame;
    private JTextField entry;
    private JButton discard;
    private JList list;
    private Vector templateNames = null;
    private String result = null;

    // -----------------------------------------------------------------------

    private static ResourceBundle resourceBundle = null;
    static {
	try {
	    resourceBundle = ResourceBundle.getBundle(
		"com.xmlmind.xmleditapp.CreateDialogRes");
	} catch (MissingResourceException ignored) {}
    }

    private static String msg(String id) {
	String message = null;
	try {
	    message = resourceBundle.getString(id);
	} catch (Exception e) {
	    return id;
	}
	return message;
    }

    private static String msg(String id, Object arg0) {
	String message = null;
	try {
	    message = resourceBundle.getString(id);
	} catch (Exception e) {
	    return id;
	}
	return MessageFormat.format(message, new Object[] { arg0 });
    }

    // -----------------------------------------------------------------------

    public CreateDialog(Frame frame) {
	super(frame, msg("title"), /*modal*/ true); 

	this.frame = frame;

   	addWindowListener(new WindowAdapter() {
   	    public void windowClosing(WindowEvent e) {
   	        cancel();
   	    }
   	});

        // workArea is a JPanel with a BorderLayout.
	JPanel workArea = (JPanel) getContentPane();
	workArea.setLayout(new GridBagLayout());

	// Should be implemented by all LAFs.
	workArea.registerKeyboardAction(
	    this, "cancel", KeyStroke.getKeyStroke(KeyEvent.VK_ESCAPE, 0), 
	    JPanel.WHEN_ANCESTOR_OF_FOCUSED_COMPONENT);

        GridBagConstraints constraints = new GridBagConstraints();
        constraints.insets.top = 5;
        constraints.insets.bottom = 5;
        constraints.insets.left = 5;
        constraints.insets.right = 5;

	JPanel form = new JPanel(new GridBagLayout());
        constraints.gridx = 0;
        constraints.gridy = 0;
	constraints.fill = GridBagConstraints.BOTH;
	constraints.weightx = 1;
	constraints.weighty = 1;
	workArea.add(form, constraints);

        GridBagConstraints constraints2 = new GridBagConstraints();
	constraints2.anchor = GridBagConstraints.WEST;
        constraints2.gridx = 0;
        constraints2.gridy = 0;

	JLabel entryLabel = new JLabel(msg("entry"));
	constraints2.fill = GridBagConstraints.HORIZONTAL;
	constraints2.weightx = 1;
	form.add(entryLabel, constraints2);
	++constraints2.gridx;

	discard = new JButton(new ImageIcon(
	    ImageResource.get(getClass(), "discard.gif")));
	discard.setEnabled(false);
	Insets margin = new Insets(1, 1, 1, 1);
	discard.setMargin(margin);
	discard.setActionCommand("discard");
	discard.addActionListener(this);
	constraints2.fill = GridBagConstraints.NONE;
	constraints2.weightx = 0;
        constraints2.insets.bottom = 2;
	form.add(discard, constraints2);
	++constraints2.gridx;

	JButton browse = new JButton(new ImageIcon(
	    ImageResource.get(getClass(), "browse.gif")));
	browse.setMargin(margin);
	browse.setActionCommand("browse");
	browse.addActionListener(this);
        constraints2.insets.left = 5;
	form.add(browse, constraints2);
	++constraints2.gridy;

	entry = new JTextField(50);
	constraints2.gridx = 0;
        constraints2.gridwidth = 3;
	constraints2.fill = GridBagConstraints.HORIZONTAL;
	constraints2.weightx = 1;
        constraints2.insets.left = 0;
	form.add(entry, constraints2);
	++constraints2.gridy;
	entry.setActionCommand("ok");
	entry.addActionListener(this);

	list = new JList(new DefaultListModel());
	list.setVisibleRowCount(10);
	list.addListSelectionListener(this);
	list.addMouseListener(new MouseAdapter() {
	    public void mouseClicked(MouseEvent e) {
		if (e.getClickCount() == 2) {
		    ok();
		}
	    }
	});
	constraints2.fill = GridBagConstraints.BOTH;
	constraints2.weighty = 1;
        constraints2.insets.bottom = 0;
	form.add(new JScrollPane(list), constraints2);
	++constraints2.gridy;
	
	// Buttons ---

	JPanel buttons = new JPanel(new GridLayout(1, 2, 10, 0));
        constraints.insets.top = 0;
        constraints.gridx = 0;
        constraints.gridy = 1;
        constraints.fill = GridBagConstraints.NONE;
        constraints.weightx = 0;
	constraints.weighty = 0;
	workArea.add(buttons, constraints);

        JButton button = new JButton(msg("ok"));
	button.setActionCommand("ok");
	button.addActionListener(this);
        buttons.add(button);
	getRootPane().setDefaultButton(button);
          
        button = new JButton(msg("cancel"));
        button.setActionCommand("cancel");
        button.addActionListener(this);
        buttons.add(button);

        pack();
	setResizable(true);
    }

    public String getTemplateName(Vector templateNames) {
	this.templateNames = templateNames;

	DefaultListModel model = (DefaultListModel) list.getModel();
	model.removeAllElements();
	int count = templateNames.size();
	for (int i = 0; i < count; ++i)
	    model.addElement(templateNames.elementAt(i));
	list.ensureIndexIsVisible(0);

	if (count > 0) {
	    entry.setText((String) templateNames.elementAt(0));
	    entry.selectAll();
	}

	discard.setEnabled(false);

	setLocationRelativeTo(frame);
	pack();
        show();
        // Modal means blocked here until OK or Cancel are pressed.

        return result;
    }

    // -----------------------------------------------------------------------

    public void valueChanged(ListSelectionEvent e) {
	String selection = (String) list.getSelectedValue();
	if (selection == null) {
	    entry.setText("");
	    discard.setEnabled(false);
	} else {
	    entry.setText(selection);
	    discard.setEnabled(true);
	}
    }

    public void actionPerformed(ActionEvent e) {
        String command = e.getActionCommand();

        if (command.equals("ok"))
            ok();
        else if (command.equals("cancel"))
            cancel();
        else if (command.equals("browse"))
            browse();
        else if (command.equals("discard"))
            discard();
    }
    
    private void browse() {
	String selection = entry.getText().trim();
	String previousFileName = null;

	if (selection.length() > 0)
	    previousFileName = FileUtil.urlToFileName(selection);

	if (previousFileName == null && templateNames.size() > 0)
	    previousFileName = 
		FileUtil.urlToFileName((String) templateNames.elementAt(0));

	if (previousFileName == null)
	    previousFileName = (new File("untitled.xml")).getAbsolutePath();

	String fileName = FileChooserUtil.getOpenFile(
	    frame, msg("browse"), previousFileName, /*filtered*/ false);
	if (fileName != null) 
	    entry.setText(FileUtil.fileToURLName(fileName));
    }

    private void discard() {
	int index = list.getSelectedIndex();
	if (index >= 0) {
	    DefaultListModel model = (DefaultListModel) list.getModel();
	    model.removeElementAt(index);

	    entry.setText("");
	    discard.setEnabled(false);
	}
    }

    private void ok() {
	String templateName = entry.getText().trim();

	if (templateName.length() == 0) {
	    getToolkit().beep();
	    entry.requestFocus();
	    return;
	}

	try {
	    new URL(templateName);
	} catch (MalformedURLException e) {
	    getToolkit().beep();
	    JOptionPane.showMessageDialog(
		frame, msg("invalidURL", templateName),
		msg("error"), JOptionPane.ERROR_MESSAGE);
	    entry.requestFocus();
	    entry.selectAll();
	    return;
	}

	updateTemplateNames();
	result = templateName;
	hide();
	dispose();
    }

    private void cancel() {
	updateTemplateNames();
	result = null;
	hide();
	dispose();
    }

    private void updateTemplateNames() {
	DefaultListModel model = (DefaultListModel) list.getModel();
	int count = model.size();

	templateNames.removeAllElements();
	for (int i = 0; i < count; ++i)
	    templateNames.addElement(model.elementAt(i));
    }
}

