/*
 * Copyright (c) 2001 Pixware. 
 *
 * Author: Hussein Shafie
 *
 * This file is part of the XMLmind XML Editor project.
 * For conditions of distribution and use, see the accompanying legal.txt file.
 */
package com.xmlmind.xmleditapp;

import java.util.ResourceBundle;
import java.util.MissingResourceException;
import java.awt.*;
import java.awt.event.*;
import javax.swing.*;
import fr.pixware.util.StringUtil;
import com.xmlmind.xmledit.JDocumentPane;
import com.xmlmind.xmledit.modeltool.SearchReplaceText;
import com.xmlmind.xmledit.modeltool.TextOffset;
import com.xmlmind.xmledit.modeltool.TextRange;

public class ReplaceTextDialog extends JDialog implements ActionListener {
    private Frame frame;

    private static final String[] buttonNames = {
	"replaceText", "skipText", "replaceAllText", "cancel"
    };

    // -----------------------------------------------------------------------

    private static ResourceBundle resourceBundle = null;
    static {
	try {
	    resourceBundle = ResourceBundle.getBundle(
		"com.xmlmind.xmleditapp.ReplaceTextDialogRes");
	} catch (MissingResourceException ignored) {}
    }

    private static String msg(String id) {
	String message = null;
	try {
	    message = resourceBundle.getString(id);
	} catch (Exception e) {
	    return id;
	}
	return message;
    }

    // -----------------------------------------------------------------------

    public ReplaceTextDialog(Frame frame, ActionListener actionListener) {
	super(frame, msg("title"), /*modal*/ true); 

	this.frame = frame;

   	addWindowListener(new WindowAdapter() {
   	    public void windowClosing(WindowEvent e) {
		cancel();
   	    }
   	});

        // workArea is a JPanel with a BorderLayout.
	JPanel workArea = (JPanel) getContentPane();
	workArea.setLayout(new FlowLayout(FlowLayout.LEFT, 5, 5));

	// Should be implemented by all LAFs.
	workArea.registerKeyboardAction(
	    this, "cancel", KeyStroke.getKeyStroke(KeyEvent.VK_ESCAPE, 0), 
	    JPanel.WHEN_ANCESTOR_OF_FOCUSED_COMPONENT);

	JLabel label = new JLabel(msg("question"));
	workArea.add(label);

	for (int i = 0; i < buttonNames.length; ++i) {
	    String name = buttonNames[i];

	    String text = msg(name);
	    int mnemoPos = text.indexOf('_');
	    char mnemo;
	    if (mnemoPos < 0) {
		mnemo = 0;
	    } else {
		mnemo = text.charAt(mnemoPos+1);
		text = StringUtil.replaceAll(text, "_", "");
	    }

	    JButton button = new JButton(text);
	    workArea.add(button);

	    if (mnemoPos >= 0)
		button.setMnemonic(mnemo);

	    button.setActionCommand(name);
	    if (i == buttonNames.length-1)
		button.addActionListener(this);
	    else
		button.addActionListener(actionListener);
	}
	
        pack();
	setResizable(true);
    }

    public void showDialog() {
	setLocation(frame.getLocation());
	pack();

	// Give focus to the replace button.
	getContentPane().getComponent(1).requestFocus();

        show();
    }

    // -----------------------------------------------------------------------

    public void actionPerformed(ActionEvent e) {
        String command = e.getActionCommand();

        if (command.equals("cancel"))
            cancel();
    }
    
    private void cancel() {
	hide();
	dispose();
    }
}


