/*
 * Copyright (c) 2001 Pixware. 
 *
 * Author: Hussein Shafie
 *
 * This file is part of the XMLmind XML Editor project.
 * For conditions of distribution and use, see the accompanying legal.txt file.
 */
package com.xmlmind.xmleditapp;

import java.util.ResourceBundle;
import java.util.MissingResourceException;
import java.util.Vector;
import java.util.StringTokenizer;
import java.awt.*;
import java.awt.event.*;
import javax.swing.*;
import javax.swing.border.TitledBorder;
import com.xmlmind.awtutil.MultiLineLabel;

public class StructFormatParamDialog extends JDialog 
                                     implements ActionListener {
    private Frame frame;
    private JTextField[] paramFields;
    private String[] result;

    // -----------------------------------------------------------------------

    private static ResourceBundle resourceBundle = null;
    static {
	try {
	    resourceBundle = ResourceBundle.getBundle(
		"com.xmlmind.xmleditapp.StructFormatParamDlgRes");
	} catch (MissingResourceException ignored) {}
    }

    private static String msg(String id) {
	String message = null;
	try {
	    message = resourceBundle.getString(id);
	} catch (Exception e) {
	    return id;
	}
	return message;
    }

    // -----------------------------------------------------------------------

    public StructFormatParamDialog(Frame frame, String[][] parameterUsage,
				   String[] parameters) {
	super(frame, msg("title"), /*modal*/ true); 

	this.frame = frame;

   	addWindowListener(new WindowAdapter() {
   	    public void windowClosing(WindowEvent e) {
   	        cancel();
   	    }
   	});

        // workArea is a JPanel with a BorderLayout.
	JPanel workArea = (JPanel) getContentPane();
	workArea.setLayout(new GridBagLayout());

	// Should be implemented by all LAFs.
	workArea.registerKeyboardAction(
	    this, "cancel", KeyStroke.getKeyStroke(KeyEvent.VK_ESCAPE, 0), 
	    JPanel.WHEN_ANCESTOR_OF_FOCUSED_COMPONENT);

        GridBagConstraints constraints = new GridBagConstraints();
        constraints.insets.top = 5;
        constraints.insets.left = 5;
        constraints.insets.right = 5;
        constraints.gridx = 0;
        constraints.gridy = 0;

	JPanel form = createForm(parameterUsage, parameters);

	JScrollPane scroller = new JScrollPane(form);
	scroller.setPreferredSize(new Dimension(600, 400));
	constraints.fill = GridBagConstraints.BOTH;
	constraints.weightx = 1;
	constraints.weighty = 1;
	workArea.add(scroller, constraints);
	++constraints.gridy;

	// Buttons ---

	JPanel buttonFrame = new JPanel(new GridLayout(1, 2, 10, 0));
        constraints.insets.bottom = 5;
	constraints.fill = GridBagConstraints.NONE;
	constraints.weightx = 0;
	constraints.weighty = 0;
	workArea.add(buttonFrame, constraints);

        JButton button = new JButton(msg("ok"));
	button.setActionCommand("ok");
	button.addActionListener(this);
        buttonFrame.add(button);
	getRootPane().setDefaultButton(button);
          
        button = new JButton(msg("cancel"));
        button.setActionCommand("cancel");
        button.addActionListener(this);
        buttonFrame.add(button);

	pack();
	setResizable(true);
    }

    private JPanel createForm(String[][] parameterUsage,
			      String[] parameters) {
	JPanel form = new JPanel(new GridBagLayout());

	Vector resultList = new Vector();
	paramFields = new JTextField[parameterUsage.length];

        GridBagConstraints constraints = new GridBagConstraints();
        constraints.insets.top = 5;
        constraints.insets.left = 5;
        constraints.insets.right = 5;
        constraints.insets.bottom = 5;
	constraints.fill = GridBagConstraints.HORIZONTAL;
	constraints.weightx = 1;
        constraints.gridx = 0;
        constraints.gridy = 0;

	int paramLength = (parameters.length/2)*2;

	for (int i = 0; i < parameterUsage.length; ++i) {
	    String[] paramUsage = parameterUsage[i];
	    String paramName = paramUsage[0];
	    String paramValue = null;

	    for (int j = 0; j < paramLength; ++j) {
		if (paramName.equals(parameters[j])) {
		    paramValue = parameters[j+1];
		    break;
		}
	    }

	    resultList.addElement(paramName);
	    resultList.addElement((paramValue == null)? 
				  paramUsage[2] : paramValue);

	    JTextField paramField = new JTextField();
	    paramFields[i] = paramField;

	    JPanel subForm = createSubForm(paramUsage, paramValue, paramField);
	    form.add(subForm, constraints);
	    ++constraints.gridy;
	}

	result = new String[resultList.size()];
	resultList.copyInto(result);

	return form;
    }

    private JPanel createSubForm(String[] paramUsage, String paramValue,
				 JTextField paramField) {
	String paramName = paramUsage[0];
	String paramType = paramUsage[1];
	String paramDefault = paramUsage[2];
	String paramDescription = paramUsage[3];
	if (paramValue == null)
	    paramValue = paramDefault;

	JPanel form = new JPanel(new GridBagLayout());
	form.setBorder(new TitledBorder(paramName));

        GridBagConstraints constraints = new GridBagConstraints();
        constraints.insets.top = 2;
        constraints.insets.left = 2;
        constraints.insets.right = 2;
        constraints.insets.bottom = 2;
        constraints.gridx = 0;
        constraints.gridy = 0;

	paramField.setText(paramValue);
	constraints.fill = GridBagConstraints.HORIZONTAL;
	constraints.weightx = 1;
	constraints.gridwidth = 2;
	form.add(paramField, constraints);
	++constraints.gridy;
	paramField.setActionCommand("ok");
	paramField.addActionListener(this);
	
	MultiLineLabel label = new MultiLineLabel(msg("type"));
	constraints.fill = GridBagConstraints.NONE;
	constraints.weightx = 0;
	constraints.gridwidth = 1;
	constraints.anchor = GridBagConstraints.NORTHEAST;
	form.add(label, constraints);
	++constraints.gridx;

	label = new MultiLineLabel(wrapWords(paramType, 60));
	constraints.anchor = GridBagConstraints.NORTHWEST;
	form.add(label, constraints);
	++constraints.gridy;
	constraints.gridx = 0;

	label = new MultiLineLabel(msg("default"));
	constraints.anchor = GridBagConstraints.NORTHEAST;
	form.add(label, constraints);
	++constraints.gridx;

	label = new MultiLineLabel(wrapWords(paramDefault, 60));
	constraints.anchor = GridBagConstraints.NORTHWEST;
	form.add(label, constraints);
	++constraints.gridy;
	constraints.gridx = 0;

	label = new MultiLineLabel(msg("description"));
	constraints.anchor = GridBagConstraints.NORTHEAST;
	form.add(label, constraints);
	++constraints.gridx;

	label = new MultiLineLabel(wrapWords(paramDescription, 60));
	constraints.anchor = GridBagConstraints.NORTHWEST;
        constraints.insets.bottom = 2;
	form.add(label, constraints);
	++constraints.gridy;
	constraints.gridx = 0;

	return form;
    }

    private static final String wrapWords(String text, int maxLineLength) {
	StringBuffer wrapped = new StringBuffer();

	int lineLength = 0;
	StringTokenizer words = new StringTokenizer(text, " \t\r\n", true);
	while (words.hasMoreTokens()) {
	    String word = words.nextToken();
	    int wordLength;

	    switch (word.charAt(0)) {
	    case ' ': case '\t': case '\r':
		// Ignore word separator.
		break;

	    case '\n':
		// Forced line break.
		wrapped.append('\n');
		lineLength = 0;
		break;

	    default:
		wordLength = word.length();
		if (lineLength + 1 + wordLength > maxLineLength) {
		    if (lineLength > 0)
			wrapped.append('\n');
		    wrapped.append(word);
		    lineLength = wordLength;
		} else {
		    if (lineLength > 0) {
			wrapped.append(' ');
			++lineLength;
		    }
		    wrapped.append(word);
		    lineLength += wordLength;
		}
	    }
	}

	return wrapped.toString();
    }

    public String[] getParameters() {
	setLocationRelativeTo(frame);
	pack();
        show();
        // Modal means blocked here until OK or Cancel are pressed.

        return result;
    }

    // -----------------------------------------------------------------------

    public void actionPerformed(ActionEvent e) {
        String command = e.getActionCommand();

        if (command.equals("ok"))
            ok();
        else if (command.equals("cancel"))
            cancel();
    }

    private void ok() {
	int resultSize = 0;
	for (int i = 1; i < result.length; i += 2) {
	    String newValue = paramFields[i/2].getText().trim();

	    if (result[i].equals(newValue)) {
		result[i] = null;
	    } else {
		result[i] = newValue;
		resultSize += 2;
	    }
	}

	if (resultSize != result.length) {
	    String[] trimmedResult = new String[resultSize];

	    resultSize = 0;
	    for (int i = 0; i < result.length; i += 2) {
		if (result[i+1] != null) {
		    trimmedResult[resultSize] = result[i];
		    trimmedResult[resultSize+1] = result[i+1];
		    resultSize += 2;
		}
	    }

	    result = trimmedResult;
	}

	hide();
	dispose();
    }

    private void cancel() {
	result = null;

	hide();
	dispose();
    }
}
