/*
 * Copyright (c) 2001 Pixware. 
 *
 * Author: Hussein Shafie
 *
 * This file is part of the XMLmind XML Editor project.
 * For conditions of distribution and use, see the accompanying legal.txt file.
 */
package com.xmlmind.xmleditapp;

import java.awt.Dimension;
import java.awt.Rectangle;
import java.awt.Window;
import java.awt.Frame;
import java.awt.event.WindowAdapter;
import java.awt.event.WindowEvent;
import javax.swing.JDialog;

public class Tool extends JDialog {
    protected Frame frame;
    private boolean topSide;
    private boolean rightSide;
    private boolean positioned;

    protected Tool(Frame frame, String title, 
		   boolean topSide, boolean rightSide) {
	super(frame, title, /*modal*/ false);
	this.frame = frame;
	this.topSide = topSide;
	this.rightSide = rightSide;
	positioned = false;

   	addWindowListener(new WindowAdapter() {
   	    public void windowClosing(WindowEvent e) {
   	        close();
   	    }
   	});
    }

    protected void close() {
	hide();
	dispose();
    }

    public void showTool() {
	if (!positioned) {
	    positioned = true;
	    setRelativeLocation(this, frame, topSide, rightSide);
	}
	pack();
	show();
    }

    public static void setRelativeLocation(Window tool, Window parent, 
					   boolean topSide, 
					   boolean rightSide) {
	Dimension dim = tool.getSize();
	Dimension screen = parent.getToolkit().getScreenSize();
	Rectangle r = parent.getBounds();

	int xl = r.x - dim.width;
	int xr = r.x + r.width;
	int offl = (xl < 0)? -xl : 0;
	int offr = ((xr + dim.width > screen.width)? 
		    (xr + dim.width - screen.width) : 0);
	int x;
	if (rightSide)
	    x = (offr <= offl)? xr : xl;
	else
	    x = (offl <= offr)? xl : xr;
	if (x < 0)
	    x = 0;
	else if (x + dim.width > screen.width)
	    x = screen.width - dim.width;

	int y = topSide? r.y : (r.y + r.height - dim.height);
	if (y < 0)
	    y = 0;
	else if (y + dim.height > screen.height)
	    y = screen.height - dim.height;

	tool.setLocation(x, y);
    }
}
