/*
 * Copyright (c) 2001 Pixware. 
 *
 * Author: Hussein Shafie
 *
 * This file is part of the XMLmind XML Editor project.
 * For conditions of distribution and use, see the accompanying legal.txt file.
 */
package com.xmlmind.xmleditapp;

import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;
import java.net.URL;
import fr.pixware.util.WorkInProgressObserver;
import com.xmlmind.xmledit.model.*;
import com.xmlmind.xmledit.modeltool.*;
import com.xmlmind.xmledit.modelimpl.*;
import com.jclark.xml.parse.OpenEntity;
import com.jclark.xml.parse.NotWellFormedException;
import com.xmlmind.structformat.*;

public class XMLFormat implements StructuredFormat {
    private XPDocumentLoader docLoader = new XPDocumentLoader();
    private boolean indentIfDocType = false;
    private boolean indentIfNoDocType = false;
    private int indentation = 2;
    private int maxLineLength = 78;

    public void setGuessingElementContent(boolean guess) {
	docLoader.setGuessingElementContent(guess);
    }

    public void setIndentation(boolean indentIfDocType, 
			       boolean indentIfNoDocType,
			       int indentation, int maxLineLength) {
	this.indentIfDocType = indentIfDocType;
	this.indentIfNoDocType = indentIfNoDocType;
	this.indentation = indentation;
	this.maxLineLength = maxLineLength;
    }

    // -----------------------------------------------------------------------
    // StructuredFormat
    // -----------------------------------------------------------------------

    public String getMimeType() {
	return "text/xml";
    }

    public String[] getFileNameExtensions() {
	return null; // No standard extensions at all.
    }

    public String getDescription() {
	return "";
    }

    public String[][] getParameterUsage() {
	return null;
    }

    public void setParameters(String[] parameters) 
	throws ParameterUsageException {
	throw new ParameterUsageException("parameters not supported");
    }

    public String[] getParameters() {
	return null;
    }

    public void setWorkInProgressObserver(WorkInProgressObserver observer) {
	docLoader.setObserver(observer);
    }

    public WorkInProgressObserver getWorkInProgressObserver() {
	return docLoader.getObserver();
    }

    public void loadDocument(InputStream in, URL url, String javaEncoding,
			     DocumentModel document) 
	throws IOException, StructuredFormatException {
	// javaEncoding ignored: detected from XML content.

	try {
	    docLoader.load(new OpenEntity(in, url.toExternalForm(), url), 
			   document);
	} catch (NotWellFormedException e) {
	    throw new StructuredFormatException(
		e.getEntityLocation(), e.getLineNumber(), 
		e.getColumnNumber(), e.getMessageWithoutLocation());
	}
    }

    public void saveDocument(DocumentModel document, OutputStream out, 
			     URL url, String javaEncoding) 
	throws IOException, StructuredFormatException {
	if (javaEncoding == null)
	    javaEncoding = "UTF8";

	boolean hasDocType = (document.getDocumentType() != null);
	int indent;
	int lineLength;
	if ((indentIfDocType && hasDocType) ||
	    (indentIfNoDocType && !hasDocType)) {
	    indent = indentation;
	    lineLength = maxLineLength;
	} else {
	    indent = -1;
	    lineLength = -1;
	}

	WorkInProgressObserver observer = docLoader.getObserver();
	if (observer != null)
	    observer.workInProgress(this, true);

	try {
	    DocumentWriter.writeDocument(document, out, javaEncoding, 
                                         /*useURL*/ true, indent, lineLength);
	} finally {
	    if (observer != null)
		observer.workInProgress(this, false);
	}
    }
}


