/*
 * Copyright (c) 1999,2000-2001 Pixware. 
 *
 * Author: Hussein Shafie
 *
 * This file is part of the Pixware Java utilities.
 * For conditions of distribution and use, see the accompanying legal.txt file.
 */
package fr.pixware.util;

import java.util.Hashtable;
import java.util.Enumeration;

/**
 * A collection of utility functions (static methods) operating on {@link
 * java.util.Hashtable}.
 */
public class HashtableUtil {
    /**
     * Adds pairs of key/value Strings to a Hashtable.
     * 
     * @param map the Hashtable to be updated
     * @param pairs an even number of String: a key followed by its value;
     * each key/value pair is added to the hashtable (possibly replacing an
     * existing entry with the same key).
     */
    public static void putAll(Hashtable map, String[] pairs) {
	for (int i = 0; i < pairs.length; i += 2) 
	    map.put(pairs[i], pairs[i+1]);
    }

    /**
     * Returns the elements contained in a Hashtable as an array of Strings.
     * 
     * @param map the Hashtable to be queried; assumed to contain String
     * elements
     * @return the elements contained in the Hashtable as an array of Strings
     */
    public static String[] getAllElements(Hashtable map) {
	String[] list = new String[map.size()];

	Enumeration iter = map.elements();
	int i = 0;
	while (iter.hasMoreElements())
	    list[i++] = (String) iter.nextElement();

	return list;
    }
}
