/*
 * Copyright (c) 2002 Pixware. 
 *
 * Author: Hussein Shafie
 *
 * This file is part of the XMLmind XML Editor project.
 * For conditions of distribution and use, see the accompanying legal.txt file.
 */
package fr.pixware.util;

import java.util.Enumeration;

public abstract class PropertySet {
    private static final Enumeration NO_PROPERTY_ENUMERATION = 
        new PropertyEnumeration(new LinearHashtable());

    protected LinearHashtable properties = null;

    // -----------------------------------------------------------------------

    public Object putProperty(Object key, Object value) {
	if (properties == null)
	    properties = new LinearHashtable();

	return properties.put(key, value);
    }

    public Object removeProperty(Object key) {
	if (properties == null)
	    return null;

	Object value = properties.remove(key);

	if (properties.size() == 0)
	    properties = null;

	return value;
    }

    public void removeAllProperties() {
	properties = null;
    }

    public boolean hasProperty(Object key) {
	return (properties == null)? false : (properties.get(key) != null);
    }

    public Object getProperty(Object key) {
	return (properties == null)? null : properties.get(key);
    }

    public int getPropertyCount() {
	return (properties == null)? 0 : properties.size();
    }

    public Enumeration getProperties() {
	if (properties == null)
	    return NO_PROPERTY_ENUMERATION;
	else
	    return new PropertyEnumeration(properties);
    }

    private static class PropertyEnumeration implements Enumeration {
	private LinearHashtable properties;
	private Enumeration keys;
	private Object[] keyValuePair = new Object[2];

	public PropertyEnumeration(LinearHashtable properties) {
	    this.properties = properties;
	    keys = properties.keys();
	}

	public boolean hasMoreElements() {
	    return keys.hasMoreElements();
	}

	public Object nextElement() {
	    String key = (String) keys.nextElement();
	    keyValuePair[0] = key;
	    keyValuePair[1] = properties.get(key);
	    return keyValuePair;
	}
    }
}
