/*
 * Copyright (c) 2001 Pixware. 
 *
 * Author: Hussein Shafie
 *
 * This file is part of the Pixware Java utilities.
 * For conditions of distribution and use, see the accompanying legal.txt file.
 */
package fr.pixware.util;

/**
 * An abstraction of a regular expression matcher.
 * 
 * @see REFactory
 */
public interface RE {
    /**
     * Searches the specified string for this regular expression pattern.
     * 
     * @param input the string to search
     * @return <code>true</code> if the pattern is found; <code>false</code>
     * otherwise
     * <p>You have to put the pattern between <tt>'^'</tt> and <tt>'$'</tt> if
     * you need the string to be matched in its entirety.
     */
    boolean search(String input);

    /**
     * Searches the specified string for this regular expression pattern.
     * 
     * @param input the string to search
     * @param from the index from which to begin the search
     * @return matched text spans if the pattern is found; <code>null</code>
     * otherwise
     * <p>First REMatch of the returned array contains the text span matched
     * by this pattern in its entirety. Following REMatch, if any, correspond
     * to text spans matched by parenthesized subexpressions of this pattern.
     */
    REMatch[] getMatch(String input, int from);

    /**
     * Works like {@link #getMatch(String, int)} but searches more generic
     * {@link CharSequence}.
     */
    REMatch[] getMatch(CharSequence input, int from);
}
