/*
 * Copyright (c) 2001 Pixware. 
 *
 * Author: Hussein Shafie
 *
 * This file is part of the Pixware Java utilities.
 * For conditions of distribution and use, see the accompanying legal.txt file.
 */
package fr.pixware.util;

/**
 * An abstraction of a regular expression engine.
 */
public interface REFactory {
    /**
     * Matching should be case-insensitive.
     */
    static final int CASE_INSENSITIVE = 0x1;
    /**
     * Newlines should match as <tt>^</tt> and <tt>$</tt>.
     */
    static final int MULTI_LINE = 0x2;
    /**
     * Newlines are matched by <tt>.</tt>.
     */
    static final int SINGLE_LINE = 0x4;

    /**
     * Compiles the specified pattern into a regular expression matcher.
     * 
     * @param pattern the pattern to compile
     * @param options one or more (OR-ed) flags parameterizing matching
     * behaviour: CASE_INSENSITIVE, MULTI_LINE, SINGLE_LINE
     * @return a regular expression matcher
     * @exception RESyntaxException if the pattern contains syntax errors
     */
    RE createRE(String pattern, int options) throws RESyntaxException;
}
