/*
 * Copyright (c) 2001 Pixware. 
 *
 * Author: Hussein Shafie
 *
 * This file is part of the Pixware Java utilities.
 * For conditions of distribution and use, see the accompanying legal.txt file.
 */
package fr.pixware.util;

/**
 * Text span returned by {@link RE#getMatch}.
 */
public final class REMatch {
    private int startIndex;
    private int endIndex;
    private String text;

    /**
     * Constructor.
     * 
     * @param startIndex the index of the start of the span
     * @param endIndex the index of the end of the span
     * @param text the text contained in the span
     */
    public REMatch(int startIndex, int endIndex, String text) {
	this.startIndex = startIndex; 
	this.endIndex = endIndex; 
	this.text = text; 
    }

    /**
     * Returns the index of the start of the span.
     * 
     * @return the index of the start of the span
     */
    public int getStartIndex() {
	return startIndex;
    }

    /**
     * Returns the index of the end of the span.
     * 
     * @return the index of the end of the span
     */
    public int getEndIndex() {
	return endIndex;
    }

    /**
     * Returns the text contained in the span.
     * 
     * @return the text contained in the span
     */
    public String getText() {
	return text;
    }
}
