/*
 * Copyright (c) 2001 Pixware. 
 *
 * Author: Hussein Shafie
 *
 * This file is part of the Pixware Java utilities.
 * For conditions of distribution and use, see the accompanying legal.txt file.
 */
package fr.pixware.util;

/**
 * Thrown by workers if its observer wishes to cancel a work in progress.
 * 
 * @see WorkInProgressObserver
 */
public class WorkCanceledException extends RuntimeException {
    private Object worker;

    /**
     * Constructs an exception with a reference to the object that was doing a
     * lengthy work.
     * 
     * @param worker the object that was doing a lengthy work
     */
    public WorkCanceledException(Object worker) {
	this.worker = worker;
    }

    /**
     * Returns the object that was doing the work that has been canceled.
     * 
     * @return the object that was doing the work that has been canceled
     */
    public Object getWorker() {
	return worker;
    }
}
