/*
 * Copyright (c) 2001 Pixware. 
 *
 * Author: Hussein Shafie
 *
 * This file is part of the Pixware Java utilities.
 * For conditions of distribution and use, see the accompanying legal.txt file.
 */
package fr.pixware.util;

/**
 * Implemented by objects needed to be notified (observers) during a work in
 * progress whose total duration is unknown.
 */
public interface WorkInProgressObserver {
    /**
     * Called by the object doing the lengthy work to notify its observer that
     * it is still working.
     * 
     * @param worker the object doing the lengthy work
     * @param working <code>true</code> if the worker is still working;
     * <code>false</code> if the work has just been finished.
     * <p><code>workInProgress(worker, false)</code> is garanteed to be called
     * once even if the work was aborted and an exception (other than
     * <code>WorkCanceledException</code>, see below) thrown.
     * @return <code>false</code> if the observer wishes the work to be
     * canceled; <code>true</code> otherwise.
     * <p>Most workers do not support work cancelation. Those who support this
     * feature will implement it throwing a <code>WorkCanceledException</code>.
     * @see WorkCanceledException
     */
    boolean workInProgress(Object worker, boolean working);
}
