/*
 * Copyright (c) 2000-2002 Pixware. 
 *
 * Author: Hussein Shafie
 *
 * This file is part of the Pixware Java utilities.
 * For conditions of distribution and use, see the accompanying legal.txt file.
 */

import java.util.Enumeration;
import fr.pixware.util.LinearHashtable;

public class TestLinearHashtable {
    public static void main(String[] args) {
	try {
	    test1();
	} catch (Exception e) {
	    e.printStackTrace();
	    System.exit(2);
	}
    }

    private static void test1() throws RuntimeException {
	LinearHashtable htab = new LinearHashtable();

	htab.clear();
	check(htab.size() == 0);

	String[] words = {
	    "zero", "one", "two", "three", "four", 
	    "five", "six", "seven", "eight", "nine", 
	    "ten"
	};

	Integer ii = null;
	for (int i = words.length-1; i >= 0; --i) {
	    ii = new Integer(i);
	    htab.put(words[i], ii);
	    check(htab.get(words[i]).equals(ii));
	}
	check(htab.size() == words.length);
	check(htab.containsKey("ten"));
	check(htab.contains(ii));

	LinearHashtable copy = (LinearHashtable) htab.clone();
	System.out.println(copy);

	String[] wordList = new String[copy.size()];
	copy.copyKeysInto(wordList);

	Integer[] intList = new Integer[copy.size()];
	copy.copyElementsInto(intList);

	Enumeration iter = copy.keys();
	while (iter.hasMoreElements()) {
	    String key = (String) iter.nextElement();
	    System.out.println(key);
	}

	iter = copy.elements();
	while (iter.hasMoreElements()) {
	    Integer value = (Integer) iter.nextElement();
	    System.out.println(value);
	}

	for (int i = 0; i < words.length; ++i) {
	    if ((i % 3) != 2) {
		htab.remove(words[i]);
		check(!htab.containsKey(words[i]));
	    } else {
		htab.put(words[i], words[i]);
		check(htab.get(words[i]).equals(words[i]));
	    }
	}
	check(htab.size() == words.length/3);

	htab.clear();
	check(htab.size() == 0);
    }

    private static void check(boolean condition) {
	if (!condition)
	    throw new RuntimeException("test failed");
    }
}
